OC.L10N.register(
    "contacts",
    {
    "Import contacts" : "Харилцагчдыг импортлох",
    "Details" : "–î—ç–ª–≥—ç—Ä—ç–Ω–≥“Ø–π",
    "All contacts" : "–ë“Ø—Ö —Ö–∞—Ä–∏–ª—Ü–∞–≥—á–∏–¥",
    "_Imported %n contact_::_Imported %n contacts_" : ["%n харилцагч импортлогдлоо","%n харилцагч импортлогдлоо"],
    "_(skipped %n contact)_::_(skipped %n contacts)_" : ["(%n харилцагч алгассан)","(%n харилцагч алгассан)"],
    "Contacts" : "–•–∞—Ä–∏–ª—Ü–∞–≥—á–∏–¥",
    "A contacts app for Nextcloud" : "Nextcloud-д зориулсан харилцагчийн апп",
    "Copy to full name" : "–ë“Ø—Ç—ç–Ω –Ω—ç—Ä —Ö—É—É–ª–∞—Ö",
    "Omit year" : "Жилийг орхих",
    "Allow updating avatars from social media" : "Сошиал медиагаас аватар шинэчлэхийг зөвшөөрөх",
    "There was an error fetching the member list" : "Гишүүдийн жагсаалтыг авахад алдаа гарлаа",
    "Please select a team" : "Баг сонгоно уу",
    "There are no contacts yet" : "Одоогоор харилцагч байхгүй байна",
    "Create contact" : "Харилцагч үүсгэх",
    "There are no contacts in this group" : "Энэ бүлэгт харилцагч байхгүй байна",
    "Create contacts" : "Харилцагчид үүсгэх",
    "Add contacts" : "Харилцагч нэмэх",
    "Manage team" : "Багийг удирдах",
    "Leave team" : "Багаас гарах",
    "Delete team" : "Баг устгах",
    "Setting saved" : "Тохиргоо хадгалагдлаа",
    "Failed to save setting" : "Тохиргоо хадгалж чадсангүй",
    "Contacts settings" : "Харилцагчийн тохиргоо",
    "General" : "–ï—Ä”©–Ω—Ö–∏–π",
    "Update avatars from social media" : "Сошиал медиагаас аватар шинэчлэх",
    "Refreshed once per week" : "Долоо хоногт нэг удаа шинэчлэгдэнэ",
    "Address books" : "Хаягийн дэвтрүүд",
    "Rename" : "–ù—ç—Ä —Å–æ–ª–∏—Ö",
    "Export" : "Экспортлох",
    "Send email" : "Имэйл илгээх",
    "Send email as BCC" : "BCC байдлаар и-мэйл илгээх",
    "Delete" : "–£—Å—Ç–≥–∞—Ö",
    "Show all groups" : "Бүх бүлгийг харуулах",
    "Collapse groups" : "Бүлгүүдийг хураах",
    "Show all teams" : "Бүх багийг харуулах",
    "Collapse teams" : "Багуудыг хураах",
    "Group name cannot be empty" : "Бүлгийн нэр хоосон байж болохгүй",
    "This group already exists" : "Энэ бүлэг аль хэдийн байна",
    "An error occurred while creating the group" : "Бүлэг үүсгэхэд алдаа гарлаа",
    "This team already exists" : "Энэ баг аль хэдийн байна",
    "An error happened during the creation of the team" : "Баг үүсгэхэд алдаа гарлаа",
    "Recently contacted" : "Саяхан холбоо барьсан",
    "Contact groups" : "Харилцагчийн бүлгүүд",
    "Create a new contact group" : "Шинэ харилцагчийн бүлэг үүсгэх",
    "Contact group name" : "Харилцагчийн бүлгийн нэр",
    "Teams" : "Багууд",
    "Create a new team" : "Шинэ баг үүсгэх",
    "Open the contacts app settings" : "Харилцагчийн апп-ийн тохиргоог нээх",
    "_Shared with {num} entity_::_Shared with {num} entities_" : ["{num} субъекттэй хуваалцсан","{num} субъекттэй хуваалцсан"],
    "Copied" : "–•—É—É–ª–∞–≥–¥—Å–∞–Ω",
    "Cannot copy" : "–•—É—É–ª–∞–≥–¥–∞–∞–≥“Ø–π",
    "Copy link" : "–•–æ–ª–±–æ–æ—Å —Ö—É—É–ª–∞—Ö",
    "Toggling of address book was not successful" : "Хаягийн дэвтрийг сэлгэх амжилтгүй боллоо",
    "This will delete the address book and every contacts within it" : "Энэ нь хаягийн дэвтэр болон доторх бүх харилцагчийг устгана",
    "Delete {addressbook}?" : "{addressbook}-г устгах уу?",
    "This will unshare the address book and every contacts within it" : "Энэ нь хаягийн дэвтэр болон доторх бүх харилцагчийн хуваалцалтыг цуцлана",
    "Unshare {addressbook}?" : "{addressbook}-ийн хуваалцалтыг цуцлах уу?",
    "Deletion of address book was not successful." : "Хаягийн дэвтэр устгах амжилтгүй боллоо.",
    "Renaming of address book was not successful." : "Хаягийн дэвтрийн нэр өөрчлөх амжилтгүй боллоо.",
    "{addressbookname} (Hidden)" : "{addressbookname} (Нуугдсан)",
    "Download" : "–¢–∞—Ç–∞–∂ –∞–≤–∞—Ö",
    "Show" : "Харуулах",
    "Unshare from me" : "Миний хуваалцалтыг цуцлах",
    "_%n contact_::_%n contacts_" : ["%n харилцагч","%n харилцагч"],
    "_%n group_::_%n groups_" : ["%n бүлэг","%n бүлэг"],
    "Share with users or groups" : "–ë—É—Å–¥–∞–¥ —Ç“Ø–≥—ç—ç—Ö",
    "Share with users" : "Хэрэглэгчидтэй хуваалцах",
    "No users or groups" : "Хэрэглэгч эсвэл бүлэг байхгүй",
    "Unable to delete the share" : "Хуваалцалтыг устгах боломжгүй",
    "Unable to change permissions" : "Зөвшөөрлийг өөрчлөх боломжгүй",
    "can create and edit" : "үүсгэх, засах эрхтэй",
    "Choose a vCard file to import" : "Импортлох vCard файл сонгоно уу",
    "Import into the {addressbookName} address book" : "{addressbookName} хаягийн дэвтэр рүү импортлох",
    "Select local file" : "Локал файл сонгох",
    "Import from files" : "Файлуудаас импортлох",
    "Importing is disabled because there are no address books available" : "Боломжтой хаягийн дэвтэр байхгүй тул импорт идэвхгүй байна",
    "An error occurred, unable to create the address book" : "Алдаа гарлаа, хаягийн дэвтэр үүсгэх боломжгүй",
    "New address book" : "Шинэ хаягийн дэвтэр",
    "Add new address book" : "Шинэ хаягийн дэвтэр нэмэх",
    "Cancel" : "–±–æ–ª–∏—É–ª–∞—Ö",
    "Add" : "–Ω—ç–º—ç—Ö",
    "First name" : "–ù—ç—Ä",
    "Last name" : "–û–≤–æ–≥",
    "Phonetic first name" : "Нэр (дуудлага)",
    "Phonetic last name" : "Овог (дуудлага)",
    "Display name" : "–•–∞—Ä–∞–≥–¥–∞—Ö –Ω—ç—Ä",
    "Last modified" : "–°“Ø“Ø–ª–¥ ”©”©—Ä—á–∏–ª—Å”©–Ω",
    "Sort contacts by" : "Харилцагчийг эрэмбэлэх",
    "Manages" : "Удирддаг",
    "Oversees" : "Хяналт тавьдаг",
    "An error happened during the config change" : "Тохиргоо өөрчлөхөд алдаа гарлаа",
    "Enforce password protection on files shared to this team" : "Энэ багтай хуваалцсан файлуудад нууц үгийн хамгаалалт шаардах",
    "Use a unique password for all shares to this team" : "Энэ багийн бүх хуваалцалтад өвөрмөц нууц үг ашиглах",
    "Save" : "–•–∞–¥–≥–∞–ª–∞—Ö",
    "Change unique password" : "Өвөрмөц нууц үг өөрчлөх",
    "Failed to save password. Please try again later." : "Нууц үг хадгалахад алдаа гарлаа. Дараа дахин оролдоно уу.",
    "Close" : "–•–∞–∞—Ö",
    "There is no description for this team" : "Энэ багт тайлбар байхгүй байна",
    "Enter a description for the team" : "Багийн тайлбар оруулна уу",
    "Folder" : "Folder",
    "New folder" : "–®–∏–Ω—ç —Ö–∞–≤—Ç–∞—Å",
    "Folder name" : "Хавтасны нэр",
    "This will create a regular folder shared with the team. To create a Team Folder, please contact your {productName} administrator" : "Энэ нь багтай хуваалцсан энгийн хавтас үүсгэнэ. Багийн хавтас үүсгэхийн тулд {productName} администраторт хандана уу.",
    "Talk conversation" : "Talk яриа",
    "New Talk conversation" : "Шинэ Talk яриа",
    "Conversation name" : "Ярианы нэр",
    "Collective" : "Хамтын",
    "Calendar" : "Календар",
    "New calendar" : "Шинэ календар",
    "Calendar name" : "Календарын нэр",
    "Deck board" : "Deck самбар",
    "New Deck board" : "Шинэ Deck самбар",
    "Board name" : "Самбарын нэр",
    "Deck app is not installed. Please install it to create team boards." : "Deck апп суулгаагүй байна. Багийн самбар үүсгэхийн тулд суулгана уу.",
    "Unknown resource type" : "Тодорхойгүй нөөцийн төрөл",
    "Team calendar \"{resourceName}\" created and shared with team" : "Багийн календар \"{resourceName}\" үүсгэгдэж багтай хуваалцсан",
    "{resourceType} \"{resourceName}\" created and shared with team" : "{resourceType} \"{resourceName}\" үүсгэгдэж багтай хуваалцсан",
    "A calendar named \"{name}\" already exists. Please choose a different name." : "\"{name}\" нэртэй календарь аль хэдийн байна. Өөр нэр сонгоно уу.",
    "Failed to create {resourceType}: {error}" : "{resourceType} үүсгэхэд алдаа гарлаа: {error}",
    "An error happened while saving {fields}" : "{fields} хадгалахад алдаа гарлаа",
    "Team name" : "Багийн нэр",
    "Team owner" : "Багийн эзэмшигч",
    "Delete picture" : "–ó—É—Ä–∞–≥ —É—Å—Ç–≥–∞—Ö",
    "Edit" : "Засах",
    "Request to join" : "Нэгдэх хүсэлт",
    "Create" : "“Æ“Ø—Å–≥—ç—Ö",
    "Show in Calendar" : "Календарт харуулах",
    "Your request to join this team is pending approval" : "Таны энэ багт нэгдэх хүсэлт батлагдахыг хүлээж байна",
    "You are not a member of {circle}" : "Та {circle}-ийн гишүүн биш байна",
    "Members" : "Гишүүд",
    "Confirm" : "Баталгаажуулах",
    "Add more info" : "Нэмэлт мэдээлэл оруулах",
    "More fields" : "Нэмэлт талбарууд",
    "Please select a valid format" : "Зөв формат сонгоно уу",
    "Invalid image" : "–±—É—Ä—É—É –∑—É—Ä–∞–≥",
    "Error cropping picture" : "Зураг тайрахад алдаа гарлаа",
    "Pick an avatar" : "Аватар сонгох",
    "Pick" : "Сонгох",
    "Error while processing the picture." : "Зураг боловсруулахад алдаа гарлаа.",
    "Avatar downloaded from social network" : "Аватар сошиал сүлжээнээс татагдлаа",
    "Avatar already up to date" : "Аватар аль хэдийн шинэчлэгдсэн байна",
    "Avatar download failed" : "Аватар татахад алдаа гарлаа",
    "Crop contact photo" : "Харилцагчийн зургийг тайрах",
    "Upload a new picture" : "–®–∏–Ω—ç –∑—É—Ä–∞–≥ –æ—Ä—É—É–ª–∞—Ö",
    "Choose from Files" : "–§–∞–π–ª–∞–∞—Å —Å–æ–Ω–≥–æ—Ö",
    "Download picture" : "–ó—É—Ä–∞–≥ —Ç–∞—Ç–∞–∂ –∞–≤–∞—Ö",
    "This contact is in read-only mode. You do not have permission to edit this contact." : "Энэ харилцагч зөвхөн унших горимд байна. Та энэ харилцагчийг засварлах эрхгүй.",
    "The contact you were trying to edit has changed. Please manually refresh the contact. Any further edits will be discarded." : "Та засварлахыг оролдсон харилцагч өөрчлөгдсөн байна. Харилцагчийг гараар шинэчилнэ үү. Цаашдын бүх засварууд хаягдана.",
    "Address book" : "–•–∞—è–≥–∏–π–Ω –±“Ø—Ä—Ç–≥—ç–ª",
    "Add contact to Birthday Calendar" : "Харилцагчийг Төрсөн өдрийн календарт нэмэх",
    "Exclude contact from Birthday Calendar" : "Харилцагчийг Төрсөн өдрийн календараас хасах",
    "{title} at {organization}" : "{organization} дахь {title}",
    "Name" : "–ù—ç—Ä",
    "Syntax error. Cannot open the contact." : "Синтаксийн алдаа. Харилцагчийг нээх боломжгүй.",
    "The contact does not exist on the server anymore." : "Харилцагч серверт байхгүй болсон байна.",
    "Unable to retrieve the contact from the server, please check your network connection." : "Серверээс харилцагчийг татаж чадсангүй, сүлжээний холболтоо шалгана уу.",
    "An error occurred while trying to move the contact" : "Харилцагчийг зөөхөд алдаа гарлаа",
    "An error occurred while trying to copy the contact" : "Харилцагчийг хуулахад алдаа гарлаа",
    "Unable to update contact" : "Харилцагчийг шинэчлэх боломжгүй",
    "No contact selected" : "Харилцагч сонгоогүй байна",
    "Select a contact on the list to begin" : "Эхлэхийн тулд жагсаалтаас харилцагч сонгоно уу",
    "Title" : "–¶–æ–ª/–ê–ª–±–∞–Ω —Ç—É—à–∞–∞–ª",
    "Company" : "Компани",
    "Go to talk conversation" : "Talk яриа руу очих",
    "View profile" : "Профайл үзэх",
    "This contact was broken and received a fix. Please review the content and click here to save it." : "Энэ харилцагч эвдэрсэн байсан бөгөөд засвар хийгдсэн. Агуулгыг хянаад хадгалахын тулд энд дарна уу.",
    "Edit profile" : "Профайл засах",
    "Clone contact" : "Харилцагч хуулбарлах",
    "Generate QR Code" : "QR код үүсгэх",
    "Contact vCard as QR code" : "Харилцагчийн vCard-г QR код болгох",
    "Pick an address book" : "Хаягийн дэвтэр сонгох",
    "Select address book" : "–•–∞—è–≥–∏–π–Ω –±“Ø—Ä—Ç–≥—ç–ª —Å–æ–Ω–≥–æ—Ö",
    "Media shares with you" : "Тантай хуваалцсан медиа",
    "Talk conversations with you" : "Тантай хийсэн Talk яриа",
    "Calendar events with you" : "Тантай холбоотой календарын үйл явдлууд",
    "Deck cards with you" : "Тантай хуваалцсан Deck картууд",
    "No shared items with this contact" : "Энэ харилцагчтай хуваалцсан зүйл байхгүй",
    "This contact cannot be moved" : "Энэ харилцагчийг зөөх боломжгүй",
    "This contact cannot be grouped" : "Энэ харилцагчийг бүлэглэх боломжгүй",
    "Add contacts to groups" : "Харилцагчийг бүлэгт нэмэх",
    "Move contacts to addressbook" : "Харилцагчийг хаягийн дэвтэр рүү зөөх",
    "Select groups" : "Бүлгүүд сонгох",
    "Select addressbook" : "Хаягийн дэвтэр сонгох",
    "Selected contacts" : "Сонгосон харилцагчид",
    "Please note that only {count} of the {total} contacts can be added to a group" : "Зөвхөн {total} харилцагчаас {count} нь бүлэгт нэмэгдэж болохыг анхаарна уу.",
    "Please note that only {count} of the {total} contacts can be moved" : "Зөвхөн {total} харилцагчийн {count}-г зөөх боломжтойг анхаарна уу",
    "Move" : "Move",
    "from {addressbook}" : "{addressbook}-с",
    "Remove from favorites" : "Remove from favorites",
    "Add to favorites" : "Add to favorites",
    "Confirm merging contacts" : "Харилцагч нэгтгэхийг баталгаажуулах",
    "The selected contacts have conflicting information. Choose which information to keep" : "Сонгосон харилцагчид зөрчилтэй мэдээлэлтэй байна. Аль мэдээллийг хадгалахаа сонгоно уу.",
    "Contacts can be merged" : "Харилцагчдыг нэгтгэх боломжтой",
    "Groups" : "–ë–∞–≥—É—É–¥",
    "Select groups to add the merged contact to" : "Нэгтгэсэн харилцагчийг нэмэх бүлгүүдийг сонгоно уу",
    "Merge contacts" : "Харилцагч нэгтгэх",
    "_Delete {number} contact_::_Delete {number} contacts_" : ["{number} харилцагч устгах","{number} харилцагч устгах"],
    "Please select at least one editable contact to delete" : "Устгах нэг ч гэсэн засах боломжтой харилцагч сонгоно уу",
    "Please select two editable contacts to merge" : "Нэгтгэх хоёр засах боломжтой харилцагч сонгоно уу",
    "_Add {number} contact to group_::_Add {number} contacts to group_" : ["{number} харилцагчийг бүлэгт нэмэх","{number} харилцагчийг бүлэгт нэмэх"],
    "Please select at least one editable contact to add to a group" : "Бүлэгт нэмэх нэг ч гэсэн засах боломжтой харилцагч сонгоно уу",
    "_Move {number} contact to addressbook_::_Move {number} contacts to addressbook_" : ["{number} харилцагчийг хаягийн дэвтэрт зөөх","{number} харилцагчийг хаягийн дэвтэрт зөөх"],
    "Please select at least one editable contact to move to an addressbook" : "Хаягийн дэвтэр рүү зөөх нэг ч гэсэн засах боломжтой харилцагч сонгоно уу",
    "Are you sure you want to proceed?" : "Та үргэлжлүүлэхдээ итгэлтэй байна уу?",
    "Add contacts to group" : "Харилцагчийг бүлэгт нэмэх",
    "Unselect {number}" : "{number}-г сонголтоос хасах",
    "Add to {group}" : "{group}-т нэмэх",
    "Add members to {group}" : "{group}-т гишүүд нэмэх",
    "Please note that you can only add contacts from writable address books to contact groups. Contacts from read-only address books, such as the system address book, cannot be added." : "Харилцагчийн бүлэгт зөвхөн бичих боломжтой хаягийн дэвтрүүдийн харилцагчдыг нэмж болохыг анхаарна уу. Системийн хаягийн дэвтэр гэх мэт зөвхөн унших хаягийн дэвтрүүдийн харилцагчдыг нэмэх боломжгүй.",
    "Remove {type}" : "{type} устгах",
    "Add to group" : "Бүлэгт нэмэх",
    "Add members to group" : "Бүлэгт гишүүд нэмэх",
    "Search {types}" : "{types} хайх",
    "Add guest" : "Зочин нэмэх",
    "Search for people to add" : "Нэмэх хүн хайх",
    "No results" : "“Æ—Ä –¥“Ø–Ω –±–∞–π—Ö–≥“Ø–π",
    "Add {type}" : "{type} нэмэх",
    "New team name" : "Шинэ багийн нэр",
    "Personal team" : "Хувийн баг",
    "This team will only be visible to you. Other members will not be able to see or use it." : "Энэ баг зөвхөн танд харагдана. Бусад гишүүд үүнийг харах эсвэл ашиглах боломжгүй.",
    "Local team" : "Локал баг",
    "This team will not be shared with the other instances of the global scale" : "Энэ баг глобал хэмжээний бусад instance-уудтай хуваалцагдахгүй",
    "Create team" : "Баг үүсгэх",
    "Promote as sole owner" : "Цорын ганц эзэмшигч болгох",
    "Promote to {level}" : "{level} болгон дэвшүүлэх",
    "Demote to {level}" : "{level} болгон бууруулах",
    "Are you sure you want to leave this team? This action cannot be undone." : "Та энэ багаас гарахдаа итгэлтэй байна уу? Энэ үйлдлийг буцаах боломжгүй.",
    "Leave team failed." : "Багаас гарахад алдаа гарлаа.",
    "Could not delete the member {displayName}" : "{displayName} гишүүнийг устгаж чадсангүй",
    "Could not change the member level to {level}" : "Гишүүний түвшинг {level} болгож өөрчлөх боломжгүй",
    "Could not accept membership request" : "Гишүүнчлэлийн хүсэлтийг хүлээн авах боломжгүй",
    "Accept membership request" : "Гишүүнчлэлийн хүсэлтийг хүлээн авах",
    "Reject membership request" : "Гишүүнчлэлийн хүсэлтийг татгалзах",
    "Manage level" : "Түвшин удирдах",
    "Remove member" : "Гишүүн устгах",
    "Unable to get the results" : "Үр дүн авах боломжгүй",
    "Some members could not be added" : "Зарим гишүүдийг нэмэж чадсангүй",
    "There was an issue adding members to the team" : "Багт гишүүд нэмэхэд асуудал гарлаа",
    "The list of members is only visible to members of this team" : "Гишүүдийн жагсаалт зөвхөн энэ багийн гишүүдэд харагдана",
    "You currently have no access to the member list" : "Та одоогоор гишүүдийн жагсаалтад хандах эрхгүй байна",
    "Add to {team}" : "{team}-т нэмэх",
    "Invite members to {team}" : "{team}-д гишүүд урих",
    "Pending" : "–•“Ø–ª—ç—ç–≥–¥—ç–∂ –±–∞–π–≥–∞–∞",
    "Chart" : "Диаграм",
    "Select Date" : "Огноо сонгох",
    "Select type" : "Төрөл сонгох",
    "Add contact in group" : "Бүлэгт харилцагч нэмэх",
    "None" : "—é—É —á “Ø–≥“Ø–π",
    "copy" : "хуулах",
    "Select option" : "Сонголт сонгох",
    "Notes" : "–¢—ç–º–¥—ç–≥–ª—ç–ª",
    "send an email" : "и-мэйл илгээх",
    "Personal dates" : "Хувийн огноонууд",
    "Add property of this type" : "Энэ төрлийн шинж чанар нэмэх",
    "Member" : "–ì–∏—à“Ø“Ø–Ω",
    "This is a read-only group managed by administrators. Group members can only view this group." : "Энэ нь администраторуудын удирддаг зөвхөн унших бүлэг юм. Бүлгийн гишүүд зөвхөн энэ бүлгийг харах боломжтой.",
    "Unable to create the contact." : "Харилцагч үүсгэх боломжгүй.",
    "Contact not found" : "Харилцагч олдсонгүй",
    "Group {group} not found" : "{group} бүлэг олдсонгүй",
    "Add member" : "–ì–∏—à“Ø“Ø–Ω –Ω—ç–º—ç—Ö",
    "New contact" : "–®–∏–Ω—ç —Ö–∞—Ä–∏–ª—Ü–∞–≥—á",
    "_{success} contact added to {name}_::_{success} contacts added to {name}_" : ["{success} харилцагч {name}-д нэмэгдлээ","{success} харилцагч {name}-д нэмэгдлээ"],
    "_Adding {success} contact to {name}_::_Adding {success} contacts to {name}_" : ["{success} харилцагчийг {name}-д нэмж байна","{success} харилцагчийг {name}-д нэмж байна"],
    "_{count} error_::_{count} errors_" : ["{count} алдаа","{count} алдаа"],
    "_Importing %n contact into {addressbook}_::_Importing %n contacts into {addressbook}_" : ["%n харилцагчийг {addressbook}-д импортлож байна","%n харилцагчийг {addressbook}-д импортлож байна"],
    "_Done importing %n contact into {addressbook}_::_Done importing %n contacts into {addressbook}_" : ["%n харилцагчийг {addressbook}-д импортлож дууслаа","%n харилцагчийг {addressbook}-д импортлож дууслаа"],
    "No data for this contact" : "Энэ харилцагчийн мэдээлэл байхгүй",
    "No data for this contact on their profile" : "Энэ харилцагчийн профайлд мэдээлэл байхгүй",
    "Import" : "–ò–º–ø–æ—Ä—Ç",
    "Are you sure you want to import this contact file?" : "Энэ харилцагчийн файлыг импортлохдоо итгэлтэй байна уу?",
    "Could not copy" : "Хуулах боломжгүй",
    "Join team" : "Багт нэгдэх",
    "You are about to leave {circle}.\nAre you sure?" : "Та {circle}-г орхихоор байна.\nИтгэлтэй байна уу?",
    "Please confirm team leave" : "Багаас гарахыг баталгаажуулна уу",
    "Could not leave the team {displayName}" : "{displayName} багаас гарах боломжгүй",
    "Unable to join the team" : "Багт нэгдэх боломжгүй",
    "You are about to delete {circle}.\nAre you sure?" : "Та {circle}-г устгахаар байна.\nИтгэлтэй байна уу?",
    "Please confirm team deletion" : "Баг устгахыг баталгаажуулна уу",
    "Unable to delete the team" : "Баг устгах боломжгүй",
    "Confirm enabling federation" : "Холбооныг идэвхжүүлэхийг баталгаажуулах",
    "Enabling this will prevent {circle} from being a member of other teams.\nAre you sure?" : "Үүнийг идэвхжүүлснээр {circle} бусад багуудын гишүүн болохоос сэргийлнэ.\nИтгэлтэй байна уу?",
    "Enable federation" : "Холбооныг идэвхжүүлэх",
    "Link copied to the clipboard" : "Холбоос санах ойд хуулагдлаа",
    "Could not copy link to the clipboard." : "Холбоосыг санах ойд хуулах боломжгүй.",
    "Not grouped" : "–ë–∞–≥—Ç –æ—Ä–æ–æ–≥“Ø–π",
    "Organization chart" : "Байгууллагын бүтцийн диаграм",
    "Team" : "Баг",
    "User" : "–•—ç—Ä—ç–≥–ª—ç–≥—á",
    "Group" : "–ë“Ø–ª—ç–≥",
    "Email" : "–¶–∞—Ö–∏–º —à—É—É–¥–∞–Ω",
    "Contact" : "Холбоо барих",
    "Moderator" : "–®–∞–ª–≥–∞–≥—á",
    "Admin" : "–ê–¥–º–∏–Ω",
    "Owner" : "–≠–∑—ç–º—à–∏–≥—á",
    "Invites" : "Урилга",
    "Anyone can request membership" : "Хэн ч гишүүнчлэл хүсэх боломжтой",
    "Members need to accept invitation" : "Гишүүд урилгыг хүлээн зөвшөөрөх шаардлагатай",
    "Memberships must be confirmed/accepted by a Moderator (requires \"Anyone can request membership\")" : "Гишүүнчлэлийг Модератор баталгаажуулах/зөвшөөрөх ёстой (\"Хэн ч гишүүнчлэл хүсэх боломжтой\" шаардлагатай)",
    "Members can also invite" : "Гишүүд мөн урих боломжтой",
    "Membership" : "Гишүүнчлэл",
    "Prevent teams from being a member of another team" : "Багийг өөр багийн гишүүн болохоос урьдчилан сэргийлэх",
    "Federation" : "Федерац",
    "Allow federated members" : "Холбоосон гишүүдийг зөвшөөрөх",
    "Privacy" : "–•—É–≤–∏–π–Ω –Ω—É—É—Ü",
    "Visible to everyone" : "Бүгдэд харагдана",
    "users" : "хэрэглэгчид",
    "Users" : "Хэрэглэгчид",
    "groups" : "бүлгүүд",
    "federated users" : "холбооны хэрэглэгчид",
    "Federated users" : "Федерацийн хэрэглэгчид",
    "teams" : "багууд",
    "email addresses" : "и-мэйл хаягууд",
    "Email addresses" : "И-мэйл хаягууд",
    "contacts" : "харилцагчид",
    "Detailed name" : "–î—ç–ª–≥—ç—Ä—ç–Ω–≥“Ø–π –Ω—ç—Ä",
    "Additional names" : "–ù—ç–º—ç–ª—Ç –Ω—ç—Ä“Ø“Ø–¥",
    "Prefix" : "Угтвар",
    "Suffix" : "Дагавар",
    "Nickname" : "–¢–æ–≤—á –Ω—ç—Ä",
    "Website" : "–¶–∞—Ö–∏–º —Ö—É—É–¥–∞—Å",
    "Location" : "–ë–∞–π—Ä—à–∏–ª",
    "Federated Cloud ID" : "Федераци үүлний ID",
    "Home" : "–ì—ç—Ä",
    "Work" : "–ê–∂–∏–ª",
    "Other" : "–ë—É—Å–∞–¥",
    "Address" : "–•–∞—è–≥",
    "Post office box" : "–®—É—É–¥–∞–Ω–≥–∏–π–Ω —Ö–∞–π—Ä—Ü–∞–≥",
    "Extended address" : "Өргөтгөсөн хаяг",
    "City" : "–•–æ—Ç",
    "State or province" : "–ê–π–º–∞–≥",
    "Postal code" : "–®—É—É–¥–∞–Ω–≥–∏–π–Ω –∫–æ–¥",
    "Country" : "–£–ª—Å",
    "Birthday" : "–¢”©—Ä—Å”©–Ω ”©–¥”©—Ä",
    "Place of birth" : "Төрсөн газар",
    "Anniversary" : "Ойн өдөр",
    "Date of death" : "–ù–∞—Å –±–∞—Ä—Å–∞–Ω –æ–≥–Ω–æ–æ",
    "Place of death" : "Нас барсан газар",
    "Instant messaging" : "Шуурхай мессеж",
    "Phone" : "–£—Ç–∞—Å",
    "Mobile" : "–ì–∞—Ä —É—Ç–∞—Å",
    "Work mobile" : "Ажлын гар утас",
    "Home mobile" : "Гэрийн гар утас",
    "Fax" : "–§–∞–∫—Å",
    "Fax home" : "–ì—ç—Ä–∏–π–Ω —Ñ–∞–∫—Å",
    "Fax work" : "–ê–∂–ª—ã–Ω —Ñ–∞–∫—Å",
    "Pager" : "Пейжер",
    "Voice" : "Дуу хоолой",
    "Car" : "Машин",
    "Work pager" : "Ажлын пейжер",
    "Line manager" : "Шууд удирдлага",
    "Social network" : "–û–ª–æ–Ω –Ω–∏–π—Ç–∏–π–Ω —Å“Ø–ª–∂—ç—ç",
    "Relationship to you" : "Тантай харьцаа",
    "Spouse" : "Гэр бүл",
    "Child" : "—Ö“Ø“Ø—Ö—ç–¥",
    "Mother" : "—ç—Ö",
    "Father" : "—ç—Ü—ç–≥",
    "Parent" : "—ç—Ü—ç–≥ —ç—Ö",
    "Brother" : "–∞—Ö",
    "Sister" : "—ç–≥—á",
    "Relative" : "–•–∞–º–∞–∞—Ä–∞–ª",
    "Friend" : "–ù–∞–π–∑",
    "Colleague" : "Хамт ажиллагч",
    "Assistant" : "Туслах",
    "Related contacts" : "Холбоотой харилцагчид",
    "Agent" : "Агент",
    "Emergency" : "Яаралтай",
    "Co-worker" : "–•–∞–º—Ç—Ä–∞–Ω –∞–∂–∏–ª–ª–∞–≥—á",
    "Gender" : "–•“Ø–π—Å",
    "Female" : "–≠–º—ç–≥—Ç—ç–π",
    "Male" : "–≠—Ä—ç–≥—Ç—ç–π",
    "Unknown" : "“Æ–ª —Ç–∞–Ω–∏–≥–¥–∞—Ö –∑“Ø–π–ª",
    "Time zone" : "–¶–∞–≥–∏–π–Ω –±“Ø—Å",
    "Spoken languages" : "Ярьдаг хэл",
    "_{failed} contact failed to be read_::_{failed} contacts failed to be read_" : ["{failed} харилцагчийг унших амжилтгүй боллоо","{failed} харилцагчийг унших амжилтгүй боллоо"],
    "An error has occurred in team(s). Check the console for more details." : "Баг(уудад) алдаа гарлаа. Дэлгэрэнгүй мэдээллийг консолоос харна уу.",
    "Unable to create team {circleName}" : "{circleName} баг үүсгэх боломжгүй",
    "Unable to delete team {circleId}" : "{circleId} баг устгах боломжгүй",
    "Unable to delete contact" : "Харилцагч устгах боломжгүй",
    "Value copied to the clipboard" : "Утгыг санах ойд хуулсан",
    "Could not copy value to the clipboard." : "Утгыг санах ойд хуулах боломжгүй байна.",
    "note" : "тэмдэглэл",
    "email" : "и-мэйл"
},
"nplurals=2; plural=(n != 1);");
