OC.L10N.register(
    "contacts",
    {
    "Import contacts" : "Увези контакте",
    "Details" : "Детаљи",
    "All contacts" : "Сви контакти",
    "_Imported %n contact_::_Imported %n contacts_" : ["Увезен је %n контакт","Увезена су %n контакта","Увезено је %n контаката"],
    "Contacts" : "Контакти",
    "A contacts app for Nextcloud" : "Контакти за Некстклауд",
    "The Nextcloud contacts app is a user interface for Nextcloud's CardDAV server. Easily sync contacts from various devices with your Nextcloud and edit them online.\n\n* 🚀 **Integration with other Nextcloud apps!** Currently Mail and Calendar – more to come.\n* 🎉 **Never forget a birthday!** You can sync birthdays and other recurring events with your Nextcloud Calendar.\n* 👥 **Sharing of Adressbooks!** You want to share your contacts with your friends or coworkers? No problem!\n* 🙈 **We’re not reinventing the wheel!** Based on the great and open SabreDAV library." : "Апликација Контакти за Некстклауд је корисничко сучеље за Некстклаудов КардДАВ сервер. Лако синхронизујте контакте са различитих уређаја са Некстклаудом и уређујте их преко мреже.\n\n* 🚀 **Интеграција са осталим Некстклауд апликацијама!** Тренутно са Е-Поштом и Календаром – планирано је још.\n* 🎉 **Да никад не заборавите рођендан!** Можете синхронизовати рођендане и друге догађаје који се понављају са Некстклауд Календаром.\n* 👥 **Дељење адресара!** Желите да поделите своје контакте са пријатељима или колегама? Нема проблема!\n* 🙈 **Не измишљамо топлу воду!** Базирано на сјајној и отвореној СејбрДАВ (SabreDAV) библиотеци.",
    "Copy to full name" : "Копирај у пуно име",
    "Omit year" : "без године",
    "Allow updating avatars from social media" : "Дозволи ажурирање аватара са друштвених медија",
    "There was an error fetching the member list" : "Дошло је до грешке приликом добављања листе чланова",
    "Please select a team" : "Молимо вас да изаберете тим",
    "Loading team…" : "Тим се учитава…",
    "Loading contacts …" : "Учитавају се контакти …",
    "There are no contacts yet" : "Још увек нема контаката",
    "Create contact" : "Направи контакт",
    "There are no contacts in this group" : "Нема контаката у овој групи",
    "Create contacts" : "Направи контакте",
    "Add contacts" : "Додај контакте",
    "Loading …" : "Учитава се …",
    "Manage team" : "Управљај тимом",
    "Leave team" : "Напусти тим",
    "Delete team" : "Обриши тим",
    "Contacts settings" : "Подешавања контакта",
    "Update avatars from social media" : "Ажурирај аватар са друштвених медија",
    "Address books" : "Адресари",
    "Rename" : "Преименуј",
    "Export" : "Извоз",
    "Send email" : "Пошаљи е-пошту",
    "Send email as BCC" : "Пошаљи и-мејл као BCC",
    "Delete" : "Обриши",
    "Show all groups" : "Прикажи све групе",
    "Collapse groups" : "Сажми групе",
    "Show all teams" : "Прикажи све тимове",
    "Collapse teams" : "Сажми тимове",
    "Group name cannot be empty" : "Назив групе не може бити празан",
    "This group already exists" : "Група већ постоји",
    "An error occurred while creating the group" : "Дошло је до грешке током креирања групе",
    "This team already exists" : "Овај тим већ постоји",
    "An error happened during the creation of the team" : "Дошло је до грешке приликом креирања тима",
    "Recently contacted" : "Недавно контактирани",
    "Contact groups" : "Групе контаката",
    "Create a new contact group" : "Креирај нову групу контаката",
    "Contact group name" : "Назив групе контаката",
    "Teams" : "Тимови",
    "Create a new team" : "Креирај нови тим",
    "Open the contacts app settings" : "Отвара подешавања апликације контаката",
    "_Shared with {num} entity_::_Shared with {num} entities_" : ["Дељено са {num} ентитетом","Дељено са {num} ентитета","Дељено са {num} ентитета"],
    "Copied" : "Копирано",
    "Cannot copy" : "Не може да се копира",
    "Copy link" : "Копирај везу",
    "Toggling of address book was not successful" : "Укључивање/искључивање адресара није било успешно",
    "This will delete the address book and every contacts within it" : "Ово ће обрисати адресар и све контакте из њега",
    "Delete {addressbook}?" : "Да обришем {addressbook}?",
    "This will unshare the address book and every contacts within it" : "Ово ће обрисати дељење адресара и свих контаката из њега",
    "Unshare {addressbook}?" : "Да обришем дељење {addressbook}?",
    "Deletion of address book was not successful." : "Брисање адресара није успело.",
    "Renaming of address book was not successful." : "Преименовање адресара није успело.",
    "{addressbookname} (Hidden)" : "{addressbookname} (скривен)",
    "Download" : "Преузми",
    "Show" : "Прикажи",
    "Unshare from me" : "Уклони дељење за мене",
    "_%n contact_::_%n contacts_" : ["%n контакт","%n контакта","%n контакта"],
    "_%n group_::_%n groups_" : ["%n група","%n групе","%n група"],
    "Share with users or groups" : "Дели са корисницима или групама",
    "Share with users" : "Подели са корисницима",
    "No users or groups" : "Нема корисника или група",
    "Unable to delete the share" : "Не могу да обришем дељење",
    "Unable to change permissions" : "Не могу да променим права приступа",
    "Choose a vCard file to import" : "Изаберите „vCard“ фајл за увоз",
    "Import into the {addressbookName} address book" : "Увоз у адресар {addressbookName}",
    "Select local file" : "Одабери локални фајл",
    "Import from files" : "Увези из фајлова",
    "Importing is disabled because there are no address books available" : "Увоз је искључен пошто нема доступних адресара",
    "An error occurred, unable to create the address book" : "Дошло је до грешке, не могу да направим адресар",
    "Add new address book" : "Додај нови адресар",
    "Cancel" : "Одустани",
    "Add" : "Додај",
    "First name" : "Име",
    "Last name" : "Презиме",
    "Phonetic first name" : "Име онако како се изговара",
    "Phonetic last name" : "Презиме онако како се изговара",
    "Display name" : "Име за приказ",
    "Last modified" : "Последња измена",
    "Manages" : "Управља",
    "Oversees" : "Надгледа",
    "An error happened during the config change" : "Дошло је до грешке током измене конфигурације",
    "Enforce password protection on files shared to this team" : "Форсирај да се фајлови подељени са овим тимом заштите лозинком ",
    "Use a unique password for all shares to this team" : "Користи јединствену лозинку за сва дељења са овим тимом",
    "Unique password …" : "Јединствена лозинка …",
    "Save" : "Сачувај",
    "Change unique password" : "Промени јединствену лозинку",
    "Failed to save password. Please try again later." : "Није успело чување лозинке. Молимо вас да касније покушате поново.",
    "Close" : "Затвори",
    "There is no description for this team" : "Нема описа овог тима",
    "Enter a description for the team" : "Унесите опис овог тима",
    "Folder" : "Folder",
    "Folder name" : "Име фасцикле",
    "Calendar" : "Календар",
    "An error happened while saving {fields}" : "Дошло је до грешке током чувања {fields}",
    "Team name" : "Назив тима",
    "Team owner" : "Власник тима",
    "Delete picture" : "Обриши слику",
    "Edit" : "Уреди",
    "Request to join" : "Захтев за приступ",
    "Create" : "Направи",
    "Your request to join this team is pending approval" : "Ваш захтев за приступ овом тиму чека на одобрење",
    "You are not a member of {circle}" : "Нисте члан круга {circle}",
    "Members" : "Чланови",
    "Confirm" : "Потврди",
    "Add more info" : "Додај још информација",
    "More fields" : "Још поља",
    "Please select a valid format" : "Молимо вас да изаберете исправни формат",
    "Invalid image" : "Неисправна слика",
    "Error cropping picture" : "Грешка приликом опсецања слике",
    "Pick an avatar" : "Одабери аватар",
    "Pick" : "Изаберите",
    "Error while processing the picture." : "Грешка приликом обраде слике.",
    "Avatar downloaded from social network" : "Аватар преузет са друштвене мреже",
    "Avatar already up to date" : "Аватар већ ажуран",
    "Avatar download failed" : "Преузимање аватара није успело",
    "Crop contact photo" : "Опсеци фото контакта",
    "Upload a new picture" : "Отпреми нову слику",
    "Choose from Files" : "Изаберите из Фајлова",
    "Download picture" : "Преузми слику",
    "This contact is in read-only mode. You do not have permission to edit this contact." : "Контакт је у режиму само за читање. Немате дозволе да га уређујете.",
    "The contact you were trying to edit has changed. Please manually refresh the contact. Any further edits will be discarded." : "Контакт који уређујете је промењен. Освежите га ручно. Свака даља измена биће одбачена.",
    "Address book" : "Адресар",
    "Add contact to Birthday Calendar" : "Додај контакт у календар Рођендани",
    "Exclude contact from Birthday Calendar" : "Изузми контакт из календара Рођендани",
    "{title} at {organization}" : "{title} у {organization}",
    "Name" : "Име",
    "Syntax error. Cannot open the contact." : "Синтаксна грешка. Не могу да отворим контакт.",
    "The contact does not exist on the server anymore." : "Контакт више не постоји на серверу.",
    "Unable to retrieve the contact from the server, please check your network connection." : "Грешка приликом дохватања контакта са сервера, проверите интернет везу.",
    "An error occurred while trying to move the contact" : "Грешка приликом покушаја померања контакта",
    "An error occurred while trying to copy the contact" : "Грешка приликом покушаја копирања контакта",
    "Unable to update contact" : "Контакт не може да се ажурира",
    "No contact selected" : "Није одабран контакт",
    "Select a contact on the list to begin" : "Одаберите контакт са списка да почнете",
    "Title" : "Звање",
    "Company" : "Компанија",
    "Go to talk conversation" : "Иди на talk разговор",
    "View profile" : "Погледај профил",
    "This contact was broken and received a fix. Please review the content and click here to save it." : "Контакт је био неисправан и поправљен је. Прегледајте садржај и кликните овде да га сачувате.",
    "Edit profile" : "Уреди профил",
    "Clone contact" : "Клонирај контакт",
    "Generate QR Code" : "Генериши КуеР код",
    "Contact vCard as QR code" : "vCard контакта као QR кôд",
    "Pick an address book" : "Изабери адресар",
    "Select address book" : "Одаберите адресар",
    "Media shares with you" : "Медији подељени са вама",
    "Talk conversations with you" : "Talk разговори са вама",
    "Calendar events with you" : "Догађаји календара са вама",
    "Deck cards with you" : "Шпилови картица са вама",
    "No shared items with this contact" : "Нема ставки подељених са овим контактом",
    "Move" : "Move",
    "Remove from favorites" : "Уклони из омиљених",
    "Add to favorites" : "Додај у омиљене",
    "Confirm merging contacts" : "Потврди спајање контаката",
    "The selected contacts have conflicting information. Choose which information to keep" : "Информације изабраних контаката су у конфликту. Изаберите информације које желите да се задрже",
    "Contacts can be merged" : "Контакти могу да се споје",
    "Groups" : "Групе",
    "Select groups to add the merged contact to" : "Изаберите групе у које ће се додати спојени контакт",
    "Merge contacts" : "Споји контакте",
    "_Delete {number} contact_::_Delete {number} contacts_" : ["Обриши {number} контакт","Обриши {number} контакта","Обриши {number} контаката"],
    "Please select at least one editable contact to delete" : "Молимо вас да изаберете за брисање барем један контакт који може да се уређује",
    "Please select two editable contacts to merge" : "Изаберите два контакта за спајање који могу да се уреде",
    "Are you sure you want to proceed?" : "Да ли сте сигурни да желите да наставите?",
    "Search contacts …" : "Претрага контаката …",
    "Unselect {number}" : "Уклони избор са {number}`",
    "Add to {group}" : "Додај у {group}",
    "Add members to {group}" : "Додај чланове у {group}",
    "Please note that you can only add contacts from writable address books to contact groups. Contacts from read-only address books, such as the system address book, cannot be added." : "Имајте на уму да контакте можете да додате у групе контаката само из адресара у које може да се уписује. Не могу да се додају контакти из адресара из којих може само да се чита, као што је системски адресар.",
    "Remove {type}" : "Уклони {type}",
    "Add to group" : "Додај у групу",
    "Add members to group" : "Додаје кориснике у групу",
    "Search {types}" : "Претражи {types}",
    "Add guest" : "Додај госта",
    "Search for people to add" : "Претражите особе које желите да додате",
    "No results" : "Нема резултата",
    "Add {type}" : "Додај {type}",
    "New team name" : "Нови назив тима",
    "Personal team" : "Лични тим",
    "This team will only be visible to you. Other members will not be able to see or use it." : "Овај тим ће бити видљив само вама. Остали чланови га неће видети и неће моћи да га користе.",
    "Local team" : "Локални тим",
    "This team will not be shared with the other instances of the global scale" : "Овај тим се неће делити са осталим инстанцама на глобалном нивоу",
    "Create team" : "Креирај тим",
    "Promote as sole owner" : "Унапреди као јединог власника",
    "Promote to {level}" : "Унапреди у {level}",
    "Demote to {level}" : "Врати на {level}",
    "Are you sure you want to leave this team? This action cannot be undone." : "Да ли сте сигурни да желите да напустите овај тим? Ова операција не може да се поништи.",
    "Leave team failed." : "Није успело напуштање тима.`",
    "Could not delete the member {displayName}" : "Члан {displayName} не може да се обрише",
    "Could not change the member level to {level}" : "Ниво члана није могао да се промени у {level}",
    "Could not accept membership request" : "Захтев за чланство није могао да се прихвати",
    "Accept membership request" : "Прихвати захтев за чланство",
    "Reject membership request" : "Одбиј захтев за чланство",
    "Manage level" : "Управљање нивоом",
    "Remove member" : "Уклони члана",
    "Unable to get the results" : "Нису могли да се добаве резултати",
    "Some members could not be added" : "Неки чланови нису могли да се додају",
    "There was an issue adding members to the team" : "Дошло је до проблема приликом додавања чланова у тим",
    "Loading members list …" : "Учитава се листа чланова …",
    "The list of members is only visible to members of this team" : "Листу чланова могу да виде само чланови овог тима",
    "You currently have no access to the member list" : "Тренутно немате приступ листи чланова",
    "Add to {team}" : "Додај у {team}",
    "Invite members to {team}" : "Позови чланове у {team}",
    "Pending" : "На чекању",
    "Select chart …" : "Изаберите график …",
    "Chart" : "График",
    "Select Date" : "Одаберите датум",
    "Select type" : "Одаберите тип",
    "Add contact in group" : "Додај контакт у групу",
    "None" : "Ништа",
    "Select option" : "Изаберите опцију",
    "Notes" : "Белешке",
    "Personal dates" : "Лични датуми",
    "Add property of this type" : "Додај особину овог типа",
    "Member" : "Члан",
    "This is a read-only group managed by administrators. Group members can only view this group." : "Ово је група само-за-читање којом управљају администратори. Чланови групе могу само да приказују ову групу.",
    "Unable to create the contact." : "Не могу да направим контакт.",
    "Contact not found" : "Контакт није нађен",
    "Group {group} not found" : "Група {group} не може да се пронађе",
    "Add member" : "Додај члана",
    "New contact" : "Нови контакт",
    "_{success} contact added to {name}_::_{success} contacts added to {name}_" : ["{success} контакт додат у {name}","{success} контакта додата у {name}","{success} контаката додато у {name}"],
    "_Adding {success} contact to {name}_::_Adding {success} contacts to {name}_" : ["Додајем {success} контакт у {name}","Додајем {success} контакта у {name}","Додајем {success} контаката у {name}"],
    "_{count} error_::_{count} errors_" : ["{count} грешка","{count} грешке","{count} грешака"],
    "_Importing %n contact into {addressbook}_::_Importing %n contacts into {addressbook}_" : ["Увозим %n контакт у {addressbook}","Увозим %n контакта у {addressbook}","Увозим %n контаката у {addressbook}"],
    "_Done importing %n contact into {addressbook}_::_Done importing %n contacts into {addressbook}_" : ["Завршен увоз %n контакта у {addressbook}","Завршен увоз %n контакта у {addressbook}","Завршен увоз %n контаката у {addressbook}"],
    "No data for this contact" : "Нема података о овом контакту",
    "No data for this contact on their profile" : "На профилу корисника нема података о овом контакту",
    "Import" : "Увоз",
    "Are you sure you want to import this contact file?" : "Да ли сте сигурни да желите да увезете овај фајл контаката?",
    "Could not copy" : "Не може да се копира",
    "Join team" : "Приступи у тим",
    "You are about to leave {circle}.\nAre you sure?" : "Напустићете {circle}.\nДа ли сте сигурни?",
    "Please confirm team leave" : "Молимо вас да потврдите напуштање тима",
    "Could not leave the team {displayName}" : "Тим {displayName} не може да се напусти",
    "Unable to join the team" : "Не може да се приступи тиму",
    "You are about to delete {circle}.\nAre you sure?" : "Обрисаћете {circle}.\nДа ли сте сигурни?",
    "Please confirm team deletion" : "Молимо вас да потврдите брисање тима",
    "Unable to delete the team" : "Тим не може да се обрише",
    "Link copied to the clipboard" : "Линк је копиран у клипборд",
    "Could not copy link to the clipboard." : "Линк није могао да се копира у клипборд.",
    "Not grouped" : "Негруписани",
    "Organization chart" : "Организациони график",
    "Team" : "Тим",
    "User" : "Корисник",
    "Group" : "Група",
    "Email" : "Е-пошта",
    "Contact" : "Контакт",
    "Moderator" : "Модератор",
    "Admin" : "Администратор",
    "Owner" : "Власник",
    "Invites" : "Позивнице",
    "Anyone can request membership" : "Било ко може да захтева чланство",
    "Members need to accept invitation" : "Чланови морају да прихвате позивницу",
    "Memberships must be confirmed/accepted by a Moderator (requires \"Anyone can request membership\")" : "Чланство мора да потврди/прихвати Модератор (захтева се „Било ко може да захтева чланство”)",
    "Members can also invite" : "Чланови такође могу да позивају",
    "Membership" : "Чланство",
    "Prevent teams from being a member of another team" : "Спречи да тимови буде чланови другог тима",
    "Privacy" : "Приватност",
    "Visible to everyone" : "Видљиво свима",
    "users" : "корисници",
    "Users" : "Корисници",
    "groups" : "групе",
    "teams" : "тимови",
    "email addresses" : "е-мејл адресе",
    "Email addresses" : "И-мејл адресе",
    "contacts" : "контакти",
    "Detailed name" : "Пуно име",
    "Additional names" : "Додатна имена",
    "Prefix" : "Префикс",
    "Suffix" : "Суфикс",
    "Nickname" : "Надимак",
    "Website" : "Вебсајт",
    "Location" : "Локација",
    "Federated Cloud ID" : "ИД Здруженог облака",
    "Home" : "Кућа",
    "Work" : "Посао",
    "Other" : "Остало",
    "Address" : "Адреса",
    "Post office box" : "Поштански фах",
    "Extended address" : "Додатак адреси",
    "City" : "Место",
    "State or province" : "Област",
    "Postal code" : "Поштански број",
    "Country" : "Држава",
    "Birthday" : "Рођендан",
    "Place of birth" : "Место рођења",
    "Anniversary" : "Годишњица",
    "Date of death" : "Датум смрти",
    "Place of death" : "Место смрти",
    "Instant messaging" : "Брзе поруке",
    "Phone" : "Телефон",
    "Mobile" : "Мобилни",
    "Work mobile" : "Пословни мобилни",
    "Home mobile" : "Лични мобилни",
    "Fax" : "Факс",
    "Fax home" : "Факс кућа",
    "Fax work" : "Факс посао",
    "Pager" : "Пејџер",
    "Voice" : "Гласовна пошта",
    "Car" : "Кола",
    "Work pager" : "Пословни пејџер",
    "Line manager" : "Надређени менаџер",
    "Social network" : "Друштвена мрежа",
    "Relationship to you" : "Веза са Вама",
    "Spouse" : "Супружник",
    "Child" : "Дете",
    "Mother" : "Мајка",
    "Father" : "Отац",
    "Parent" : "Родитељ",
    "Brother" : "Брат",
    "Sister" : "Сестра",
    "Relative" : "Родбина",
    "Friend" : "Пријатељ",
    "Colleague" : "Колега",
    "Assistant" : "Асистент",
    "Related contacts" : "Слични контакти",
    "Agent" : "Агент",
    "Emergency" : "Хитни број",
    "Co-worker" : "Сарадник",
    "Gender" : "Пол",
    "Female" : "Женски",
    "Male" : "Мушки",
    "Unknown" : "Непознато",
    "Time zone" : "Временска зона",
    "Spoken languages" : "Знање језика",
    "_{failed} contact failed to be read_::_{failed} contacts failed to be read_" : ["Не могу да прочитам {failed} контакт","Не могу да прочитам {failed} контакта","Не могу да прочитам {failed} контаката"],
    "An error has occurred in team(s). Check the console for more details." : "Дошло је до грешке у тиму/тимовима. Погледајте конзолу за више детаља.",
    "Unable to create team {circleName}" : "Не може да се креира тим {circleName}",
    "Unable to delete team {circleId}" : "Не може да се обрише тим {circleId}",
    "Unable to delete contact" : "Не могу да обришем контакт"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");
