OC.L10N.register(
    "contacts",
    {
    "Import contacts" : "Importar contactos",
    "Details" : "Detalles",
    "All contacts" : "Todos os contactos",
    "_Imported %n contact_::_Imported %n contacts_" : ["Importado %n contacto","Importados %n contactos"],
    "_(skipped %n contact)_::_(skipped %n contacts)_" : ["(omitiuse %n contacto)","(omitíronse %n contactos)"],
    "Contacts" : "Contactos",
    "A contacts app for Nextcloud" : "Unha aplicación de contactos para Nextcloud",
    "The Nextcloud contacts app is a user interface for Nextcloud's CardDAV server. Easily sync contacts from various devices with your Nextcloud and edit them online.\n\n* 🚀 **Integration with other Nextcloud apps!** Currently Mail and Calendar – more to come.\n* 🎉 **Never forget a birthday!** You can sync birthdays and other recurring events with your Nextcloud Calendar.\n* 👥 **Sharing of Adressbooks!** You want to share your contacts with your friends or coworkers? No problem!\n* 🙈 **We’re not reinventing the wheel!** Based on the great and open SabreDAV library." : "O Contactos de Nextcloud é unha interface de usuario para o servidor CalDAV de Nextcloud. Sincronice doadamente os contactos en varios dispositivos co seu Nextcloud e edíteos en liña.\n\n* 🚀 **Integración con outras aplicacións de Nextcloud!** Actualmente Correo e Calendario – outras por chegar.\n* 🎉 **Non esqueza nunca un aniversario!** Pode sincronizar aniversarios e outros eventos recorrentes co seu Calendario de Nextcloud.\n* 👥 **Compartir as axendas!** Quere compartir os seus contactos cos seus amigos e compañeiros de traballo? Non hai problema!\n* 🙈 **Non reinventamos a roda!** Baseada na grande e aberta biblioteca SabreDAV.",
    "Copy to full name" : "Copiar a nome completo",
    "Omit year" : "Omitir o ano",
    "Allow updating avatars from social media" : "Permitir actualizar avatares desde os medios sociais",
    "There was an error fetching the member list" : "Produciuse un erro ao recuperar a lista de membros",
    "Please select a team" : "Seleccione un equipo",
    "Loading team…" : "Cargando equipo…",
    "Loading contacts …" : "Cargando contactos…",
    "There are no contacts yet" : "Aínda non hai contactos",
    "Create contact" : "Crear contacto.",
    "There are no contacts in this group" : "Non hai contactos neste grupo",
    "Create contacts" : "Crear contactos",
    "Add contacts" : "Engadir contactos",
    "Loading …" : "Cargando…",
    "Manage team" : "Xestionar o equipo",
    "Leave team" : "Abandonar o equipo",
    "Delete team" : "Eliminar o equipo",
    "Setting saved" : "Axustes gardados",
    "Failed to save setting" : "Produciuse un fallo ao gardar o axuste",
    "Contacts settings" : "Axustes de Contactos",
    "General" : "Xeral",
    "Update avatars from social media" : "Actualizar avatares desde as redes sociais",
    "Refreshed once per week" : "Actualizado unha vez por semana",
    "Address books" : "Cadernos de enderezos",
    "Rename" : "Cambiar o nome",
    "Export" : "Exportar",
    "Send email" : "Enviar o correo",
    "Send email as BCC" : "Enviar un correo-e como Cca",
    "Delete" : "Eliminar",
    "Show all groups" : "Amosar todos os grupos",
    "Collapse groups" : "Contraer grupos",
    "Show all teams" : "Amosar todos os equipos",
    "Collapse teams" : "Contraer os equipos",
    "Group name cannot be empty" : "O nome do grupo non pode estar baleiro",
    "This group already exists" : "Xa existe este grupo",
    "An error occurred while creating the group" : "Produciuse un erro ao crear o grupo",
    "This team already exists" : "Xa existe este equipo",
    "An error happened during the creation of the team" : "Produciuse un erro durante a creación do equipo",
    "Recently contacted" : "Contactado recentemente",
    "Contact groups" : "Grupos de contacto",
    "Create a new contact group" : "Crear un novo grupo de contactos",
    "Contact group name" : "Nome do grupo de contacto",
    "Teams" : "Equipos",
    "Create a new team" : "Crear un novo equipo",
    "Open the contacts app settings" : "Abrir os axustes da aplicación de contactos",
    "_Shared with {num} entity_::_Shared with {num} entities_" : ["Compartido con {num} entidade","Compartido con {num} entidades"],
    "Copied" : "Copiado",
    "Cannot copy" : "Non se pode copiar",
    "Copy link" : "Copiar a ligazón",
    "Toggling of address book was not successful" : "Non foi posíbel facer o cambio do caderno de enderezos.",
    "This will delete the address book and every contacts within it" : "Isto eliminará o caderno de enderezos e todos os contactos do mesmo",
    "Delete {addressbook}?" : "Quere eliminar {addressbook}?",
    "This will unshare the address book and every contacts within it" : "Isto deixará de compartir o caderno de enderezos e todos os contactos do mesmo",
    "Unshare {addressbook}?" : "Quere deixar de compartir {addressbook}?",
    "Deletion of address book was not successful." : "Non foi posíbel eliminar o caderno de enderezos.",
    "Renaming of address book was not successful." : "Non foi posíbel cambiarlle o nome ao caderno de enderezos.",
    "{addressbookname} (Hidden)" : "{addressbookname}  (Agochado)",
    "Download" : "Descargar",
    "Show" : "Amosar",
    "Unshare from me" : "Deixar de compartir comigo",
    "_%n contact_::_%n contacts_" : ["%n contacto","%n contactos"],
    "_%n group_::_%n groups_" : ["%n grupo","%n grupos"],
    "Share with users or groups" : "Compartir con usuarios ou grupos",
    "Share with users" : "Compartir cos usuarios",
    "No users or groups" : "Non hai usuarios nin grupos",
    "Unable to delete the share" : "Non é posíbel eliminar a compartición",
    "Unable to change permissions" : "Non é posíbel cambiar os permisos",
    "can create and edit" : "pode crear e editar",
    "Choose a vCard file to import" : "Escolla un ficheiro vCard para importalo",
    "Import into the {addressbookName} address book" : "Importar ao caderno de enderezos {addressbookName}",
    "Select local file" : "Seleccionar ficheiro local",
    "Import from files" : "Importar desde ficheiros",
    "Importing is disabled because there are no address books available" : "A importación está desactivado porque non hai cadernos de enderezos dispoñíbeis",
    "An error occurred, unable to create the address book" : "Produciuse un erro: non é posíbel crear o caderno de enderezos",
    "New address book" : "Novo caderno de enderezos",
    "Add new address book" : "Engadir un novo caderno de enderezos",
    "Cancel" : "Cancelar",
    "Add" : "Engadir",
    "First name" : "Nome",
    "Last name" : "Apelidos",
    "Phonetic first name" : "Nome fonético",
    "Phonetic last name" : "Apelido fonético",
    "Display name" : "Nome para amosar",
    "Last modified" : "Última modificación",
    "Sort contacts by" : "Ordenar os contactos por",
    "Manages" : "Xestiona",
    "Oversees" : "Supervisa",
    "An error happened during the config change" : "Produciuse un erro durante o cambio de configuración",
    "Enforce password protection on files shared to this team" : "Facer obrigatoria a protección por contrasinal nos ficheiros compartidos con este equipo",
    "Use a unique password for all shares to this team" : "Usar un contrasinal único para todas as comparticións neste equipo",
    "Unique password …" : "Contrasinal único…",
    "Save" : "Gardar",
    "Change unique password" : "Cambiar o contrasinal único",
    "Failed to save password. Please try again later." : "Produciuse un fallo ao gardar o contrasinal. Ténteo de novo máis tarde.",
    "Close" : "Pechar",
    "There is no description for this team" : "Non hai ningunha descrición para este equipo",
    "Enter a description for the team" : "Introduza unha descrición para o equipo",
    "Folder" : "Cartafol",
    "New folder" : "Novo cartafol",
    "Folder name" : "Nome do cartafol",
    "This will create a regular folder shared with the team. To create a Team Folder, please contact your {productName} administrator" : "Isto creará un cartafol normal compartido co equipo. Para crear un cartafol de equipo, contacte coa administración de {productName}",
    "Talk conversation" : "Conversa no Parladoiro",
    "New Talk conversation" : "Nova conversa no Parladoiro",
    "Conversation name" : "Nome da conversa",
    "Collective" : "Colectivo",
    "Calendar" : "Calendario",
    "New calendar" : "Novo calendario",
    "Calendar name" : "Nome do calendario",
    "Deck board" : "Taboleiro da Gabeta",
    "New Deck board" : "Novo taboleiro da Gabeta",
    "Board name" : "Nome do taboleiro",
    "Deck app is not installed. Please install it to create team boards." : "A aplicación Gabeta non está instalada. Instálea para crear taboleiros de equipo.",
    "Unknown resource type" : "Tipo de recurso descoñecido",
    "Team calendar \"{resourceName}\" created and shared with team" : "Calendario do equipo «{resourceName}» creado e compartido co equipo",
    "{resourceType} \"{resourceName}\" created and shared with team" : "{resourceType} «{resourceName}» creado e compartido co equipo",
    "A calendar named \"{name}\" already exists. Please choose a different name." : "Xa existe un calendario chamado «{name}». Escolla outro nome.",
    "Failed to create {resourceType}: {error}" : "Produciuse un fallo ao crear {resourceType}: {error}",
    "An error happened while saving {fields}" : "Produciuse un erro ao gardar {fields}",
    "Team name" : "Nome do equipo",
    "Team owner" : "Propietario do equipo",
    "Delete picture" : "Eliminar a imaxe",
    "Edit" : "Editar",
    "Request to join" : "Solicitude para unirse",
    "Create" : "Crear",
    "Show in Calendar" : "Amosar no calendario",
    "Your request to join this team is pending approval" : "A súa solicitude para unirse a este equipo está pendente de aprobación",
    "You are not a member of {circle}" : "Vde. non é membro de {circle}",
    "Members" : "Membros",
    "Confirm" : "Confirmar",
    "Add more info" : "Engadir máis información",
    "More fields" : "Máis campos",
    "Please select a valid format" : "Seleccione un formato válido",
    "Invalid image" : "Imaxe incorrecta",
    "Error cropping picture" : "Produciuse un erro ao recortar a imaxe",
    "Pick an avatar" : "Escolla un avatar",
    "Pick" : "Escoller",
    "Error while processing the picture." : "Produciuse un erro ao procesar a imaxe.",
    "Avatar downloaded from social network" : "Avatar descargado das redes sociais",
    "Avatar already up to date" : "O avatar xa está actualizado",
    "Avatar download failed" : "Produciuse un fallo ao descargar o avatar",
    "Crop contact photo" : "Recortar a foto do contacto",
    "Upload a new picture" : "Enviar unha nova imaxe",
    "Choose from Files" : "Escoller desde Ficheiros",
    "Download picture" : "Descargar a imaxe",
    "This contact is in read-only mode. You do not have permission to edit this contact." : "Este contacto está en modo de só lectura. Non ten permiso para editar este contacto.",
    "The contact you were trying to edit has changed. Please manually refresh the contact. Any further edits will be discarded." : "O contacto que estaba tentando editar cambiou, Actualice o contacto manualmente. Calquera outra edición será desbotada.",
    "Address book" : "Caderno de enderezos",
    "Add contact to Birthday Calendar" : "Engadir contacto ao calendario de aniversarios",
    "Exclude contact from Birthday Calendar" : "Excluír contacto do calendario de aniversarios",
    "{title} at {organization}" : "{title} en {organization}",
    "Name" : "Nome",
    "Syntax error. Cannot open the contact." : "Erro de sintaxe. Non foi posíbel abrir o contacto.",
    "The contact does not exist on the server anymore." : "O contacto xa non existe no servidor.",
    "Unable to retrieve the contact from the server, please check your network connection." : "Non é posíbel recuperar o contacto do servidor. Comprobe a súa conexión de rede.",
    "An error occurred while trying to move the contact" : "Produciuse un erro ao tentar mover o contacto",
    "An error occurred while trying to copy the contact" : "Produciuse un erro ao tentar copiar o contacto",
    "Unable to update contact" : "Non é posíbel actualizar o contacto",
    "No contact selected" : "Non hai ningún contacto seleccionado",
    "Select a contact on the list to begin" : "Para comezar, seleccione un contacto da lista",
    "Title" : "Título",
    "Company" : "Empresa",
    "Go to talk conversation" : "Ir á conversa en Parladoiro",
    "View profile" : "Ver o perfil",
    "This contact was broken and received a fix. Please review the content and click here to save it." : "Este contacto rachou e recibiu unha solución. Revise o contido e prema aquí para gardalo.",
    "Edit profile" : "Editar o perfil",
    "Clone contact" : "Clonar o contacto",
    "Generate QR Code" : "Xerar un código QR",
    "Contact vCard as QR code" : "vCard de contacto como código QR",
    "Pick an address book" : "Escolla un caderno de enderezos",
    "Select address book" : "Seleccionar caderno de enderezos",
    "Media shares with you" : "Medios compartidos con Vde.",
    "Talk conversations with you" : "Conversas en Parladoiro con Vde.",
    "Calendar events with you" : "Eventos de calendario con Vde.",
    "Deck cards with you" : "Tarxetas de Gabeta con Vde.",
    "No shared items with this contact" : "Non hai elementos compartidos con este contacto",
    "This contact cannot be moved" : "Non é posíbel mover este contacto",
    "This contact cannot be grouped" : "Non é posíbel agrupar este contacto",
    "Add contacts to groups" : "Engadir contactos a grupos",
    "Move contacts to addressbook" : "Mover contactos ao caderno de enderezos",
    "Select groups" : "Seleccionar grupos",
    "Select addressbook" : "Seleccionar caderno de enderezos",
    "Selected contacts" : "Contactos seleccionados",
    "Please note that only {count} of the {total} contacts can be added to a group" : "Teña en conta que só é posíbel engadir {count} dos {total} contactos a un grupo",
    "Please note that only {count} of the {total} contacts can be moved" : "Teña en conta que só é posíbel mover {count} dos {total} contactos a un grupo",
    "Move" : "Move",
    "from {addressbook}" : "desde {addressbook}",
    "Remove from favorites" : "Retirar de favoritos",
    "Add to favorites" : "Engadir a favoritos",
    "Confirm merging contacts" : "Confirmar a combinación de contactos",
    "The selected contacts have conflicting information. Choose which information to keep" : "Os contactos seleccionados teñen información contraditoria. Escolla a información que debe gardar",
    "Contacts can be merged" : "É posíbel combinar os contactos",
    "Groups" : "Grupos",
    "Select groups to add the merged contact to" : "Seleccione os grupos aos que engadir o contacto combinado",
    "Merge contacts" : "Combinar contactos",
    "_Delete {number} contact_::_Delete {number} contacts_" : ["Eliminar {number} contacto","Eliminar {number} contactos"],
    "Please select at least one editable contact to delete" : "Seleccione polo menos un contacto editábel para eliminar",
    "Please select two editable contacts to merge" : "Seleccione dous contactos editábeis para combinar",
    "_Add {number} contact to group_::_Add {number} contacts to group_" : ["Engadir {number} contacto ao grupo","Engadir {number} contactos ao grupo"],
    "Please select at least one editable contact to add to a group" : "Seleccione polo menos un contacto editábel para engadilo a un grupo",
    "_Move {number} contact to addressbook_::_Move {number} contacts to addressbook_" : ["Mover {number} contacto ao caderno de enderezos","Mover {number} contactos ao caderno de enderezos"],
    "Please select at least one editable contact to move to an addressbook" : "Seleccione polo menos un contacto editábel para movelo a un grupo",
    "Are you sure you want to proceed?" : "Confirma que quere continuar?",
    "Add contacts to group" : "Engadir contactos ao grupo",
    "Search contacts …" : "Buscar contactos…",
    "Unselect {number}" : "Deseleccionar {number}",
    "Add to {group}" : "Engadir a {group}",
    "Add members to {group}" : "Engadir membros a {group}",
    "Please note that you can only add contacts from writable address books to contact groups. Contacts from read-only address books, such as the system address book, cannot be added." : "Teña en conta que só pode engadir contactos de cadernos de enderezos editábeis a grupos de contactos. Non é posíbel engadir contactos de cadernos de enderezos de só lectura, como o caderno de enderezos do sistema.",
    "Remove {type}" : "Retirar {type}",
    "Add to group" : "Engadir ao grupo",
    "Add members to group" : "Engadir membros ao grupo",
    "Search {types}" : "Buscar {types}",
    "Add guest" : "Engadir convidados",
    "Search for people to add" : "Buscar persoas para engadir",
    "No results" : "Sen resultados",
    "Add {type}" : "Engadir {type}",
    "New team name" : "Novo nome do equipo",
    "Personal team" : "Equipo persoal",
    "This team will only be visible to you. Other members will not be able to see or use it." : "Este equipo só será visíbel para Vde. Outros membros non poderán velo nin usalo.",
    "Local team" : "Equipo local",
    "This team will not be shared with the other instances of the global scale" : "Este equipo non se compartirá coas outras instancias da escala global",
    "Create team" : "Crear equipo",
    "Promote as sole owner" : "Promover como propietario único",
    "Promote to {level}" : "Promover a {level}",
    "Demote to {level}" : "Relegar a {level}",
    "Are you sure you want to leave this team? This action cannot be undone." : "Confirma que quere abandonar este equipo?Esta acción non é posíbel desfacela.",
    "Leave team failed." : "Produciuse un fallo ao abandonar o equipo",
    "Could not delete the member {displayName}" : "Non foi posíbel eliminar o membro {displayName}",
    "Could not change the member level to {level}" : "Non foi posíbel cambiar o nivel do membro a {level}",
    "Could not accept membership request" : "Non foi posíbel aceptar a solicitude de pertenza",
    "Accept membership request" : "Aceptar a solicitude de pertenza",
    "Reject membership request" : "Rexeitar a solicitude de pertenza",
    "Manage level" : "Xestionar o nivel",
    "Remove member" : "Retirar membro",
    "Unable to get the results" : "Non é posíbel obter os resultados",
    "Some members could not be added" : "Non foi posíbel engadir algúns membros",
    "There was an issue adding members to the team" : "Produciuse un problema ao engadir membros ao equipo",
    "Loading members list …" : "Cargando a lista de membros…",
    "The list of members is only visible to members of this team" : "A lista de membros só é visíbel para os membros deste equipo",
    "You currently have no access to the member list" : "Agora non ten acceso á lista de membros",
    "Add to {team}" : "Engadir a {team}",
    "Invite members to {team}" : "Convidar a membros a {team}",
    "Pending" : "Pendentes",
    "Select chart …" : "Seleccionar o gráfico…",
    "Chart" : "Gráfico",
    "Select Date" : "Seleccione a data",
    "Select type" : "Seleccione o tipo",
    "Add contact in group" : "Engadir contacto en grupo",
    "None" : "Ningún",
    "copy" : "copia",
    "Select option" : "Seleccione a opción",
    "Notes" : "Notas",
    "send an email" : "enviar un correo",
    "Personal dates" : "Datas persoais",
    "Add property of this type" : "Engada unha propiedade deste tipo",
    "Member" : "Membro",
    "This is a read-only group managed by administrators. Group members can only view this group." : "Este é un grupo de só lectura xestionado pola administración. Só os membros poden ver este grupo.",
    "Unable to create the contact." : "Non é posíbel crear o contacto.",
    "Contact not found" : "Non se atopou o contacto",
    "Group {group} not found" : "Non se atopou o grupo {group}",
    "Add member" : "Engadir membro",
    "New contact" : "Novo contacto",
    "_{success} contact added to {name}_::_{success} contacts added to {name}_" : ["Engadiuse {success} contacto a {name}","Engadironse {success} contactos a {name}"],
    "_Adding {success} contact to {name}_::_Adding {success} contacts to {name}_" : ["Engadindo {success} contacto a {name}","Engadindo {success} contactos a {name}"],
    "_{count} error_::_{count} errors_" : ["{count} erro","{count} erros"],
    "_Importing %n contact into {addressbook}_::_Importing %n contacts into {addressbook}_" : ["Importando %n contacto en {addressbook}","Importando %n contactos en {addressbook}"],
    "_Done importing %n contact into {addressbook}_::_Done importing %n contacts into {addressbook}_" : ["Finalizada a importación de %n contacto en {addressbook}","Finalizada a importación de %n contactos en {addressbook}"],
    "No data for this contact" : "Non hai datos para este contacto",
    "No data for this contact on their profile" : "Non hai datos para este contacto no seu perfil",
    "Import" : "Importar",
    "Are you sure you want to import this contact file?" : "Confirma que quere importar este ficheiro de contacto?",
    "Could not copy" : "Non foi posíbel copiar",
    "Join team" : "Únase ao equipo",
    "You are about to leave {circle}.\nAre you sure?" : "Está a piques de abandonar {circle}.\nConfirma que quere facelo?",
    "Please confirm team leave" : "Confirme que quere abandonar o equipo",
    "Could not leave the team {displayName}" : "Non foi posíbel abandonar o equipo {displayName}",
    "Unable to join the team" : "Non é posíbel unirse ao equipo",
    "You are about to delete {circle}.\nAre you sure?" : "Está a piques de eliminar {circle}.\nConfirma que quere facelo?",
    "Please confirm team deletion" : "Confirme a eliminación do equipo",
    "Unable to delete the team" : "Non é posíbel eliminar o equipo",
    "Confirm enabling federation" : "Confirmar a activación da federación",
    "Enabling this will prevent {circle} from being a member of other teams.\nAre you sure?" : "Activar isto impedirá que {circle} sexa membro doutros equipos.\nEstá seguro?",
    "Enable federation" : "Activar a federación",
    "Link copied to the clipboard" : "A ligazón foi copiada no portapapeis",
    "Could not copy link to the clipboard." : "Non foi posíbel copiar a ligazón no portapapeis.",
    "Not grouped" : "Sen agrupar",
    "Organization chart" : "Organigrama",
    "Team" : "Equipo",
    "User" : "Usuario",
    "Group" : "Grupo",
    "Email" : "Correo",
    "Contact" : "Contacto",
    "Moderator" : "Moderador",
    "Admin" : "Administración",
    "Owner" : "Propietario",
    "Invites" : "Convites",
    "Anyone can request membership" : "Calquera persoa pode solicitar a pertenza",
    "Members need to accept invitation" : "Os membros deben aceptar o convite",
    "Memberships must be confirmed/accepted by a Moderator (requires \"Anyone can request membership\")" : "As pertenzas deben ser confirmadas/aceptadas por un moderador (precisa «Calquera persoa pode solicitar a pertenza»)",
    "Members can also invite" : "Os membros tamén poden convidar",
    "Membership" : "Pertenza",
    "Prevent teams from being a member of another team" : "Impedir que o equipo sexa membro doutro equipo",
    "Federation" : "Federación",
    "Allow federated members" : "Permitir os membros federados",
    "Privacy" : "Privacidade",
    "Visible to everyone" : "Visíbel para todos",
    "users" : "usuarios",
    "Users" : "Usuarios",
    "groups" : "grupos",
    "federated users" : "usuarios federados",
    "Federated users" : "Usuarios federados",
    "teams" : "equipos",
    "email addresses" : "enderezos de correo",
    "Email addresses" : "Enderezos de correo",
    "contacts" : "contactos",
    "Detailed name" : "Nome completo",
    "Additional names" : "Nomes adicionais",
    "Prefix" : "Prefixo",
    "Suffix" : "Sufixo",
    "Nickname" : "Alcume",
    "Website" : "Sitio web",
    "Location" : "Localización",
    "Federated Cloud ID" : "ID de nube federada",
    "Home" : "Particular",
    "Work" : "Traballo",
    "Other" : "Outro",
    "Address" : "Enderezo",
    "Post office box" : "Apartado de correos",
    "Extended address" : "Enderezo estendido",
    "City" : "Cidade",
    "State or province" : "Provincia ou estado",
    "Postal code" : "Código postal",
    "Country" : "País",
    "Birthday" : "Aniversario (nacemento)",
    "Place of birth" : "Lugar de nacemento",
    "Anniversary" : "Aniversario (casamento)",
    "Date of death" : "Data do pasamento",
    "Place of death" : "Lugar do pasamento",
    "Instant messaging" : "Mensaxería instantánea",
    "Phone" : "Teléfono",
    "Mobile" : "Móbil",
    "Work mobile" : "Teléfono móbil do traballo",
    "Home mobile" : "Teléfono móbil particular",
    "Fax" : "Fax",
    "Fax home" : "Fax particular",
    "Fax work" : "Fax do traballo",
    "Pager" : "Buscapersoas",
    "Voice" : "Voz",
    "Car" : "Coche",
    "Work pager" : "Buscapersoas do traballo",
    "Line manager" : "Superior inmediato",
    "Social network" : "Rede social",
    "Relationship to you" : "Relación con Vde.",
    "Spouse" : "Muller",
    "Child" : "Fillo/a",
    "Mother" : "Nai",
    "Father" : "Pai",
    "Parent" : "Parente",
    "Brother" : "Irmán",
    "Sister" : "Irmá",
    "Relative" : "Achegado/a",
    "Friend" : "Amigo/a",
    "Colleague" : "Colega",
    "Assistant" : "Asistente",
    "Related contacts" : "Contactos relacionados",
    "Agent" : "Axente",
    "Emergency" : "Emerxencia",
    "Co-worker" : "Compañeiro de traballo",
    "Gender" : "Xénero",
    "Female" : "Muller",
    "Male" : "Home",
    "Unknown" : "Descoñecido",
    "Time zone" : "Fuso horario:",
    "Spoken languages" : "Idiomas falados",
    "_{failed} contact failed to be read_::_{failed} contacts failed to be read_" : ["Produciuse un fallo ao ler {failed} contacto","Produciuse un fallo ao ler {failed} contactos"],
    "An error has occurred in team(s). Check the console for more details." : "Produciuse un erro no(s) equipo(s). Consulta a consola para obter máis detalles.",
    "Unable to create team {circleName}" : "Non é posíbel crear o equipo {circleName}",
    "Unable to delete team {circleId}" : "Non é posíbel eliminar o equipo {circleId}",
    "Unable to delete contact" : "Non é posíbel eliminar o contacto",
    "Value copied to the clipboard" : "O valor foi copiado no portapapeis",
    "Could not copy value to the clipboard." : "Non foi posíbel copiar o valor no portapapeis.",
    "note" : "nota",
    "email" : "correo"
},
"nplurals=2; plural=(n != 1);");
