OC.L10N.register(
    "contacts",
    {
    "Import contacts" : "Importar contautos",
    "Details" : "Detalles",
    "All contacts" : "Tolos contautos",
    "Contacts" : "Contautos",
    "Omit year" : "Omitir l'añu",
    "There was an error fetching the member list" : "Hebo un error al dir en cata de la llista de miembros",
    "Loading team…" : "Cargando l'equipu…",
    "There are no contacts yet" : "Nun hai nengún contautu",
    "Create contact" : "Crear un contautu",
    "There are no contacts in this group" : "Nun hai nengún contautu nesti grupu",
    "Create contacts" : "Crear contautos",
    "Add contacts" : "Amestar contautos",
    "Leave team" : "Colar del equipu",
    "Delete team" : "Desaniciar l'equipu",
    "Contacts settings" : "Configuración de Contautos",
    "Address books" : "Llibretes de direiciones",
    "Rename" : "Renomar",
    "Export" : "Esportar",
    "Delete" : "Desaniciar",
    "Show all groups" : "Amosar tolos grupos",
    "Collapse groups" : "Contrayer los grupos",
    "Show all teams" : "Amosar tolos equipos",
    "Collapse teams" : "Contrayer tolos equipos",
    "This group already exists" : "Esti grupu yá esiste",
    "This team already exists" : "Esti equipu yá esiste",
    "An error happened during the creation of the team" : "Prodúxose un error demientres la creación del equipu",
    "Contact groups" : "Grupos de contautos",
    "Teams" : "Equipos",
    "Create a new team" : "Crear un equipu",
    "Copied" : "Copióse",
    "Cannot copy" : "Nun se pue copiar",
    "Copy link" : "Copiar l'enllaz",
    "Delete {addressbook}?" : "¿Quies desaniciar «{addressbook}»?",
    "Unshare {addressbook}?" : "¿Quies dexar de compartir «{addressbook}»?",
    "Deletion of address book was not successful." : "El desaniciu de la llibreta de direiciones nun foi correutu.",
    "Renaming of address book was not successful." : "El renomáu de la llibreta de direiciones nun foi correutu.",
    "Download" : "Baxar",
    "Show" : "Amosar",
    "_%n contact_::_%n contacts_" : ["%n contautu","%n contautos"],
    "_%n group_::_%n groups_" : ["%n grupu","%n grupos"],
    "Unable to delete the share" : "Nun ye posible desaniciar l'elementu compartíu",
    "Unable to change permissions" : "Nun ye posible camudar los permisos",
    "An error occurred, unable to create the address book" : "Prodúxose un error, nun ye posible crear la llibreta de direiciones",
    "Cancel" : "Encaboxar",
    "Add" : "Add",
    "First name" : "Nome",
    "Last name" : "Apellíos",
    "Phonetic first name" : "Nome fonéticu",
    "Phonetic last name" : "Apellíos fonéticos",
    "Display name" : "Nome visible",
    "An error happened during the config change" : "Prodúxose un error demientres el cambéu de la configuración",
    "Save" : "Guardar",
    "Failed to save password. Please try again later." : "Nun se pue guardar la contraseña. Volvi tentalo dempués.",
    "Close" : "Zarrar",
    "There is no description for this team" : "Nun hai nenguna descripción pa esti equipu",
    "Enter a description for the team" : "Introduz una descripción pal equipu",
    "Folder" : "Folder",
    "Conversation name" : "Nome de la conversación",
    "Team name" : "Nome del equipu",
    "Delete picture" : "Desaniciar la semeya",
    "Edit" : "Editar",
    "Members" : "Miiembros",
    "Confirm" : "Confirmar",
    "Add more info" : "Amestar más información",
    "More fields" : "Más campos",
    "Please select a valid format" : "Seleiciona un formatu válidu",
    "Invalid image" : "La imaxe ye inválida",
    "Pick an avatar" : "Escoyer un avatar",
    "Error while processing the picture." : "Hebo un error mentanto se procesaba la semeya",
    "Avatar already up to date" : "L'avatar yá ta anováu",
    "Avatar download failed" : "La descarga del avatar falló",
    "Upload a new picture" : "Xubir una semeya nueva",
    "Choose from Files" : "Escoyer de Ficheros",
    "Download picture" : "Baxar la semeya",
    "Address book" : "Llibreta de direiciones",
    "{title} at {organization}" : "{title} en: {organization}",
    "Name" : "Nome",
    "Unable to retrieve the contact from the server, please check your network connection." : "Nun ye posible recuperar el contautu del sirividor. Comprueba la conexón a la rede.",
    "An error occurred while trying to move the contact" : "Prodúxose un error al tentar de mover el contautu",
    "An error occurred while trying to copy the contact" : "Prodúxose un error al tentar de copiar el contautu",
    "Unable to update contact" : "Nun ye posible anovar el contautu",
    "No contact selected" : "Nun se seleicionó nengún contautu",
    "Title" : "Títulu",
    "Company" : "Compaña",
    "View profile" : "Ver el perfil",
    "Clone contact" : "Clonar el contautu",
    "Generate QR Code" : "Xenerar un códigu QR",
    "Move" : "Mover",
    "Personal team" : "Equipu personal",
    "Local team" : "Equipu llocal",
    "Unable to get the results" : "Nun ye posible consiguir los resultaos",
    "There was an issue adding members to the team" : "Hebo un problema al amestar los miembros al equipu",
    "Pending" : "Pendiente",
    "Notes" : "Notes",
    "Member" : "Miembru",
    "Unable to create the contact." : "Nun ye posible crear el contautu.",
    "Add member" : "Amestar un miembru",
    "New contact" : "Contautu nuevu",
    "_{count} error_::_{count} errors_" : ["{count} error","{count} errores"],
    "Unable to join the team" : "Nun ye posible xunise al equipu",
    "Unable to delete the team" : "Nun ye posible desaniciar l'equipu",
    "Link copied to the clipboard" : "L'enllaz copióse nel cartafueyu",
    "Not grouped" : "Ensin grupu",
    "Team" : "Equipu",
    "User" : "Usuariu",
    "Group" : "Grupu",
    "Email" : "Corréu electrónicu",
    "Contact" : "Contautu",
    "Moderator" : "Moderador",
    "Admin" : "Alministrador",
    "Owner" : "Propietariu",
    "Invites" : "Convidáu",
    "Members need to accept invitation" : "Los miembros precisen aceptar la invitación",
    "Members can also invite" : "Los miembros tamién puen convidar",
    "Privacy" : "Privacidá",
    "Users" : "Usuarios",
    "Prefix" : "Prefixu",
    "Suffix" : "Sufixu",
    "Nickname" : "Nomatu",
    "Website" : "Sitiu web",
    "Location" : "Llocalización",
    "Home" : "Aniciu",
    "Post office box" : "Oficina de Correos",
    "City" : "Ciudá",
    "State or province" : "Estáu o provincia",
    "Postal code" : "Códigu postal",
    "Country" : "País",
    "Instant messaging" : "Mensaxería instantanea",
    "Fax" : "Fax",
    "Pager" : "Buscapersones",
    "Spouse" : "Esposa",
    "Mother" : "Ma",
    "Father" : "Pá",
    "Parent" : "Pá",
    "Brother" : "Hermanu",
    "Sister" : "Hermana",
    "Assistant" : "Asistente",
    "Agent" : "Axente",
    "Gender" : "Xéneru",
    "Female" : "Femenín",
    "Male" : "Masculín",
    "Time zone" : "Fusu horariu",
    "Spoken languages" : "Llingües falaes",
    "Unable to create team {circleName}" : "Nun ye posible crear l'equipu «{circleName}»",
    "Unable to delete team {circleId}" : "Nun ye posible crear l'equipu «{circled}»",
    "Unable to delete contact" : "Nun ye posible desaniciar el contautu"
},
"nplurals=2; plural=(n != 1);");
