OC.L10N.register(
    "contacts",
    {
    "Import contacts" : "درون‌ریزی آشنایان",
    "Details" : "جزئیات",
    "All contacts" : "تمام مخاطبین",
    "Contacts" : "مخاطبین",
    "A contacts app for Nextcloud" : "کارهٔ آشنایانی برای نکست‌کلود",
    "The Nextcloud contacts app is a user interface for Nextcloud's CardDAV server. Easily sync contacts from various devices with your Nextcloud and edit them online.\n\n* 🚀 **Integration with other Nextcloud apps!** Currently Mail and Calendar – more to come.\n* 🎉 **Never forget a birthday!** You can sync birthdays and other recurring events with your Nextcloud Calendar.\n* 👥 **Sharing of Adressbooks!** You want to share your contacts with your friends or coworkers? No problem!\n* 🙈 **We’re not reinventing the wheel!** Based on the great and open SabreDAV library." : "برنامه Nextcloud Contacts یک رابط کاربری برای سرور CardDAV Nextcloud است. به راحتی مخاطبین دستگاه های مختلف را با Nextcloud خود همگام کنید و آنها را به صورت آنلاین ویرایش کنید.\n\n* 🚀 **ادغام با سایر برنامه های Nextcloud!** در حال حاضر Mail و Calendar - موارد بیشتری در راه است.\n* 🎉 **هرگز تولد را فراموش نکنید!** می توانید تولدها و سایر رویدادهای تکرار شونده را با تقویم Nextcloud خود همگام کنید.\n* 👥 **اشتراک گذاری دفترچه آدرس!** می خواهید مخاطبین خود را با دوستان یا همکاران خود به اشتراک بگذارید؟ مشکلی نیست!\n* 🙈 **ما چرخ را دوباره اختراع نمی کنیم!** بر اساس کتابخانه بزرگ و باز SabreDAV.",
    "Copy to full name" : "رونوشت در نام کامل",
    "Omit year" : "در نظر نگرفتن سال",
    "Allow updating avatars from social media" : "اجازهٔ به‌روز رسانی چهرک‌ها از رسانهٔ اجتماعی",
    "There was an error fetching the member list" : "خطایی در واکشی سیاههٔ اعضا رخ داد",
    "There are no contacts yet" : "هنوز هیچ آشنایی وجود ندارد",
    "Create contact" : "ایجاد آشما",
    "There are no contacts in this group" : "هیچ آشنایی در این گروه وجود ندارد",
    "Create contacts" : "ایجاد آشنایان",
    "Add contacts" : "افزودن آشنایان",
    "Contacts settings" : "تنظمیات آشنایان",
    "Update avatars from social media" : "به‌روز رسانی چهرک‌ها از رسانهٔ اجتماعی",
    "Address books" : "Address books",
    "Rename" : "تغییرنام",
    "Export" : "برون‌ریزی",
    "Send email" : "فرستادن رایانامه",
    "Send email as BCC" : "فرستادن رایانامه به صورت BCC",
    "Delete" : "حذف",
    "Show all groups" : "نمایش تمامی گروه‌ها",
    "Collapse groups" : "جمع کردن گروه ها",
    "This group already exists" : "این گروه از پیش وجود دارد",
    "Recently contacted" : "تازه تماس گرفته",
    "Contact groups" : "گروه‌های آشنایان",
    "Create a new contact group" : "ایجاد یک گروه آشنای جدید",
    "Contact group name" : "نام گروه آشنا",
    "_Shared with {num} entity_::_Shared with {num} entities_" : ["هم‌رسانده با {num} موجودیت","هم‌رسانده با {num} موجودیت"],
    "Copied" : "رونوشت شد",
    "Cannot copy" : "نمی‌توان رونوشت مرد",
    "Copy link" : "کپی کردن لینک",
    "Toggling of address book was not successful" : "Toggling of address book was not successful",
    "This will delete the address book and every contacts within it" : "This will delete the address book and every contacts within it",
    "Delete {addressbook}?" : "حذف {addressbook}؟",
    "Deletion of address book was not successful." : "Deletion of address book was not successful.",
    "Renaming of address book was not successful." : "Renaming of address book was not successful.",
    "Download" : "دانلود",
    "Show" : "نمایش",
    "_%n contact_::_%n contacts_" : ["%n آشنا","%n آشنا"],
    "_%n group_::_%n groups_" : ["%n گروه","%n گروه"],
    "Share with users or groups" : "اشتراک گذاری با کاربران یا گروه ها ...",
    "Share with users" : "هم‌رسانی با کاربران",
    "No users or groups" : "هیچ کاربر یا گروهی وجود ندارد",
    "Unable to delete the share" : "ناتوان در حذف هم‌رسانی",
    "Unable to change permissions" : "ناتوان در تغییر اجازه‌ها",
    "Choose a vCard file to import" : "گزینش یک vCard برای درون‌ریزی",
    "Import into the {addressbookName} address book" : "وارد کردن به دفترچه آدرس {addressbookName}",
    "Select local file" : "گزینش پروندهٔ محلی",
    "Import from files" : "وارد کردن از فایل ها",
    "Importing is disabled because there are no address books available" : "واردات غیرفعال است زیرا هیچ دفترچه آدرسی در دسترس نیست",
    "An error occurred, unable to create the address book" : "خطایی روی داد، دفترچه آدرس ایجاد نشد",
    "Add new address book" : "دفترچه آدرس جدید اضافه کنید",
    "Cancel" : "لغو",
    "Add" : "افزودن",
    "First name" : "نام",
    "Last name" : "نام‌خانوادگی",
    "Phonetic first name" : "نام آوایی",
    "Phonetic last name" : "نام‌خانوادگی آوایی",
    "Display name" : "نام نمایشی",
    "Last modified" : "آخرین اصلاح",
    "Manages" : "مدیریت می‌کند",
    "Oversees" : "نظارت می‌کند",
    "An error happened during the config change" : "An error happened during the config change",
    "Save" : "ذخیره",
    "Change unique password" : "تغییر گذرواژهٔ یکتا",
    "Failed to save password. Please try again later." : "رمز عبور ذخیره نشد. لطفاً بعداً دوباره امتحان کنید.",
    "Close" : "بستن",
    "Folder" : "Folder",
    "Delete picture" : "حذف نگاره",
    "Edit" : "ویرایش",
    "Request to join" : "Request to join",
    "Create" : "ایجاد شده",
    "You are not a member of {circle}" : "عضوی از {circle} نیستید",
    "Add more info" : "افزودن اطّلاعات بیش‌تر",
    "More fields" : "زمینه‌های بیش‌تر",
    "Please select a valid format" : "لطفاً قالبی معتبر برگزینید",
    "Invalid image" : "تصویر نامعتبر",
    "Error cropping picture" : "خطا در برش نگاره",
    "Pick an avatar" : "گزینش یک چهرک",
    "Error while processing the picture." : "Error while processing the picture.",
    "Avatar downloaded from social network" : "Avatar downloaded from social network",
    "Avatar already up to date" : "Avatar already up to date",
    "Avatar download failed" : "دانلود آواتار ناموفق بود",
    "Crop contact photo" : "برش عکس آشنا",
    "Upload a new picture" : "بارگذاری نگارهٔ جدید",
    "Choose from Files" : "گزینش از پرونده‌ها",
    "Download picture" : "بارگیری نگاره",
    "This contact is in read-only mode. You do not have permission to edit this contact." : "This contact is in read-only mode. You do not have permission to edit this contact.",
    "The contact you were trying to edit has changed. Please manually refresh the contact. Any further edits will be discarded." : "The contact you were trying to edit has changed. Please manually refresh the contact. Any further edits will be discarded.",
    "Address book" : "دفترچه نشانی",
    "Add contact to Birthday Calendar" : "Add contact to Birthday Calendar",
    "Exclude contact from Birthday Calendar" : "Exclude contact from Birthday Calendar",
    "{title} at {organization}" : "{title} در {organization}",
    "Name" : "نام",
    "Syntax error. Cannot open the contact." : "Syntax error. Cannot open the contact.",
    "The contact does not exist on the server anymore." : "The contact does not exist on the server anymore.",
    "Unable to retrieve the contact from the server, please check your network connection." : "Unable to retrieve the contact from the server, please check your network connection.",
    "An error occurred while trying to move the contact" : "An error occurred while trying to move the contact",
    "An error occurred while trying to copy the contact" : "An error occurred while trying to copy the contact",
    "Unable to update contact" : "Unable to update contact",
    "No contact selected" : "مخاطبی انتخاب نشده است",
    "Select a contact on the list to begin" : "برای شروع، یک مخاطب را در لیست انتخاب کنید",
    "Title" : "عنوان",
    "Company" : "شرکت",
    "Go to talk conversation" : "Go to talk conversation",
    "View profile" : "دیدن نمایه",
    "This contact was broken and received a fix. Please review the content and click here to save it." : "This contact was broken and received a fix. Please review the content and click here to save it.",
    "Edit profile" : "ویرایش نمایه",
    "Clone contact" : "Clone contact",
    "Generate QR Code" : "Generate QR Code",
    "Contact vCard as QR code" : "Contact vCard as QR code",
    "Pick an address book" : "Pick an address book",
    "Select address book" : "Select address book",
    "Move" : "Move",
    "Remove from favorites" : "حذف از برگزیده‌ها",
    "Add to favorites" : "اضافه کردن به برگزیده ها",
    "Add to {group}" : "افزودن به {group}",
    "Remove {type}" : "برداشتن {type}",
    "Add to group" : "افزودن به گروه",
    "Search {types}" : "جست‌وجوی {types}",
    "Search for people to add" : "جست‌وجوی افراد برای افزودن",
    "No results" : "بدون نتیجه",
    "Add {type}" : "افزودن {type}",
    "Promote as sole owner" : "Promote as sole owner",
    "Promote to {level}" : "Promote to {level}",
    "Demote to {level}" : "Demote to {level}",
    "Could not delete the member {displayName}" : "Could not delete the member {displayName}",
    "Could not change the member level to {level}" : "Could not change the member level to {level}",
    "Could not accept membership request" : "Could not accept membership request",
    "Accept membership request" : "پذیرش درخواست عضویت",
    "Reject membership request" : "Reject membership request",
    "Manage level" : "Manage level",
    "Remove member" : "برداشتن عضو",
    "Unable to get the results" : "قادر به دریافت نتایج نیست",
    "Some members could not be added" : "برخی از اعضا نمی توانند اضافه شوند",
    "You currently have no access to the member list" : "You currently have no access to the member list",
    "Pending" : "منتظر",
    "Chart" : "نمودار",
    "Select Date" : "گزینش تاریخ",
    "Select type" : "گزینش گونه",
    "Add contact in group" : "افزودن آشنا به گروه",
    "None" : "هیچ‌کدام",
    "Select option" : "گزینش گزینه",
    "Notes" : "یادداشت ها",
    "Add property of this type" : "افزودن ویژگی این گونه",
    "Member" : "عضو",
    "Unable to create the contact." : "ناتوان در ایجاد آشنا.",
    "Contact not found" : "آشنا پیدا نشد",
    "Group {group} not found" : "گروه {group} پیدا نشد",
    "Add member" : "افزودن عضو",
    "New contact" : "مخاطب جدید",
    "_{success} contact added to {name}_::_{success} contacts added to {name}_" : ["{success} contact added to {name}","{success} contacts added to {name}"],
    "_Adding {success} contact to {name}_::_Adding {success} contacts to {name}_" : ["Adding {success} contact to {name}","افزودن مخاطبین {success} به {name}"],
    "_{count} error_::_{count} errors_" : ["{count} خطا","{count} خطا"],
    "_Importing %n contact into {addressbook}_::_Importing %n contacts into {addressbook}_" : ["Importing %n contact into {addressbook}","وارد کردن مخاطبین به {addressbook}"],
    "_Done importing %n contact into {addressbook}_::_Done importing %n contacts into {addressbook}_" : ["Done importing %n contact into {addressbook}","وارد کردن مخاطبین به {addressbook} انجام شد"],
    "Import" : "درون‌ریزی",
    "Could not copy" : "نتوانست رونوشت کند",
    "You are about to leave {circle}.\nAre you sure?" : "شما در شرف خروج از {circle} هستید.\nمطمئن هستید ؟",
    "You are about to delete {circle}.\nAre you sure?" : "شما در شرف حذف {circle} هستید.\nمطمئن هستید؟",
    "Link copied to the clipboard" : "پیوند در تخته‌گیره رونوشت شد",
    "Could not copy link to the clipboard." : "پیوند در کلیپ بورد کپی نشد.",
    "Not grouped" : "گروه نشده",
    "Organization chart" : "نمودار سازمانی",
    "User" : "کاربر",
    "Group" : "گروه",
    "Email" : "پست الکترونیکی",
    "Contact" : "آشنا",
    "Moderator" : "ناظم",
    "Admin" : "مدیر",
    "Owner" : "مالک",
    "Invites" : "دعوت‌ها",
    "Anyone can request membership" : "هر کسی می تواند درخواست عضویت کند",
    "Members need to accept invitation" : "اعضا باید دعوت را بپذیرند",
    "Members can also invite" : "اعضا نیز می توانند دعوت کنند",
    "Privacy" : "حریم خصوصی",
    "Visible to everyone" : "برای همه قابل مشاهده است",
    "Users" : "Users",
    "Email addresses" : "نشانی‌های رایانامه",
    "Detailed name" : "نام کامل",
    "Additional names" : "نام های دیگر",
    "Prefix" : "پیشوند",
    "Suffix" : "پسوند",
    "Nickname" : "نام مستعار",
    "Website" : "وب‌سایت",
    "Location" : "مکان",
    "Federated Cloud ID" : "Federated Cloud شناسه",
    "Home" : "خانه",
    "Work" : "کار",
    "Other" : "دیگر",
    "Address" : "آدرس",
    "Post office box" : "صندوق پستی محل کار",
    "Extended address" : "نشانی‌های گسترده",
    "City" : "شهر",
    "State or province" : "استان",
    "Postal code" : "کد پستی",
    "Country" : "کشور",
    "Birthday" : "روزتولد",
    "Place of birth" : "محل تولد",
    "Anniversary" : "سالگرد",
    "Date of death" : "تاریخ فوت",
    "Instant messaging" : "پیام رسانی فوری",
    "Phone" : "شماره تلفن",
    "Mobile" : "موبایل",
    "Work mobile" : "همراه کاری",
    "Home mobile" : "همراه خانگی",
    "Fax" : "دورنگار:",
    "Fax home" : "دورنگار منزل",
    "Fax work" : "دورنگار محل کار",
    "Pager" : "صفحه",
    "Voice" : "صدا",
    "Car" : "خودرو",
    "Work pager" : "پی‌چوی کاری",
    "Social network" : "شبکه اجتماعی",
    "Relationship to you" : "رابطه با شما",
    "Spouse" : "همسر",
    "Child" : "فرزند",
    "Mother" : "مادر",
    "Father" : "پدر",
    "Parent" : "والدین",
    "Brother" : "برادر",
    "Sister" : "خواهر",
    "Relative" : "مرتبط",
    "Friend" : "دوست",
    "Colleague" : "کالج",
    "Assistant" : "راهنما",
    "Related contacts" : "آشنایان مرتبط",
    "Agent" : "عامل",
    "Emergency" : "اضطراری",
    "Co-worker" : "همکار",
    "Gender" : "جنسیت",
    "Female" : "مؤنث",
    "Male" : "مذکر",
    "Unknown" : "نامعلوم",
    "Time zone" : "منطقهٔ زمانی",
    "Spoken languages" : "زبان‌های صحبت",
    "_{failed} contact failed to be read_::_{failed} contacts failed to be read_" : ["{failed} contact failed to be read","{failed} contacts failed to be read"],
    "Unable to delete contact" : "Unable to delete contact"
},
"nplurals=2; plural=(n > 1);");
