OC.L10N.register(
    "contacts",
    {
    "Import contacts" : "Kontakte importieren",
    "Details" : "Details",
    "All contacts" : "Alle Kontakte",
    "_Imported %n contact_::_Imported %n contacts_" : ["%n Kontakt importiert","%n Kontakte importiert"],
    "_(skipped %n contact)_::_(skipped %n contacts)_" : ["(%n Kontakt übersprungen)","(%n Kontakte übersprungen)"],
    "Contacts" : "Kontakte",
    "A contacts app for Nextcloud" : "Eine Adressbuch-App für Nextcloud",
    "The Nextcloud contacts app is a user interface for Nextcloud's CardDAV server. Easily sync contacts from various devices with your Nextcloud and edit them online.\n\n* 🚀 **Integration with other Nextcloud apps!** Currently Mail and Calendar – more to come.\n* 🎉 **Never forget a birthday!** You can sync birthdays and other recurring events with your Nextcloud Calendar.\n* 👥 **Sharing of Adressbooks!** You want to share your contacts with your friends or coworkers? No problem!\n* 🙈 **We’re not reinventing the wheel!** Based on the great and open SabreDAV library." : "Die Nextcloud-Kontakte-App ist eine Benutzeroberfläche für den CardDAV-Server von Nextcloud. Synchronisieren Sie Kontakte von verschiedenen Geräten mit Ihrer Nextcloud und bearbeiten Sie diese online.\n* 🚀 ** Integration mit anderen Nextcloud-Apps! Aktuell Mail und Kalender  – weitere sind in Planung.\n* 🎉 **Niemals einen Geburtstag vergessen!** Sie können Geburtstage und andere wiederkehrende Ereignisse mit Ihrem Nextcloud-Kalender synchronisieren.\n* 👥 **Teilen von Adressbüchern!** Sie möchten Ihre Kontakte mit Ihren Freunden oder Kollegen teilen? Kein Problem!\n* 🙈 **Wir erfinden das Rad nicht neu!** Basierend auf der großartigen und offenen SabreDAV-Bibliothek.",
    "Copy to full name" : "In vollständigen Namen kopieren",
    "Omit year" : "Jahr weglassen",
    "Allow updating avatars from social media" : "Die Aktualisierung von Avataren aus sozialen Medien erlauben",
    "There was an error fetching the member list" : "Fehler beim Laden der Mitgliederliste",
    "Please select a team" : "Bitte ein Team auswählen",
    "Loading team…" : "Lade Team…",
    "Loading contacts …" : "Lade Kontakte …",
    "There are no contacts yet" : "Es gibt noch keine Kontakte",
    "Create contact" : "Kontakt erstellen",
    "There are no contacts in this group" : "In dieser Gruppe befinden sich keine Kontakte",
    "Create contacts" : "Kontakte erstellen",
    "Add contacts" : "Kontakte hinzufügen",
    "Loading …" : "Lade …",
    "Manage team" : "Team verwalten",
    "Leave team" : "Team verlassen",
    "Delete team" : "Team löschen",
    "Setting saved" : "Einstellung gespeichert",
    "Failed to save setting" : "Einstellung konnte nicht gespeichert werden",
    "Contacts settings" : "Kontakte-Einstellungen",
    "General" : "Allgemein",
    "Update avatars from social media" : "Avatare aus sozialen Medien aktualisieren",
    "Refreshed once per week" : "Einmal wöchentlich aktualisiert",
    "Address books" : "Adressbücher",
    "Tried to drop an invalid contact!" : "Es wurde versucht, einen ungültigen Kontakt zu löschen!",
    "Rename" : "Umbenennen",
    "Export" : "Exportieren",
    "Send email" : "E-Mail senden",
    "Send email as BCC" : "E-Mail als BCC senden",
    "Delete" : "Löschen",
    "Show all groups" : "Alle Gruppen anzeigen",
    "Collapse groups" : "Gruppen einklappen",
    "Show all teams" : "Alle Teams anzeigen",
    "Collapse teams" : "Teams einklappen",
    "Group name cannot be empty" : "Gruppenname darf nicht leer sein",
    "This group already exists" : "Diese Gruppe existiert bereits",
    "An error occurred while creating the group" : "Es ist ein Fehler beim Erstellen der Gruppe aufgetreten",
    "This team already exists" : "Dieses Team existiert bereits",
    "An error happened during the creation of the team" : "Es ist ein Fehler beim Erstellen des Teams aufgetreten.",
    "Recently contacted" : "Zuletzt kontaktiert",
    "Contact groups" : "Kontaktgruppen",
    "Create a new contact group" : "Neue Kontaktgruppe erstellen",
    "Contact group name" : "Name der Kontaktgruppe",
    "Teams" : "Teams",
    "Create a new team" : "Ein neues Team erstellen",
    "Open the contacts app settings" : "Einstellungen der Kontakte-App öffnen",
    "_Shared with {num} entity_::_Shared with {num} entities_" : ["Für {num} Entität freigegeben","Für {num} Entitäten freigegeben"],
    "Copied" : "Kopiert",
    "Cannot copy" : "Kopieren nicht möglich",
    "Copy link" : "Link kopieren",
    "Toggling of address book was not successful" : "Das Umschalten des Adressbuches war nicht erfolgreich.",
    "This will delete the address book and every contacts within it" : "Hierdurch wird das Adressbuch und alle Kontakte in ihm gelöscht",
    "Delete {addressbook}?" : " {addressbook} löschen?",
    "This will unshare the address book and every contacts within it" : "Hierdurch wird das Adressbuch und alle enthaltenen Kontakte nicht mehr geteilt",
    "Unshare {addressbook}?" : "{addressbook} nicht mehr teilen?",
    "Deletion of address book was not successful." : "Das Löschen des Adressbuches war nicht erfolgreich.",
    "Renaming of address book was not successful." : "Das Umbenennen des Adressbuches war nicht erfolgreich.",
    "{addressbookname} (Hidden)" : "{addressbookname} (versteckt)",
    "Download" : "Herunterladen",
    "Show" : "Anzeigen",
    "Unshare from me" : "Nicht mehr mit mir teilen",
    "_%n contact_::_%n contacts_" : ["%n Kontakt","%n Kontakte"],
    "_%n group_::_%n groups_" : ["%n Gruppe","%n Gruppen"],
    "Share with users or groups" : "Mit Benutzern oder Gruppen teilen",
    "Share with users" : "Mit Benutzern teilen",
    "No users or groups" : "Keine Benutzer oder Gruppen",
    "Unable to delete the share" : "Freigabe kann nicht gelöscht werden",
    "Unable to change permissions" : "Berechtigungen können nicht geändert werden.",
    "can create and edit" : "Kann erstellen und bearbeiten",
    "Choose a vCard file to import" : "Wählen Sie eine vCard zum Importieren",
    "Import into the {addressbookName} address book" : "In Adressbuch {addressbookName} importieren",
    "Select local file" : "Lokale Datei auswählen",
    "Import from files" : "Aus Dateien importieren",
    "Importing is disabled because there are no address books available" : "Der Import ist deaktiviert, da kein Adressbuch verfügbar ist",
    "An error occurred, unable to create the address book" : "Es ist ein Fehler aufgetreten, das Adressbuch konnte nicht erstellt werden.",
    "New address book" : "Neues Adressbuch",
    "Add new address book" : "Neues Adressbuch hinzufügen",
    "Cancel" : "Abbrechen",
    "Add" : "Hinzufügen",
    "First name" : "Vorname",
    "Last name" : "Nachname",
    "Phonetic first name" : "Phonetischer Vorname",
    "Phonetic last name" : "Phonetischer Nachname",
    "Display name" : "Anzeigename",
    "Last modified" : "Zuletzt geändert",
    "Sort contacts by" : "Kontakte sortieren nach",
    "Manages" : "Verwaltet",
    "Oversees" : "Überschaut",
    "An error happened during the config change" : "Bei der Konfigurationsänderung ist ein Fehler aufgetreten",
    "Enforce password protection on files shared to this team" : "Passwortschutz für Dateien erzwingen, die mit diesem Team geteilt werden",
    "Use a unique password for all shares to this team" : "Ein eindeutiges Passwort für alle Freigaben mit diesem Team verwenden",
    "Unique password …" : "Einzigartiges Passwort …",
    "Save" : "Speichern",
    "Change unique password" : "Eindeutiges Passwort ändern",
    "Failed to save password. Please try again later." : "Das Passwort konnte nicht gespeichert werden. Bitte versuchen Sie es später erneut.",
    "Close" : "Schließen",
    "Choose a team picture" : "Ein Teambild auswählen",
    "There is no description for this team" : "Es existiert keine Beschreibung für dieses Team",
    "Enter a description for the team" : "Beschreibung für das Team eingeben",
    "Folder" : "Ordner",
    "New folder" : "Neuer Ordner",
    "Folder name" : "Ordnername",
    "This will create a regular folder shared with the team. To create a Team Folder, please contact your {productName} administrator" : "Dadurch wird ein regulärer Ordner erstellt, der mit dem Team geteilt wird. Um einen Team-Ordner zu erstellen, bitte die {productName}-Administration kontaktieren",
    "Talk conversation" : "Talk-Unterhaltung",
    "New Talk conversation" : "Neue Talk-Unterhaltung",
    "Conversation name" : "Name der Unterhaltung",
    "Collective" : "Kollektive",
    "Calendar" : "Kalender",
    "New calendar" : "Neuer Kalender",
    "Calendar name" : "Kalendername",
    "Deck board" : "Deck-Board",
    "New Deck board" : "Neues Deck-Board",
    "Board name" : "Boardname",
    "Deck app is not installed. Please install it to create team boards." : "Die Deck-App ist nicht installiert. Bitte Deck installieren, um Team-Boards zu erstellen.",
    "Unknown resource type" : "Unbekannter Ressourcentyp",
    "Team calendar \"{resourceName}\" created and shared with team" : "Der Team-Kalender \"{resourceName}\" wurde erstellt und mit dem Team geteilt",
    "{resourceType} \"{resourceName}\" created and shared with team" : "{resourceType} \"{resourceName}\" erstellt und mit dem Team geteilt",
    "A calendar named \"{name}\" already exists. Please choose a different name." : "Ein Kalender mit dem Namen \"{name}\" existiert bereits. Bitte einen anderen Namen wählen.",
    "Failed to create {resourceType}: {error}" : "{resourceType} konnte nicht erstellt werden: {error} ",
    "Please select a valid png or jpg file" : "Bitte eine gültige PNG- oder JPG-Datei wählen",
    "Error picking team picture" : "Fehler bei der Auswahl des Teambildes",
    "Error cropping avatar picture" : "Fehler beim Zuschneiden des Avatarbildes",
    "An error happened while saving {fields}" : "Beim Speichern von {fields} ist ein Fehler aufgetreten",
    "Team name" : "Teamname",
    "Team owner" : "Team-Besitzer",
    "Upload team picture" : "Teambild hochladen",
    "Choose from Nextcloud Files" : "Aus Nextcloud Dateien wählen",
    "Delete picture" : "Bild löschen",
    "Edit" : "Bearbeiten",
    "Request to join" : "Beitritt anfragen",
    "Create" : "Erstellen",
    "Show in Calendar" : "Im Kalender anzeigen",
    "Your request to join this team is pending approval" : "Ihre Anfrage, diesem Team beizutreten, muss noch genehmigt werden",
    "You are not a member of {circle}" : "Sie sind kein Mitglied von {circle}",
    "Members" : "Mitglieder",
    "Edit team picture" : "Teambild bearbeiten",
    "Apply" : "Anwenden",
    "Confirm" : "Bestätigen",
    "Add more info" : "Weitere Informationen hinzufügen",
    "More fields" : "Weitere Felder",
    "Please select a valid format" : "Bitte ein gültiges Format wählen",
    "Invalid image" : "Ungültiges Bild",
    "Error cropping picture" : "Fehler beim Zuschneiden des Bildes",
    "Pick an avatar" : "Avatar auswählen",
    "Pick" : "Auswählen",
    "Error while processing the picture." : "Fehler beim Verarbeiten des Bildes.",
    "Avatar downloaded from social network" : "Avatar vom sozialen Netzwerk heruntergeladen",
    "Avatar already up to date" : "Avatar bereits auf dem neuesten Stand",
    "Avatar download failed" : "Avatar-Download fehlgeschlagen",
    "Crop contact photo" : "Kontaktfoto zuschneiden",
    "Upload a new picture" : "Neues Bild hochladen",
    "Choose from Files" : "Aus Dateien wählen",
    "Download picture" : "Bild herunterladen",
    "This contact is in read-only mode. You do not have permission to edit this contact." : "Dieser Kontakt ist schreibgeschützt. Sie haben keine Berechtigung, diesen Kontakt zu bearbeiten.",
    "The contact you were trying to edit has changed. Please manually refresh the contact. Any further edits will be discarded." : "Der Kontakt, den Sie versuchen zu bearbeiten, hat sich geändert. Bitte aktualisieren Sie den Kontakt manuell. Alle weiteren Änderungen werden verworfen.",
    "Address book" : "Adressbuch",
    "Add contact to Birthday Calendar" : "Kontakt zum Geburtstagskalender hinzufügen",
    "Exclude contact from Birthday Calendar" : "Kontakt vom Geburtstagskalender ausschließen",
    "{title} at {organization}" : "{title} bei {organization}",
    "Name" : "Name",
    "Syntax error. Cannot open the contact." : "Syntaxfehler. Der Kontakt kann nicht geöffnet werden.",
    "The contact does not exist on the server anymore." : "Der Kontakt existiert nicht mehr auf dem Server.",
    "Unable to retrieve the contact from the server, please check your network connection." : "Der Kontakt konnte nicht vom Server abgerufen werden, überprüfen Sie bitte Ihre Netzwerkverbindung.",
    "An error occurred while trying to move the contact" : "Es ist ein Fehler beim Verschieben des Kontakts aufgetreten",
    "An error occurred while trying to copy the contact" : "Es ist ein Fehler beim Kopieren des Kontakts aufgetreten",
    "Unable to update contact" : "Kontakt konnte nicht aktualisiert werden",
    "No contact selected" : "Kein Kontakt ausgewählt",
    "Select a contact on the list to begin" : "Wählen Sie einen Kontakt aus der Liste aus, um zu beginnen.",
    "Title" : "Titel",
    "Company" : "Firma",
    "Go to talk conversation" : "Zur Talk-Unterhaltung wechseln",
    "View profile" : "Profil ansehen",
    "This contact was broken and received a fix. Please review the content and click here to save it." : "Dieser Kontakt war defekt und wurde korrigiert. Bitte überprüfen Sie den Inhalt und klicken Sie hier, um ihn zu speichern.",
    "Edit profile" : "Profil bearbeiten",
    "Clone contact" : "Kontakt duplizieren",
    "Generate QR Code" : "QR-Code erzeugen",
    "Contact vCard as QR code" : "vCard des Kontakts als QR-Code",
    "Pick an address book" : "Ein Adressbuch auswählen",
    "Select address book" : "Adressbuch auswählen",
    "Media shares with you" : "Mit Ihnen geteilte Medien",
    "Talk conversations with you" : "Talk-Unterhaltungen mit Ihnen",
    "Calendar events with you" : "Kalendereinträge mit Ihnen",
    "Deck cards with you" : "Deck-Karten mit Ihnen",
    "No shared items with this contact" : "Keine geteilten Objekte mit diesem Kontakt",
    "This contact cannot be moved" : "Dieser Kontakt kann nicht verschoben werden",
    "This contact cannot be grouped" : "Dieser Kontakt kann nicht einer Gruppe zugeordnet werden",
    "Add contacts to groups" : "Kontakte zu Gruppen hinzufügen",
    "Move contacts to addressbook" : "Kontakte in ein Adressbuch verschieben",
    "Select groups" : "Gruppen auswählen",
    "Select addressbook" : "Adressbuch auswählen",
    "Selected contacts" : "Ausgewählte Kontakte",
    "Please note that only {count} of the {total} contacts can be added to a group" : "Bitte beachten, dass nur {count} der {total} Kontakte einer Gruppe zugeordnet werden können",
    "Please note that only {count} of the {total} contacts can be moved" : "Bitte beachten, dass nur {count} der {total} Kontakte verschoben werden können",
    "Move" : "Verschieben",
    "Could not update favorite status" : "Favoritenstatus konnte nicht aktualisiert werden",
    "from {addressbook}" : "aus {addressbook}",
    "Remove from favorites" : "Aus Favoriten entfernen",
    "Add to favorites" : "Zu den Favoriten hinzufügen",
    "Confirm merging contacts" : "Zusammenführen der Kontakte bestätigen",
    "The selected contacts have conflicting information. Choose which information to keep" : "Die ausgewählten Kontakte enthalten widersprüchliche Informationen. Bitte auswählen, welche Informationen behalten werden sollen",
    "Contacts can be merged" : "Kontakte können zusammengeführt werden",
    "Groups" : "Gruppen",
    "Select groups to add the merged contact to" : "Gruppen auswählen, denen die zusammengeführten Kontakte hinzugefügt werden sollen",
    "Merge contacts" : "Kontakte zusammenführen",
    "_Delete {number} contact_::_Delete {number} contacts_" : ["{number} Kontakt löschen","{number} Kontakte löschen"],
    "Please select at least one editable contact to delete" : "Bitte mindestens einen bearbeitbaren Kontakt zum Löschen auswählen",
    "Please select two editable contacts to merge" : "Bitte zwei bearbeitbare Kontakte zum Zusammenführen auswählen",
    "_Add {number} contact to group_::_Add {number} contacts to group_" : ["{number} Kontakt einer Gruppe hinzufügen","{number} Kontakte einer Gruppe hinzufügen"],
    "Please select at least one editable contact to add to a group" : "Bitte mindestens einen bearbeitbaren Kontakt zum Hinzufügen zu einer Gruppe auswählen",
    "_Move {number} contact to addressbook_::_Move {number} contacts to addressbook_" : ["{number} Kontakt in ein Adressbuch verschieben","{number} Kontakte in ein Adressbuch verschieben"],
    "Please select at least one editable contact to move to an addressbook" : "Bitte mindestens einen bearbeitbaren Kontakt zum Verschieben in ein Adressbuch auswählen",
    "Are you sure you want to proceed?" : "Möchten Sie fortfahren?",
    "Add contacts to group" : "Kontakte einer Gruppe hinzufügen",
    "Search contacts …" : "Suche Kontakte …",
    "Unselect {number}" : "{number} abwählen",
    "Add to {group}" : "Zur Gruppe {group} hinzufügen",
    "Add members to {group}" : "Mitglieder zu {group} hinzufügen",
    "Please note that you can only add contacts from writable address books to contact groups. Contacts from read-only address books, such as the system address book, cannot be added." : "Bitte beachten Sie, dass Sie nur Kontakte aus beschreibbaren Adressbüchern zu Kontaktgruppen hinzufügen können. Kontakte aus schreibgeschützten Adressbüchern, wie z. B. dem Systemadressbuch, können nicht hinzugefügt werden.",
    "Remove {type}" : "Entferne {type}",
    "Add to group" : "Zur Gruppe hinzufügen",
    "Add members to group" : "Mitglieder der Gruppe hinzufügen",
    "Search {types}" : "Suche {types}",
    "Add guest" : "Gast hinzufügen",
    "Search for people to add" : "Nach Personen zum Hinzufügen suchen",
    "No results" : "Keine Ergebnisse",
    "Add {type}" : "Hinzufügen von {type}",
    "New team name" : "Neuer Teamname",
    "Personal team" : "Persönliches Team",
    "This team will only be visible to you. Other members will not be able to see or use it." : "Dieses Team ist nur für Sie sichtbar. Andere Mitglieder können es nicht sehen oder verwenden.",
    "Local team" : "Lokales Team",
    "This team will not be shared with the other instances of the global scale" : "Dieses Team wird nicht mit den anderen Instanzen des \"Global Scales\" geteilt",
    "Create team" : "Team erstellen",
    "Promote as sole owner" : "Als Alleineigentümer ernennen",
    "Promote to {level}" : "Zum {level} ernennen",
    "Demote to {level}" : "Herabstufen auf {level}",
    "Are you sure you want to leave this team? This action cannot be undone." : "Möchten Sie das Team verlassen? Dieser Vorgang kann nicht rückgängig gemacht werden.",
    "Leave team failed." : "Team verlassen fehlgeschlagen",
    "Could not delete the member {displayName}" : "Das Mitglied {displayName} konnte nicht gelöscht werden ",
    "Could not change the member level to {level}" : "Mitgliedsstufe konnte nicht geändert werden auf {level}",
    "Could not accept membership request" : "Mitgliedsanfrage konnte nicht angenommen werden",
    "Accept membership request" : "Mitgliedsanfrage angenommen",
    "Reject membership request" : "Mitgliedsanfrage ablehnen",
    "Manage level" : "Mitgliedsstufe verwalten",
    "Remove member" : "Mitglied entfernen",
    "Unable to get the results" : "Die Ergebnisse können nicht abgerufen werden",
    "Some members could not be added" : "Einige Mitglieder konnten nicht hinzugefügt werden",
    "There was an issue adding members to the team" : "Beim Hinzufügen von Mitgliedern zum Team ist ein Problem aufgetreten",
    "Loading members list …" : "Lade Mitgliederliste …",
    "The list of members is only visible to members of this team" : "Die Mitgliederliste ist nur für Mitglieder dieses Teams sichtbar",
    "You currently have no access to the member list" : "Sie haben aktuell keinen Zugriff auf die Mitgliederliste",
    "Add to {team}" : "Zu {team} hinzufügen",
    "Invite members to {team}" : "Mitglieder zu {team} einladen",
    "Pending" : "Ausstehend",
    "Select chart …" : "Diagramm auswählen …",
    "Chart" : "Diagramm",
    "Select Date" : "Datum auswählen",
    "Select type" : "Typ auswählen",
    "Add contact in group" : "Kontakt zur Gruppe hinzufügen",
    "None" : "Keine",
    "copy" : "Kopieren",
    "Select option" : "Option auswählen",
    "JavaScript URIs are not allowed" : "JavaScript URIs sind unzulässig",
    "Notes" : "Notizen",
    "send an email" : "Eine E-Mail senden",
    "Personal dates" : "Persönliche Daten",
    "Add property of this type" : "Eigenschaft dieses Typs hinzufügen",
    "Member" : "Mitglied",
    "This is a read-only group managed by administrators. Group members can only view this group." : "Dies ist eine schreibgeschützte Gruppe, die von der Administration verwaltet wird. Gruppenmitglieder können diese Gruppe nur ansehen.",
    "Unable to create the contact." : "Kontakt konnte nicht erstellt werden.",
    "Contact not found" : "Kontakt nicht gefunden",
    "Group {group} not found" : "Gruppe {group} wurde nicht gefunden",
    "Add member" : "Mitglied hinzufügen",
    "New contact" : "Neuer Kontakt",
    "_{success} contact added to {name}_::_{success} contacts added to {name}_" : ["{success} Kontakt wurde hinzugefügt zu {name}","{success} Kontakte wurden hinzugefügt zu {name}"],
    "_Adding {success} contact to {name}_::_Adding {success} contacts to {name}_" : ["Füge {success} Kontakt zu {name} hinzu","Füge {success} Kontakte zu {name} hinzu"],
    "_{count} error_::_{count} errors_" : ["{count} Fehler","{count} Fehler"],
    "_Importing %n contact into {addressbook}_::_Importing %n contacts into {addressbook}_" : ["Importiere %n Kontakt nach {addressbook}","Importiere %n Kontakte nach {addressbook}"],
    "_Done importing %n contact into {addressbook}_::_Done importing %n contacts into {addressbook}_" : ["Import von %n Kontakt nach {addressbook} abgeschlossen","Import von %n Kontakten nach {addressbook} abgeschlossen"],
    "No data for this contact" : "Keine Daten für diesen Kontakt",
    "No data for this contact on their profile" : "Keine Daten für diesen Kontakt in dessen Profil",
    "Import" : "Importieren",
    "Are you sure you want to import this contact file?" : "Soll diese Kontaktdatei importiert werden?",
    "Could not copy" : "Konnte nicht kopiert werden",
    "Join team" : "Team beitreten",
    "You are about to leave {circle}.\nAre you sure?" : "Sie sind dabei {circle} zu verlassen.\nSind Sie sich sicher?",
    "Please confirm team leave" : "Bitte bestätigen Sie, dass Sie das Team verlassen möchten",
    "Could not leave the team {displayName}" : "Team {displayName} konnte nicht verlassen werden",
    "Unable to join the team" : "Beitritt zum Team nicht möglich",
    "You are about to delete {circle}.\nAre you sure?" : "Sie sind dabei {circle} zu löschen.\nSind Sie sich sicher?",
    "Please confirm team deletion" : "Löschen des Teams bestätigen",
    "Unable to delete the team" : "Team konnte nicht gelöscht werden",
    "Confirm enabling federation" : "Aktivierung der Federation bestätigen",
    "Enabling this will prevent {circle} from being a member of other teams.\nAre you sure?" : "Dies zu aktivieren verhindert, dass {circle} Mitglied in anderen Teams wird.\nAktivieren?",
    "Enable federation" : "Federation aktivieren",
    "Link copied to the clipboard" : "Link wurde in die Zwischenablage kopiert",
    "Could not copy link to the clipboard." : "Link konnte nicht in die Zwischenablage kopiert werden.",
    "Not grouped" : "Nicht gruppiert",
    "Organization chart" : "Organigramm",
    "Create your own teams for sharing. Add Nextcloud users, contacts, or anyone via email." : "Eigene Teams zum Teilen erstellen. Nextcloud-Benutzer, Kontakte oder andere Personen per E-Mail hinzufügen.",
    "Team" : "Team",
    "User" : "Benutzer",
    "Group" : "Gruppe",
    "Email" : "E-Mail",
    "Contact" : "Kontakt",
    "Moderator" : "Moderator",
    "Admin" : "Administration",
    "Owner" : "Besitzer",
    "Invites" : "Einladungen",
    "Anyone can request membership" : "Jeder kann eine Mitgliedschaft beantragen",
    "Members need to accept invitation" : "Mitglieder müssen die Einladung annehmen ",
    "Memberships must be confirmed/accepted by a Moderator (requires \"Anyone can request membership\")" : "Mitgliedschaften müssen von der Moderation bestätigt/angenommen werden (erfordert \"Jeder kann eine Mitgliedschaft beantragen\")",
    "Members can also invite" : "Mitglieder können auch einladen",
    "Membership" : "Mitgliedschaft",
    "Prevent teams from being a member of another team" : "Teams daran hindern, Mitglied eines anderen Teams zu werden",
    "Federation" : "Federation",
    "Allow federated members" : "Federated-Mitglieder zulassen",
    "Privacy" : "Datenschutz",
    "Visible to everyone" : "Für jeden sichtbar",
    "users" : "Benutzer",
    "Users" : "Benutzer",
    "groups" : "Gruppen",
    "federated users" : "Federated-Benutzer",
    "Federated users" : "Federated-Benutzer",
    "teams" : "Teams",
    "email addresses" : "E-Mail-Adressen",
    "Email addresses" : "E-Mail-Adressen",
    "contacts" : "Kontakte",
    "Detailed name" : "Detaillierter Name",
    "Additional names" : "Zusätzliche Namen",
    "Prefix" : "Präfix",
    "Suffix" : "Suffix",
    "Nickname" : "Spitzname",
    "Website" : "Webseite",
    "Location" : "Ort",
    "Federated Cloud ID" : "Federated-Cloud-ID",
    "Home" : "Privat",
    "Work" : "Arbeit",
    "Other" : "Andere",
    "Address" : "Adresse",
    "Post office box" : "Postfach",
    "Extended address" : "Erweiterte Adresse",
    "City" : "Stadt",
    "State or province" : "Bundesland oder Region",
    "Postal code" : "Postleitzahl",
    "Country" : "Land",
    "Birthday" : "Geburtstag",
    "Place of birth" : "Geburtsort",
    "Anniversary" : "Jahrestag",
    "Date of death" : "Todestag",
    "Place of death" : "Todesort",
    "Instant messaging" : "Instant Messaging",
    "Phone" : "Telefon",
    "Mobile" : "Mobil",
    "Work mobile" : "Arbeit mobil",
    "Home mobile" : "Privat mobil",
    "Fax" : "Fax",
    "Fax home" : "Fax privat",
    "Fax work" : "Fax Arbeit",
    "Pager" : "Pager",
    "Voice" : "Anruf",
    "Car" : "Auto",
    "Work pager" : "Arbeit Pager",
    "Line manager" : "Vorgesetzter",
    "Social network" : "Soziales Netzwerk",
    "Relationship to you" : "Verbindung zu Ihnen",
    "Spouse" : "Partner",
    "Child" : "Kind",
    "Mother" : "Mutter",
    "Father" : "Vater",
    "Parent" : "Eltern",
    "Brother" : "Bruder",
    "Sister" : "Schwester",
    "Relative" : "Verwandter",
    "Friend" : "Freund",
    "Colleague" : "Kollege",
    "Assistant" : "Assistent",
    "Related contacts" : "Zugehörige Kontakte",
    "Agent" : "Vertreter",
    "Emergency" : "Notfall",
    "Co-worker" : "Kollege",
    "Gender" : "Geschlecht",
    "Female" : "Weiblich",
    "Male" : "Männlich",
    "Unknown" : "Unbekannt",
    "Time zone" : "Zeitzone",
    "Spoken languages" : "Gesprochene Sprachen",
    "_{failed} contact failed to be read_::_{failed} contacts failed to be read_" : ["{failed} Kontakt konnte nicht gelesen werden","{failed} Kontakte konnten nicht gelesen werden"],
    "An error has occurred in team(s). Check the console for more details." : "Es ist ein Fehler in Team(s) aufgetreten. Bitte die Konsole für weitere Einzelheiten prüfen.",
    "Unable to create team {circleName}" : "Fehler beim Erstellen des Teams {circleName}",
    "Unable to delete team {circleId}" : "Fehler beim Löschen des Teams {circleId}",
    "Could not update favorite state" : "Favoritenzustand konnte nicht aktualisiert werden",
    "Unable to delete contact" : "Kontakt konnte nicht gelöscht werden",
    "Value copied to the clipboard" : "Wert in die Zwischenablage kopiert",
    "Could not copy value to the clipboard." : "Wert konnte nicht in die Zwischenablage kopiert werden.",
    "note" : "Notiz",
    "email" : "E-Mail",
    "Create your own groups for sharing. Add Nextcloud users, contacts, or anyone via email." : "Erstellen Sie Ihre eigenen Gruppen zum Teilen. Fügen Sie Nextcloud-Benutzer, Kontakte oder beliebige Personen per E-Mail hinzu."
},
"nplurals=2; plural=(n != 1);");
