OC.L10N.register(
    "contacts",
    {
    "Import contacts" : "Flytja inn tengiliði",
    "Details" : "Nánar",
    "All contacts" : "Allir tengiliðir",
    "Contacts" : "Tengiliðir",
    "A contacts app for Nextcloud" : "Tengiliðaforrit fyrir Nextcloud",
    "The Nextcloud contacts app is a user interface for Nextcloud's CardDAV server. Easily sync contacts from various devices with your Nextcloud and edit them online.\n\n* 🚀 **Integration with other Nextcloud apps!** Currently Mail and Calendar – more to come.\n* 🎉 **Never forget a birthday!** You can sync birthdays and other recurring events with your Nextcloud Calendar.\n* 👥 **Sharing of Adressbooks!** You want to share your contacts with your friends or coworkers? No problem!\n* 🙈 **We’re not reinventing the wheel!** Based on the great and open SabreDAV library." : "Tengiliðaforritið (Contacts) er notandaviðmót fyrir CardDAV-þjón Nextcloud. Samstilltu á einfaldan máta tengilði af ýmsum tækjum við Nextcloud tölvuskýið og breyttu þeim á netinu.\n\n* 🚀 **Samþætting við önnur Nextcloud forrit!** Nú er það þegar hægt við Tölvupóst (Mail) og Dagatal (Calendar) - fleira er í bígerð.\n* 🎉 **Ekki gleyma framar afmælisdögum!** Þú getur samstillt afmælisdaga og aðra endurtekna atburði við Nextcloud dagatalið þitt.\n* 👥 **Deildu nafnaskránum þínum!** Viltu deila tengiliðum með vinum þínum eða samstarfsmönnum? Ekki vandamál!\n* 🙈 **Við erum ekki að finna upp hjólið!** Byggist á hinu frábæra SabreDAV aðgerðasafni.",
    "Copy to full name" : "Afrita í fullt nafn",
    "Omit year" : "Sleppa ártali",
    "Allow updating avatars from social media" : "Leyfa uppfærslu auðkennismynda af samfélagsnetum",
    "There was an error fetching the member list" : "Villa kom upp við að ná í meðlimalistann",
    "Please select a team" : "Veldu eitthvað teymi",
    "Loading team…" : "Hleð inn teymi…",
    "There are no contacts yet" : "Það eru enn engir tengiliðir",
    "Create contact" : "Búa til tengilið",
    "There are no contacts in this group" : "Það eru engir tengiliðir í þessum hópi",
    "Create contacts" : "Búa til tengiliði",
    "Add contacts" : "Bæta við tengiliðum",
    "Manage team" : "Sýsla með teymi",
    "Leave team" : "Yfirgefa teymi",
    "Delete team" : "Eyða teymi",
    "Contacts settings" : "Stillingar tengiliða",
    "Update avatars from social media" : "Uppfæra auðkennismyndir af samfélagsmiðlum",
    "Address books" : "Nafnaskrár",
    "Rename" : "Endurnefna",
    "Export" : "Flytja út",
    "Send email" : "Senda tölvupóst",
    "Send email as BCC" : "Senda tölvupóst sem BCC",
    "Delete" : "Eyða",
    "Show all groups" : "Sýna alla hópa",
    "Collapse groups" : "Fella hópa saman",
    "Show all teams" : "Sýna öll teymi",
    "Collapse teams" : "Fella saman teymin",
    "Group name cannot be empty" : "Heiti hóps má ekki vera autt",
    "This group already exists" : "Þessi hópur er þegar til",
    "An error occurred while creating the group" : "Villa kom upp við að búa til hópinn",
    "This team already exists" : "Þetta teymi er þegar til staðar",
    "An error happened during the creation of the team" : "Villa kom upp við gerð teymisins",
    "Recently contacted" : "Nýlega haft samband við",
    "Contact groups" : "Tengiliðahópar",
    "Create a new contact group" : "Búa til nýjan tengiliðahóp",
    "Contact group name" : "Heiti tengiliðahóps",
    "Teams" : "Teymi",
    "Create a new team" : "Búa til nýtt teymi",
    "Open the contacts app settings" : "Opna stillingar tengiliðaforritsins",
    "_Shared with {num} entity_::_Shared with {num} entities_" : ["Deilt með {num} einindi","Deilt með {num} einindum"],
    "Copied" : "Afritað",
    "Cannot copy" : "Get ekki afritað",
    "Copy link" : "Afrita tengil",
    "Toggling of address book was not successful" : "Tókst ekki að víxla nafnaskrá af/á",
    "This will delete the address book and every contacts within it" : "Þetta mun eyða nafnaskránni og öllum tengiliðum í henni",
    "Delete {addressbook}?" : "Eyða {addressbook}?",
    "This will unshare the address book and every contacts within it" : "Þetta mun taka nafnaskrána úr deilingu og alla tengiliði í henni",
    "Unshare {addressbook}?" : "Hætta deilingu á {addressbook}?",
    "Deletion of address book was not successful." : "Tókst ekki að eyða nafnaskrá.",
    "Renaming of address book was not successful." : "Tókst ekki að endurnefna nafnaskrá.",
    "Download" : "Sækja",
    "Show" : "Birta",
    "Unshare from me" : "Hætta deilingu frá mér",
    "_%n contact_::_%n contacts_" : ["%n tengiliður","%n tengiliðir"],
    "_%n group_::_%n groups_" : ["%n hópur","%n hópar"],
    "Share with users or groups" : "Deila með notendum eða hópum",
    "Share with users" : "Deila með notendum",
    "No users or groups" : "Engir notendur eða hópar",
    "Unable to delete the share" : "Get ekki eytt sameigninni",
    "Unable to change permissions" : "Tekst ekki að breyta heimildum",
    "Choose a vCard file to import" : "Veldu vCard-skrá sem á að flytja inn",
    "Import into the {addressbookName} address book" : "Flytja inn í {addressbookName} nafnaskrána",
    "Select local file" : "Veldu skrá á tölvunni",
    "Import from files" : "Flytja inn úr skrám",
    "Importing is disabled because there are no address books available" : "Innflutningur er óvirkur því engar nafnaskrár eru tiltækar",
    "An error occurred, unable to create the address book" : "Villa kom upp, tókst ekki að útbúa nafnaskrána",
    "Add new address book" : "Bæta við nýrri nafnaskrá",
    "Cancel" : "Hætta við",
    "Add" : "Bæta við",
    "First name" : "Eiginnafn",
    "Last name" : "Kenninafn",
    "Phonetic first name" : "Hljóðstafað eiginnafn",
    "Phonetic last name" : "Hljóðstafað eftirnafn",
    "Display name" : "Birtingarnafn",
    "Last modified" : "Síðast breytt",
    "Manages" : "Stjórnar",
    "Oversees" : "Hefur umsjón",
    "An error happened during the config change" : "Óvænt villa kom upp við breytingu á uppsetningu",
    "Enforce password protection on files shared to this team" : "Krefjast verndunar með lykilorði á skrám sem deilt er með þessu teymi",
    "Use a unique password for all shares to this team" : "Nota einstakt lykilorð fyrir allar sameignir í þessu teymi",
    "Save" : "Vista",
    "Change unique password" : "Breyta einstöku lykilorði",
    "Failed to save password. Please try again later." : "Mistókst að vista lykilorð. Reyndu aftur síðar.",
    "Close" : "Loka",
    "There is no description for this team" : "Það er engin lýsing á þessu teymi",
    "Enter a description for the team" : "Settu inn lýsingu á teyminu",
    "Folder name" : "Heiti möppu",
    "Conversation name" : "Nafn samtals",
    "Team name" : "Heiti teymis",
    "Delete picture" : "Eyða mynd",
    "Edit" : "Breyta",
    "Request to join" : "Beiðni um þátttöku",
    "Create" : "Búa til",
    "Your request to join this team is pending approval" : "Beiðni þín um að taka þátt í þessu teymi bíður samþykkis",
    "You are not a member of {circle}" : "Þú ert ekki meðlimur í {circle}",
    "Members" : "Meðlimir",
    "Confirm" : "Staðfesta",
    "Add more info" : "Bæta við nánari upplýsingum",
    "More fields" : "Fleiri reitir",
    "Please select a valid format" : "Veldu gilt snið",
    "Invalid image" : "Ógild mynd",
    "Error cropping picture" : "Villa við að skera utan af mynd",
    "Pick an avatar" : "Veldu auðkennismynd",
    "Pick" : "Veldu",
    "Error while processing the picture." : "Villa kom upp við vinnslu myndar.",
    "Avatar downloaded from social network" : "Aðkennismynd hlaðið inn af samfélagsneti",
    "Avatar already up to date" : "Auðkennismynd er af nýjustu útgáfu",
    "Avatar download failed" : "Niðurhal auðkennismyndar tókst ekki",
    "Crop contact photo" : "Utanskera mynd tengiliðar",
    "Upload a new picture" : "Senda inn nýja mynd",
    "Choose from Files" : "Velja úr skrám",
    "Download picture" : "Sækja mynd",
    "This contact is in read-only mode. You do not have permission to edit this contact." : "Þessi tengiliður er skrifvarinn. Þú hefur ekki heimild til að breyta þessum tengilið.",
    "The contact you were trying to edit has changed. Please manually refresh the contact. Any further edits will be discarded." : "Tengiliðurinn sem þú ert að reyna að breyta hefur breyst. Endurlestu hann handvirkt. Öllum frekari breytingum verður hent.",
    "Address book" : "Nafnaskrá",
    "Add contact to Birthday Calendar" : "Bæta tengilið við fæðingardagatal",
    "Exclude contact from Birthday Calendar" : "Útiloka tengilið frá fæðingardagatali",
    "{title} at {organization}" : "{title} hjá {organization}",
    "Name" : "Nafn",
    "Syntax error. Cannot open the contact." : "Villa í málskipan. Get ekki opnað tengiliðinn.",
    "The contact does not exist on the server anymore." : "Tengiliðurinn er ekki lengur til á netþjóninum.",
    "Unable to retrieve the contact from the server, please check your network connection." : "Ekki er hægt að sækja tengiliðinn frá netþjóninum, athugaðu nettenginguna þína.",
    "An error occurred while trying to move the contact" : "Villa kom upp þegar reynt var að færa tengiliðinn",
    "An error occurred while trying to copy the contact" : "Villa kom upp þegar reynt var að afrita tengiliðinn",
    "Unable to update contact" : "Get ekki uppfært tengilið",
    "No contact selected" : "Enginn tengiliður valinn",
    "Select a contact on the list to begin" : "Veldu fyrst tengilið á listanum",
    "Title" : "Starfsheiti",
    "Company" : "Fyrirtæki",
    "Go to talk conversation" : "Fara í samtal",
    "View profile" : "Skoða notandasnið",
    "This contact was broken and received a fix. Please review the content and click here to save it." : "Þessi tengiliður var gallaður og var hann lagfærður. Yfirfarðu upplýsingarnar og smelltu síðan hér til að vista tengiliðinn.",
    "Edit profile" : "Breyta sniði",
    "Clone contact" : "Klóna tengilið",
    "Generate QR Code" : "Útbúa QR-kóða",
    "Contact vCard as QR code" : "vCard-upplýsingar tengiliðar sem QR-kóði",
    "Pick an address book" : "Veldu nafnaskrá",
    "Select address book" : "Veldu nafnaskrá",
    "Media shares with you" : "Myndefni deilt með þér",
    "Talk conversations with you" : "Samtöl við þig",
    "Calendar events with you" : "Atburðir dagatals með þér",
    "Deck cards with you" : "Deck-spjöld með þér",
    "No shared items with this contact" : "Engin samnýtt (deild) atriði með þessum tengilið",
    "Move" : "Move",
    "Remove from favorites" : "Fjarlægja úr eftirlætum",
    "Add to favorites" : "Bæta í eftirlæti",
    "Groups" : "Hópar",
    "Add to {group}" : "Bæta í {group}",
    "Remove {type}" : "Fjarlægja {type}",
    "Add to group" : "Bæta í hóp",
    "Search {types}" : "Leita að {types}",
    "Search for people to add" : "Leita að fólki til að bæta við",
    "No results" : "Engar niðurstöður",
    "Add {type}" : "Bæta við {type}",
    "New team name" : "Nýtt heiti teymis",
    "Personal team" : "Persónulegt teymi",
    "This team will only be visible to you. Other members will not be able to see or use it." : "Þetta teymi verður aðeins sýnilegt þér. Aðrir meðlimir munu ekki geta séð það eða notað.",
    "Local team" : "Staðvært teymi",
    "This team will not be shared with the other instances of the global scale" : "Þessu teymi verður ekki deilt með öðrum tilvikum í víðværa kerfinu",
    "Create team" : "Búa til teymi",
    "Promote as sole owner" : "Hækka upp í einasta eiganda",
    "Promote to {level}" : "Hækka upp í {level}",
    "Demote to {level}" : "Lækka niður í {level}",
    "Could not delete the member {displayName}" : "Gat ekki eytt meðlimnum {displayName}",
    "Could not change the member level to {level}" : "Ekki tókst að breyta stigi meðlims í {level}",
    "Could not accept membership request" : "Gat ekki samþykkt beiðni um þátttöku",
    "Accept membership request" : "Samþykkja beiðni um þátttöku",
    "Reject membership request" : "Hafna beiðni um þátttöku",
    "Manage level" : "Stjórna stigi",
    "Remove member" : "Fjarlægja meðlim",
    "Unable to get the results" : "Ekki tókst að sækja niðurstöðurnar",
    "Some members could not be added" : "Ekki var hægt að bæta við sumum meðlimum",
    "There was an issue adding members to the team" : "Upp kom vandamál við að bæta meðlimum í teymið",
    "The list of members is only visible to members of this team" : "Meðlimalistinn er aðeins sýnilegur meðlimum teymisins",
    "You currently have no access to the member list" : "Þú ert í augnablikinu ekki ekki aðgang að meðlimalistanum",
    "Pending" : "Í bið",
    "Chart" : "Graf",
    "Select Date" : "Veldu dagsetningu",
    "Select type" : "Veldu gerð",
    "Add contact in group" : "Bæta tengilið í hóp",
    "None" : "Ekkert",
    "Select option" : "Veldu valkost",
    "Notes" : "Minnispunktar",
    "Add property of this type" : "Bæta við eiginleika af þessari tegund",
    "Member" : "Meðlimur",
    "Unable to create the contact." : "Tókst ekki að búa til tengiliðinn.",
    "Contact not found" : "Tengiliður fannst ekki",
    "Group {group} not found" : "Hópurinn {group} fannst ekki",
    "Add member" : "Bæta við meðlimi",
    "New contact" : "Nýr tengiliður",
    "_{success} contact added to {name}_::_{success} contacts added to {name}_" : ["{success} tengilið bætt við {name}","{success} tengiliðum bætt við {name}"],
    "_Adding {success} contact to {name}_::_Adding {success} contacts to {name}_" : ["Bæti {success} tengilið við {name}","Bæti {success} tengiliðum við {name}"],
    "_{count} error_::_{count} errors_" : ["{count} villa","{count} villur"],
    "_Importing %n contact into {addressbook}_::_Importing %n contacts into {addressbook}_" : ["Flyt %n tengilið inn í {addressbook}","Flyt %n tengiliði inn í {addressbook}"],
    "_Done importing %n contact into {addressbook}_::_Done importing %n contacts into {addressbook}_" : ["Kláraði að flytja %n tengilið inn í {addressbook}","Kláraði að flytja %n tengiliði inn í {addressbook}"],
    "No data for this contact" : "Engin gögn fyrir þennan tengilið",
    "No data for this contact on their profile" : "Engin gögn fyrir þennan tengilið á notandasniði viðkomandi",
    "Import" : "Flytja inn",
    "Are you sure you want to import this contact file?" : "Ertu viss um að þú viljið flytja inn þessa tengiliðaskrá?",
    "Could not copy" : "Gat ekki afritað",
    "Join team" : "Taka þátt í teymi",
    "You are about to leave {circle}.\nAre you sure?" : "Þú ert að fara að hætta í {circle}.\nErtu viss?",
    "Please confirm team leave" : "Staðfestu úrsögn úr teymi",
    "Could not leave the team {displayName}" : "Mistókst að ganga úr teyminu {displayName}",
    "Unable to join the team" : "Mistókst að ganga til liðs við teymið",
    "You are about to delete {circle}.\nAre you sure?" : "Þú ert að fara að eyða {circle}.\nErtu viss?",
    "Please confirm team deletion" : "Staðfestu eyðingu teymisins",
    "Unable to delete the team" : "Tókst ekki að eyða teyminu",
    "Link copied to the clipboard" : "Tengill afritaður á klippispjaldið",
    "Could not copy link to the clipboard." : "Gat ekki afritað tengil á klippispjald.",
    "Not grouped" : "Ekki hópaður",
    "Organization chart" : "Skipulagsgraf",
    "Team" : "Teymi",
    "User" : "Notandi",
    "Group" : "Hópur",
    "Email" : "Netfang",
    "Contact" : "Tengiliður",
    "Moderator" : "Umsjónarmaður",
    "Admin" : "Stjórnandi",
    "Owner" : "Eigandi",
    "Invites" : "Boðsgestir",
    "Anyone can request membership" : "Hver sem er getur beðið um að verða meðlimur",
    "Members need to accept invitation" : "Meðlimir þurfa að samþykkja boð",
    "Memberships must be confirmed/accepted by a Moderator (requires \"Anyone can request membership\")" : "Þátttakendur þurfa að vera staðfestir/samþykktir af umsjónarmanni (krefst \"Hver sem er getur beðið um að verða meðlimur\")",
    "Members can also invite" : "Meðlimir geta einnig boðið",
    "Prevent teams from being a member of another team" : "Koma í veg fyrir að teymi sé meðlimur í öðru teymi",
    "Privacy" : "Friðhelgi",
    "Visible to everyone" : "Sýnilegt öllum",
    "users" : "notendur",
    "Users" : "Notendur",
    "groups" : "hópar",
    "teams" : "teymi",
    "email addresses" : "tölvupóstföng",
    "Email addresses" : "Tölvupóstföng",
    "contacts" : "tengiliðir",
    "Detailed name" : "Ítarlegt nafn",
    "Additional names" : "Aukanöfn",
    "Prefix" : "Forskeyti",
    "Suffix" : "Viðskeyti",
    "Nickname" : "Gælunafn",
    "Website" : "Vefsvæði",
    "Location" : "Staðsetning",
    "Federated Cloud ID" : "Skýjasambandsauðkenni (Federated Cloud ID)",
    "Home" : "Heima",
    "Work" : "Vinna",
    "Other" : "Annað",
    "Address" : "Slóð",
    "Post office box" : "Pósthólf",
    "Extended address" : "Ítarlegt heimilisfang",
    "City" : "Borg",
    "State or province" : "Ríki eða fylki",
    "Postal code" : "Póstnúmer",
    "Country" : "Land",
    "Birthday" : "Afmælisdagur",
    "Place of birth" : "Fæðingarstaður",
    "Anniversary" : "Afmæli",
    "Date of death" : "Dánardægur",
    "Place of death" : "Dánarstaður",
    "Instant messaging" : "Snarskilaboð",
    "Phone" : "Sími",
    "Mobile" : "Farsími",
    "Work mobile" : "Vinnufarsími",
    "Home mobile" : "Einkafarsími",
    "Fax" : "Fax",
    "Fax home" : "Heimafax",
    "Fax work" : "Vinnufax",
    "Pager" : "Símboði",
    "Voice" : "Raddskilaboð",
    "Car" : "Bíll",
    "Work pager" : "Vinnufriðþjófur",
    "Line manager" : "Línustjórnandi",
    "Social network" : "Samfélagsnet",
    "Relationship to you" : "Vensl við þig",
    "Spouse" : "Maki",
    "Child" : "Barn",
    "Mother" : "Móðir",
    "Father" : "Faðir",
    "Parent" : "Foreldri",
    "Brother" : "Bróðir",
    "Sister" : "Systir",
    "Relative" : "Ættingi",
    "Friend" : "Vinur",
    "Colleague" : "Samstarfsmaður",
    "Assistant" : "Aðstoðarmaður",
    "Related contacts" : "Tengdir tengiliðir",
    "Agent" : "Umboðsaðili",
    "Emergency" : "Neyðartilfelli",
    "Co-worker" : "Samstarfsmaður",
    "Gender" : "Kyn",
    "Female" : "Kona",
    "Male" : "Karl",
    "Unknown" : "Óþekkt",
    "Time zone" : "Tímabelti",
    "Spoken languages" : "Töluð tungumál",
    "_{failed} contact failed to be read_::_{failed} contacts failed to be read_" : ["Mistókst að lesa {failed} tengilið","Mistókst að lesa {failed} tengiliði"],
    "An error has occurred in team(s). Check the console for more details." : "Villa hefur átt sér stað í teymi/teymum. Skoðaðu stjórnskjáinn til að sjá nánari upplýsingar.",
    "Unable to create team {circleName}" : "Tókst ekki að búa til teymið {circleName}",
    "Unable to delete team {circleId}" : "Tókst ekki að eyða teyminu {circleId}",
    "Unable to delete contact" : "Tókst ekki að eyða tengilið"
},
"nplurals=2; plural=(n % 10 != 1 || n % 100 == 11);");
