OC.L10N.register(
    "contacts",
    {
    "Import contacts" : "إستيراد جهات الاتصال",
    "Details" : "التفاصيل",
    "All contacts" : "كل جهات الإتصال",
    "Contacts" : "جهات الاتصال",
    "A contacts app for Nextcloud" : "تطبيق \"جهات الاتصال\" Contacts لنكست كلاود",
    "The Nextcloud contacts app is a user interface for Nextcloud's CardDAV server. Easily sync contacts from various devices with your Nextcloud and edit them online.\n\n* 🚀 **Integration with other Nextcloud apps!** Currently Mail and Calendar – more to come.\n* 🎉 **Never forget a birthday!** You can sync birthdays and other recurring events with your Nextcloud Calendar.\n* 👥 **Sharing of Adressbooks!** You want to share your contacts with your friends or coworkers? No problem!\n* 🙈 **We’re not reinventing the wheel!** Based on the great and open SabreDAV library." : "تطبيق \"جهات الاتصال\" Contacts لنكست كلاود هو واجهة مستخدم لخادم CardDAV الخاص بـنكست كلاود. يمكنك مزامنة جهات الاتصال بسهولة من مختلف الأجهزة مع نكست كلاود وتحريرها عبر الإنترنت. \n\n* 🚀 ** التكامل مع تطبيقات نكست كلاود الأخرى! ** حاليًا البريد والتقويم - المزيد في المستقبل. \n* 🎉 ** يمكنك مزامنة أعياد الميلاد والأحداث المتكررة الأخرى مع تقويم نكست كلاود الخاص بك. \n* 👥 ** مشاركة دفاتر العناوين! ** تريد مشاركة جهات الاتصال الخاصة بك مع أصدقائك أو زملائك في العمل؟ لا مشكلة! \n* 🙈 ** نحن لا نعيد اختراع العجلة! ** استنادًا إلى مكتبة SabreDAV الرائعة والمفتوحة.",
    "Copy to full name" : "إنسخ إلى الإسم الكامل",
    "Omit year" : "تَجَاهَل السَّنَة",
    "Allow updating avatars from social media" : "السماح بتحديث التجسيد الرمزي avatar من وسائل التواصل الاجتماعي.",
    "There was an error fetching the member list" : "حدث خطأٌ في جلب أعضاء القائمة",
    "Please select a team" : "يرجى اختيار فريق",
    "Loading team…" : "تحميل الفريق ...",
    "There are no contacts yet" : "لا توجد أي جهات اتصال حتى الآن",
    "Create contact" : "إنشاء جهة اتصال",
    "There are no contacts in this group" : "لا توجد أي جهات اتصال في هذه المجموعة",
    "Create contacts" : "إنشاء جهات اتصال",
    "Add contacts" : "اضافة جهات اتصال",
    "Manage team" : "إدارة الفريق",
    "Leave team" : "مغادرة الفريق",
    "Delete team" : "حذف الفريق",
    "Contacts settings" : "إعدادات جهات الاتصال",
    "Update avatars from social media" : "تحديث الصورة الرمزية من وسائط التواصل الاجتماعي",
    "Address books" : "دفاتر العناوين",
    "Rename" : "تعديل الإسم",
    "Export" : "تصدير",
    "Send email" : "إرسال بريد",
    "Send email as BCC" : "إرسل الإيميل كـنسخة كربونية مخفية BCC",
    "Delete" : "حذف",
    "Show all groups" : "عرض كل المجموعات",
    "Collapse groups" : "تقويض collapse المجموعات",
    "Show all teams" : "عرض كل الفرق",
    "Collapse teams" : "طي الفرق",
    "Group name cannot be empty" : "اسم المجموعة يجب ألاّ يكون خالياً",
    "This group already exists" : "المجموعة موجودة مسبقاً",
    "An error occurred while creating the group" : "حدث خطأ أثناء إنشاء المجموعة",
    "This team already exists" : "هذا الفريق موجود سلفاً",
    "An error happened during the creation of the team" : "حدث خطأ أثناء إنشاء الفريق",
    "Recently contacted" : "تمّ التواصل معه مُؤخّراً",
    "Contact groups" : "مجموعات الاتصال",
    "Create a new contact group" : "إنشاء مجموعة اتصال جديدة",
    "Contact group name" : "اسم مجموعة الاتصال",
    "Teams" : "الفرق",
    "Create a new team" : "إنشاء فريق جديد",
    "Open the contacts app settings" : "إفتَح إعدادات تطبيق جهات الاتصال",
    "_Shared with {num} entity_::_Shared with {num} entities_" : ["تم مشاركته مع {num} كيانات","تم مشاركته مع {num} كيان","تم مشاركته مع {num} كيانات","تم مشاركته مع {num} كيانات","تم مشاركته مع {num} كيانات","تم مشاركته مع {num} كيانات"],
    "Copied" : "نُسخت ",
    "Cannot copy" : "تعذّر النسخ",
    "Copy link" : "نسخ الرابط",
    "Toggling of address book was not successful" : "لم يكن تبديل دفتر العناوين ناجحًا",
    "This will delete the address book and every contacts within it" : "هذا الإجراء سيؤدي إلى حذف دفتر العناوين و جميع ما فيه من جهات اتصال",
    "Delete {addressbook}?" : "حذف {addressbook}؟",
    "This will unshare the address book and every contacts within it" : "سيؤدي هذا إلى إلغاء مشاركة دفتر العناوين و كل ما يحتويه من جهات اتصال",
    "Unshare {addressbook}?" : "إلغاء مشاركة {addressbook}?",
    "Deletion of address book was not successful." : "تعذّر حذف دفتر العناوين",
    "Renaming of address book was not successful." : "تعذّرت إعادة تسمية دفتر العناوين",
    "Download" : "تنزيل",
    "Show" : "عرض",
    "Unshare from me" : "إلغِ المشاركة من جانبي",
    "_%n contact_::_%n contacts_" : ["%n جهات اتصال","%n جهة اتصال","%n جهات اتصال","%n جهات اتصال","%n جهات اتصال","%n جهات اتصال"],
    "_%n group_::_%n groups_" : ["%n مجموعات","%n مجموعة","%n مجموعات","%n مجموعات","%n مجموعات","%n مجموعات"],
    "Share with users or groups" : "شارِك مع مستخدمين او مجموعات",
    "Share with users" : "مشاركة مع المستخدمين",
    "No users or groups" : "لا يوجد مستخدمون أو مجموعات",
    "Unable to delete the share" : "تعذّر حذف المشاركة",
    "Unable to change permissions" : "تعذّر تغيير الأذونات",
    "Choose a vCard file to import" : "إختر ملف vCard لاستيراده",
    "Import into the {addressbookName} address book" : "الإستيراد إلى دفتر العناوين {addressbookName} ",
    "Select local file" : "إختر ملف محلي",
    "Import from files" : "إستيراد من تطبيق الملفات ",
    "Importing is disabled because there are no address books available" : "تمّ إيقاف الاستيراد لعدم وجود دفتر عناوين متاح",
    "An error occurred, unable to create the address book" : "حدث خطأ؛ تعذّر إنشاء دفتر العناوين",
    "Add new address book" : "أضف دفتر عناوين جديد",
    "Cancel" : "إلغاء",
    "Add" : "أضف",
    "First name" : "الإسم",
    "Last name" : "اللقب",
    "Phonetic first name" : "الاسم الأول نُطقاً",
    "Phonetic last name" : "الاسم الأخير نُطقاً",
    "Display name" : "اسم العرض",
    "Last modified" : "آخر تعديل",
    "Manages" : "يُدير",
    "Oversees" : "يُشرف على",
    "An error happened during the config change" : "حدث خطأ أثناء تعديل التهيئة",
    "Enforce password protection on files shared to this team" : "فرض الحماية بكلمات المرور للملفات المشتركة مع هذا الفريق",
    "Use a unique password for all shares to this team" : "استخدام كلمة مرور فريدة لكل مشاركات هذا الفريق",
    "Save" : "حفظ",
    "Change unique password" : "تغيير كلمة المرور الفريدة",
    "Failed to save password. Please try again later." : "تعذّر حفظ كلمة المرور. رجاءً، حاول مرة أخرى لاحقاً.",
    "Close" : "إغلاق",
    "There is no description for this team" : "لا يوجد وصف لهذا الفريق",
    "Enter a description for the team" : "أدخِل وصف الفريق",
    "Folder" : "Folder",
    "Conversation name" : "اسم المحادثة",
    "Calendar" : "التقويم",
    "Team name" : "اسم الفريق",
    "Delete picture" : "حذف الصورة",
    "Edit" : "تعديل",
    "Request to join" : "طلب انضمام",
    "Create" : "إنشاء",
    "Your request to join this team is pending approval" : "طلبك الانضمام إلى هذا الفريق في انتظار الموافقة",
    "You are not a member of {circle}" : "أنت لست عضواً في {circle}",
    "Members" : "الأعضاء",
    "Confirm" : "تأكيد",
    "Add more info" : "إضافة معلومات أكثر",
    "More fields" : "حقول أكثر",
    "Please select a valid format" : "يرجى اختيار تنسيق صحيح",
    "Invalid image" : "الصورة غير صالحة",
    "Error cropping picture" : "خطأ أثناء قصقصة الصورة cropping",
    "Pick an avatar" : "إختر صورة الملف الشخصي الرمزية",
    "Pick" : "إختر",
    "Error while processing the picture." : "حدث خطأ أثناء معالجة الصورة.",
    "Avatar downloaded from social network" : "تمّ تنزيل صورة الملف الشخصي الرمزية من وسائط التواصل الاجتماعي",
    "Avatar already up to date" : "صورة الملف الشخصي الرمزية محدثة",
    "Avatar download failed" : "فشل تنزيل الصورة الرمزية لجهة الاتصال",
    "Crop contact photo" : "قص صورة جهة الاتصال",
    "Upload a new picture" : "تحميل صورة جديدة",
    "Choose from Files" : "اختر من الملفات",
    "Download picture" : "تنزيل الصورة",
    "This contact is in read-only mode. You do not have permission to edit this contact." : "جهة الاتصال هذه في وضع القراءة فقط. ليس لديك إذن لتعديل جهة الاتصال هذه.",
    "The contact you were trying to edit has changed. Please manually refresh the contact. Any further edits will be discarded." : "تم تغيير جهة الاتصال التي كنت تحاول تحريرها. يرجى تحديث جهة الاتصال يدويًا. سيتم تجاهل أي تعديلات أخرى.",
    "Address book" : "دفتر العناوين",
    "Add contact to Birthday Calendar" : "أضف جهات اتصال إلى تقويم أعياد الميلاد",
    "Exclude contact from Birthday Calendar" : "إستبعد جهة اتصال من تقويم أعياد الميلاد",
    "{title} at {organization}" : "{title} في {organization}",
    "Name" : "الاسم",
    "Syntax error. Cannot open the contact." : "خطأ في بناء الجملة syntax. لا يمكن فتح جهة الاتصال.",
    "The contact does not exist on the server anymore." : "لم تعد جهة الاتصال هذه موجودة على الخادم.",
    "Unable to retrieve the contact from the server, please check your network connection." : "تعذر استرداد جهة الاتصال من الخادم ، يرجى التحقق من اتصال الشبكة.",
    "An error occurred while trying to move the contact" : "حدث خطأ أثناء محاولة نقل جهة الاتصال",
    "An error occurred while trying to copy the contact" : "حدث خطأ أثناء محاولة نسخ جهة الاتصال",
    "Unable to update contact" : "تعذّر تحديث جهة الاتصال",
    "No contact selected" : "لم يتم تحديد جهة اتصال",
    "Select a contact on the list to begin" : "حدّد جهة اتصال في القائمة للبدء",
    "Title" : "الصفة",
    "Company" : "جهة العمل",
    "Go to talk conversation" : "إذهَب إلى محادثة talk",
    "View profile" : "إعرِض الملف الشخصي",
    "This contact was broken and received a fix. Please review the content and click here to save it." : "تمّ قطع جهة الاتصال هذه و تمّ إصلاحها. يرجى مراجعة المحتوى والنقر هنا لحفظه.",
    "Edit profile" : "تعديل الملف الشخصي",
    "Clone contact" : "استنساخ الاتصال",
    "Generate QR Code" : "توليد كود QR",
    "Contact vCard as QR code" : "بطاقة اتصال Contact vCard في صورة كود QR",
    "Pick an address book" : "إختر دفتر عناوين",
    "Select address book" : "إختر دفتر العناوين",
    "Media shares with you" : "وسائط تمّت مُشارَكتها معك",
    "Talk conversations with you" : "مُحادثاتك",
    "Calendar events with you" : "أحداثك على التقويم",
    "Deck cards with you" : "بطاقات لك",
    "No shared items with this contact" : "لا توجد عناصر مُشارَكة مع جهة الاتصال هذه",
    "Move" : "Move",
    "Remove from favorites" : "إزالة مِن \"المُفضّلة\"",
    "Add to favorites" : "إضافة إلى المفضلة",
    "Groups" : "مجموعات",
    "Add to {group}" : "إضافة إلى {group}",
    "Remove {type}" : "حذف {type}",
    "Add to group" : "إضافة إلى مجموعة",
    "Search {types}" : "بحث {types}",
    "Search for people to add" : "البحث عن أشخاص لإضافتهم",
    "No results" : "لا توجد نتائج",
    "Add {type}" : "إضافة {type}",
    "New team name" : "اسم الفريق الجديد",
    "Personal team" : "فريق شخصي",
    "This team will only be visible to you. Other members will not be able to see or use it." : "هذا الفريق سيكون مرئياً لك أنت فقط. لن يتمكن الأعضاء الآخرون من رؤيته و لا من استعماله.",
    "Local team" : "فريق محلي",
    "This team will not be shared with the other instances of the global scale" : "هذا الفريق سوف لن تتم مشاركته مع الخوادم الأخرى على المستوى الشامل",
    "Create team" : "إنشاء فريق",
    "Promote as sole owner" : "ترقية المرتبة كمالكٍ وحيدٍ",
    "Promote to {level}" : "ترقية المرتبة إلى {level}",
    "Demote to {level}" : "خفض المرتبة إلى {level}",
    "Could not delete the member {displayName}" : "تعذّر حذف العضو {displayName}",
    "Could not change the member level to {level}" : "تعذّر تغيير مرتبة العضو إلى  {level}",
    "Could not accept membership request" : "تعذّر قبول طلب العضوية",
    "Accept membership request" : "قبول طلبات العضوية",
    "Reject membership request" : "رفض طلبات العضوية",
    "Manage level" : "إدارة المراتب",
    "Remove member" : "حذف عضو",
    "Unable to get the results" : "تعذّر الحصول على النتائج",
    "Some members could not be added" : "تعذّرت إضافة بعض الأعضاء",
    "There was an issue adding members to the team" : "حدث إشكال أثناء إضافة أعضاء للفريق",
    "The list of members is only visible to members of this team" : "قائمة الأعضاء تظهر فقط لأعضاء هذا الفريق",
    "You currently have no access to the member list" : "لا يحق لك حاليّاً الوصول إلى قائمة الأعضاء",
    "Pending" : "في انتظار الموافقة",
    "Chart" : "شكل Chart",
    "Select Date" : "اختر التاريخ ",
    "Select type" : "إختر نوعاً",
    "Add contact in group" : "إضافة جهة اتصال في المجموعة",
    "None" : "لا شيء",
    "Select option" : "حدّد خياراً",
    "Notes" : "ملاحظات",
    "Personal dates" : "تواريخ شخصية",
    "Add property of this type" : "إضافة خاصية من هذا النوع ",
    "Member" : "عضو",
    "Unable to create the contact." : "تعذّر إنشاء جهة الاتصال",
    "Contact not found" : "جهة الاتصال غير موجودة",
    "Group {group} not found" : "المجموعة {group} غير موجودة",
    "Add member" : "أضِف عُضْواً",
    "New contact" : "جهة إتصال جديدة",
    "_{success} contact added to {name}_::_{success} contacts added to {name}_" : ["{success} أضيفت جهات الاتصال إلى {name}","{success} أضيفت جهة الاتصال إلى {name}","{success} أضيفت جهات الاتصال إلى {name}","{success} أضيفت جهات الاتصال إلى {name}","{success} أضيفت جهات الاتصال إلى {name}","{success} أضيفت جهات الاتصال إلى {name}"],
    "_Adding {success} contact to {name}_::_Adding {success} contacts to {name}_" : ["جار {success} إضافة جهات اتصال إلى {name}","جار {success} إضافة جهة اتصال إلى {name}","جار {success} إضافة جهات اتصال إلى {name}","جار {success} إضافة جهات اتصال إلى {name}","جار {success} إضافة جهات اتصال إلى {name}","جار {success} إضافة جهات اتصال إلى {name}"],
    "_{count} error_::_{count} errors_" : ["{count} أخطاء","{count} خطأ","{count} أخطاء","{count} أخطاء","{count} أخطاء","{count} أخطاء"],
    "_Importing %n contact into {addressbook}_::_Importing %n contacts into {addressbook}_" : ["جار استيراد %n جهات اتصال إلى {addressbook}","جار استيراد %n جهة اتصال إلى {addressbook}","جار استيراد %n جهات اتصال إلى {addressbook}","جار استيراد %n جهات اتصال إلى {addressbook}","جار استيراد %n جهات اتصال إلى {addressbook}","جار استيراد %n جهات اتصال إلى {addressbook}"],
    "_Done importing %n contact into {addressbook}_::_Done importing %n contacts into {addressbook}_" : ["تم استيراد %nجهات اتصال إلى {addressbook}","تم استيراد %n جهة اتصال إلى {addressbook}","تم استيراد %nجهات اتصال إلى {addressbook}","تم استيراد %nجهات اتصال إلى {addressbook}","تم استيراد  %nجهات اتصال إلى {addressbook}","تم استيراد %n جهات اتصال إلى {addressbook}"],
    "No data for this contact" : "لا توجد أي بيانات حول جهة الاتصال هذه",
    "No data for this contact on their profile" : "لا توجد أي بيانات حول جهة الاتصال هذا في ملفها الشخصي",
    "Import" : "استيراد",
    "Are you sure you want to import this contact file?" : "هل أنت متأكد أنك تريد استيراد ملف جهات الاتصال هذا؟",
    "Could not copy" : "تعذّر النسخ",
    "Join team" : "الانضمام للفريق",
    "You are about to leave {circle}.\nAre you sure?" : "أنت على وشك مغادرة الدائرة {circle}.\nهل أنت متأكد؟",
    "Please confirm team leave" : "من فضلك، أكِّد مغادرتك للفريق",
    "Could not leave the team {displayName}" : "تعذّرت مغادرة الفريق {displayName}",
    "Unable to join the team" : "تعذّر الانضمام للفريق",
    "You are about to delete {circle}.\nAre you sure?" : "أنت على وشك حذف الدائرة {circle}.\nهل أنت متأكد؟",
    "Please confirm team deletion" : "من فضلك، أكِّد حذف الفريق",
    "Unable to delete the team" : "تعذّر حذف الفريق",
    "Link copied to the clipboard" : "تمّ نسخ الرابط إلى الحافظة",
    "Could not copy link to the clipboard." : "تعذّر نسخ الرابط إلى الحافظة",
    "Not grouped" : "غير مُجمّعٍ",
    "Organization chart" : "الهيكل التنظيمي",
    "Team" : "الفريق",
    "User" : "المستخدم",
    "Group" : "المجموعة",
    "Email" : "البريد الإلكتروني",
    "Contact" : "جهة اتصال",
    "Moderator" : "مشرِف",
    "Admin" : "مدير",
    "Owner" : "مالك",
    "Invites" : "يدعو",
    "Anyone can request membership" : "يمكن لأي شخص طلب العضوية",
    "Members need to accept invitation" : "يلزم أن يقبل العضو الدعوة",
    "Memberships must be confirmed/accepted by a Moderator (requires \"Anyone can request membership\")" : "يجب أن يتم قبول العضويات من قِبَل مشرف (يستلزم \"أي أحدٍ يمكنه طلب العضوية Anyobe can request membership\")",
    "Members can also invite" : "يمكن للأعضاء أيضاً إرسال دعوات العضوية",
    "Prevent teams from being a member of another team" : "منع الفريق من ان يكون عضواً في فريق آخر",
    "Visible to everyone" : "مرئي للجميع",
    "users" : "مستخدِمون",
    "Users" : "المستخدمين",
    "groups" : "مجموعات",
    "teams" : "الفرق",
    "email addresses" : "عناوين بريد الكتروني",
    "Email addresses" : "عناوين البريد الالكتروني",
    "contacts" : "جهات اتصال",
    "Detailed name" : "الاسم بالتفصيل",
    "Additional names" : "الأسماء الإضافية",
    "Prefix" : "بادئة",
    "Suffix" : "لاحقة",
    "Nickname" : "اللقب",
    "Website" : "موقع إلكتروني",
    "Location" : "المكان",
    "Federated Cloud ID" : "معرف السحابة الموحدة",
    "Home" : "المنزل",
    "Work" : "العمل",
    "Other" : "آخر",
    "Address" : "العنوان",
    "Post office box" : "صندوق البريد",
    "Extended address" : "عنوان مفصل",
    "City" : "المدينة",
    "State or province" : "الولاية أو المقاطعة",
    "Postal code" : "الرمز البريدي",
    "Country" : "البلد",
    "Birthday" : "عيد ميلاد",
    "Place of birth" : "مكان الميلاد",
    "Anniversary" : "ذكرى سنوية",
    "Date of death" : "تاريخ وفاة",
    "Place of death" : "مكان الوفاة",
    "Instant messaging" : "مراسلة فورية",
    "Phone" : "الهاتف",
    "Mobile" : "النقّال",
    "Work mobile" : "نقّال العمل",
    "Home mobile" : "نقّال البيت",
    "Fax" : "الفاكس",
    "Fax home" : "فاكس المنزل",
    "Fax work" : "فاكس العمل",
    "Pager" : "المُنادِي pager",
    "Voice" : "صوت",
    "Car" : "سيارة",
    "Work pager" : "مُنادِي العمل Work pager",
    "Line manager" : "مدير الخط",
    "Social network" : "شبكة اجتماعية",
    "Relationship to you" : "العلاقة معك",
    "Spouse" : "زوج/زوجة",
    "Child" : "طفل",
    "Mother" : "أم",
    "Father" : "أب",
    "Parent" : "والدين",
    "Brother" : "أخ",
    "Sister" : "أخت",
    "Relative" : "مرتبط",
    "Friend" : "صديق",
    "Colleague" : "زميل",
    "Assistant" : "مُساعِد",
    "Related contacts" : "جهات الاتصال ذات العلاقة",
    "Agent" : "مندوب",
    "Emergency" : "إسعاف/طوارئ",
    "Co-worker" : "زميل عمل",
    "Gender" : "الجنس",
    "Female" : "أنثى",
    "Male" : "ذكر",
    "Unknown" : "مجهول",
    "Time zone" : "المنطقة الزمنية",
    "Spoken languages" : "اللغات المحكية",
    "_{failed} contact failed to be read_::_{failed} contacts failed to be read_" : ["{failed} فشل قراءة جهات الاتصال","{failed} فشل قراءة جهة الاتصال","{failed} فشل قراءة جهات الاتصال","{failed} فشل قراءة جهات الاتصال","{failed} فشل قراءة جهات الاتصال","{failed} فشل قراءة جهات الاتصال"],
    "An error has occurred in team(s). Check the console for more details." : "حدث خطأ في الفريق أو الفرق. إفحص شاشة التحكم (console) لمزيد من التفاصيل.",
    "Unable to create team {circleName}" : "تعذّر إنشاء الفريق {circleName}",
    "Unable to delete team {circleId}" : "تعذّر حذف الفريق {circleId}",
    "Unable to delete contact" : "تعذّر حذف جهة الاتصال"
},
"nplurals=6; plural=n==0 ? 0 : n==1 ? 1 : n==2 ? 2 : n%100>=3 && n%100<=10 ? 3 : n%100>=11 && n%100<=99 ? 4 : 5;");
