OC.L10N.register(
    "contacts",
    {
    "Import contacts" : "Importa contactes",
    "Details" : "Detalls",
    "All contacts" : "Tots els contactes",
    "Contacts" : "Contactes",
    "A contacts app for Nextcloud" : "Una aplicació de contactes per al Nextcloud",
    "The Nextcloud contacts app is a user interface for Nextcloud's CardDAV server. Easily sync contacts from various devices with your Nextcloud and edit them online.\n\n* 🚀 **Integration with other Nextcloud apps!** Currently Mail and Calendar – more to come.\n* 🎉 **Never forget a birthday!** You can sync birthdays and other recurring events with your Nextcloud Calendar.\n* 👥 **Sharing of Adressbooks!** You want to share your contacts with your friends or coworkers? No problem!\n* 🙈 **We’re not reinventing the wheel!** Based on the great and open SabreDAV library." : "L'aplicació Contactes del Nextcloud és una interfície d'usuari per al servidor CardDAV del Nextcloud. Sincronitzeu fàcilment els contactes de diversos dispositius amb el Nextcloud i editeu-los en línia.\n\n* 🚀 **Integració amb altres aplicacions del Nextcloud.** Actualment, Correu i Calendari. Pròximament hi haurà més integracions.\n* 🎉 **No oblidareu mai els aniversaris.** Podeu sincronitzar els aniversaris i altres esdeveniments periòdics amb el vostre calendari del Nextcloud.\n* 👥 **Ús compartit de llibretes d'adreces.** Voleu compartir els vostres contactes amb amics o companys de feina? Cap problema!\n* 🙈 **No reinventem la roda.** Es basa en la fantàstica llibreria SabreDAV, de codi obert.",
    "Copy to full name" : "Copia al nom complet",
    "Omit year" : "Omet l'any",
    "Allow updating avatars from social media" : "Permet l'actualització d'avatars des de les xarxes socials",
    "There was an error fetching the member list" : "S'ha produït un error en recuperar la llista de membres",
    "Please select a team" : "Seleccioneu un equip",
    "Loading team…" : "S'està carregant l'equip…",
    "There are no contacts yet" : "Encara no hi ha contactes",
    "Create contact" : "Crea un contacte",
    "There are no contacts in this group" : "No hi ha contactes en aquest grup",
    "Create contacts" : "Crea contactes",
    "Add contacts" : "Afegeix contactes",
    "Manage team" : "Administrar l'equip",
    "Leave team" : "Abandonar l'equip",
    "Delete team" : "Suprimeix l'equip",
    "Contacts settings" : "Paràmetres de Contactes",
    "Update avatars from social media" : "Actualitza els avatars des de les xarxes socials",
    "Address books" : "Llibretes d'adreces",
    "Rename" : "Canvia el nom",
    "Export" : "Exporta",
    "Send email" : "Envia un correu electrònic",
    "Send email as BCC" : "Envia un correu electrònic com a Cco",
    "Delete" : "Suprimeix",
    "Show all groups" : "Mostra tots els grups",
    "Collapse groups" : "Redueix els grups",
    "Show all teams" : "Mostra tots els equips",
    "Collapse teams" : "Col·lapse els equips",
    "Group name cannot be empty" : "El nom del grup no pot estar buit",
    "This group already exists" : "Aquest grup ja existeix",
    "An error occurred while creating the group" : "S'ha produït un error en crear el grup",
    "This team already exists" : "Aquest equip ja existeix",
    "An error happened during the creation of the team" : "S'ha produït un error durant la creació de l'equip",
    "Recently contacted" : "Contactes recents",
    "Contact groups" : "Grups de contacte",
    "Create a new contact group" : "Creació d'un grup de contactes nou",
    "Contact group name" : "Nom del grup de contacte",
    "Teams" : "Equips",
    "Create a new team" : "Crea un nou equip",
    "Open the contacts app settings" : "Obriu els paràmetres de l'aplicació contactes",
    "_Shared with {num} entity_::_Shared with {num} entities_" : ["S'ha compartit amb {num} entitat","S'ha compartit amb {num} entitats"],
    "Copied" : "S'ha copiat",
    "Cannot copy" : "No s'ha pogut copiar",
    "Copy link" : "Copia l'enllaç",
    "Toggling of address book was not successful" : "No s'ha pogut canviar la llibreta d'adreces",
    "This will delete the address book and every contacts within it" : "Això suprimirà la llibreta d'adreces i tots els contactes que conté",
    "Delete {addressbook}?" : "Voleu suprimir {addressbook}?",
    "This will unshare the address book and every contacts within it" : "Això deixarà de compartir la llibreta d'adreces i tots els contactes que hi hagi",
    "Unshare {addressbook}?" : "Vols deixar de compartir {addressbook}?",
    "Deletion of address book was not successful." : "No s'ha pogut suprimir la llibreta d'adreces.",
    "Renaming of address book was not successful." : "No s'ha pogut canviar el nom de la llibreta d'adreces.",
    "Download" : "Baixa",
    "Show" : "Mostra",
    "Unshare from me" : "Deixa de compartir amb mi",
    "_%n contact_::_%n contacts_" : ["%n contacte","%n contactes"],
    "_%n group_::_%n groups_" : ["%n grup","%n grups"],
    "Share with users or groups" : "Comparteix amb usuaris o grups",
    "Share with users" : "Comparteix amb els usuaris",
    "No users or groups" : "No hi ha usuaris ni grups",
    "Unable to delete the share" : "No s'ha pogut inhabilitar l'ús compartit",
    "Unable to change permissions" : "No s'han pogut canviar els permisos",
    "Choose a vCard file to import" : "Trieu un fitxer vCard per a importar-lo",
    "Import into the {addressbookName} address book" : "Importa a la llibreta d'adreces {addressbookName}",
    "Select local file" : "Selecciona un fitxer local",
    "Import from files" : "Importa des de fitxers",
    "Importing is disabled because there are no address books available" : "La importació està inhabilitada perquè no hi ha cap llibreta d'adreces disponible",
    "An error occurred, unable to create the address book" : "S'ha produït un error, no s'ha pogut crear la llibreta d'adreces",
    "Add new address book" : "Afegeix una llibreta d'adreces",
    "Cancel" : "Cancel·la",
    "Add" : "Afegeix",
    "First name" : "Nom",
    "Last name" : "Cognoms",
    "Phonetic first name" : "Nom fonètic",
    "Phonetic last name" : "Cognoms fonètics",
    "Display name" : "Nom de visualització",
    "Last modified" : "Darrera modificació",
    "Manages" : "Gestiona",
    "Oversees" : "Supervisa",
    "An error happened during the config change" : "S'ha produït un error durant el canvi de configuració",
    "Enforce password protection on files shared to this team" : "Força la protecció amb contrasenya als fitxers compartits amb aquest equip",
    "Use a unique password for all shares to this team" : "Utilitzeu una contrasenya única per a totes les comparticions d'aquest equip",
    "Save" : "Desa",
    "Change unique password" : "Canvia la contrasenya única",
    "Failed to save password. Please try again later." : "No s'ha pogut desar la contrasenya. Torneu-ho a provar més tard.",
    "Close" : "Tanca",
    "There is no description for this team" : "No hi ha cap descripció per a aquest equip",
    "Enter a description for the team" : "Introduïu una descripció per a l'equip",
    "Folder" : "Folder",
    "Team name" : "Nom de l'equip",
    "Delete picture" : "Suprimeix la imatge",
    "Edit" : "Edita",
    "Request to join" : "Sol·licita unir-m'hi",
    "Your request to join this team is pending approval" : "La teva sol·licitud per unir-te a aquest equip està pendent d'aprovació",
    "You are not a member of {circle}" : "No formeu part del cercle {circle}",
    "Members" : "Membres",
    "Confirm" : "Confirma",
    "Add more info" : "Afegeix més informació",
    "More fields" : "Més camps",
    "Please select a valid format" : "Seleccioneu un format vàlid",
    "Invalid image" : "La imatge no és vàlida",
    "Error cropping picture" : "S'ha produït un error en retallar la imatge",
    "Pick an avatar" : "Trieu un avatar",
    "Pick" : "Tria",
    "Error while processing the picture." : "S'ha produït un error en processar la imatge.",
    "Avatar downloaded from social network" : "S'ha baixat l'avatar des de la xarxa social",
    "Avatar already up to date" : "L'avatar ja està actualitzat",
    "Avatar download failed" : "S'ha produït un error en baixar l'avatar",
    "Crop contact photo" : "Retalla la fotografia del contacte",
    "Upload a new picture" : "Puja una imatge nova",
    "Choose from Files" : "Tria a Fitxers",
    "Download picture" : "Baixa la imatge",
    "This contact is in read-only mode. You do not have permission to edit this contact." : "Aquest contacte està en mode de només lectura. No teniu permís per a editar-lo.",
    "The contact you were trying to edit has changed. Please manually refresh the contact. Any further edits will be discarded." : "El contacte que intentàveu editar s'ha modificat. Actualitzeu la pàgina del contacte manualment. Es descartaran tots els canvis posteriors.",
    "Address book" : "Llibreta d'adreces",
    "Add contact to Birthday Calendar" : "Afegeix un contacte al calendari d'aniversaris",
    "Exclude contact from Birthday Calendar" : "Exclou contacte del calendari d'aniversaris",
    "{title} at {organization}" : "{title} a {organization}",
    "Name" : "Nom",
    "Syntax error. Cannot open the contact." : "Error de sintaxi. No es pot obrir el contacte.",
    "The contact does not exist on the server anymore." : "El contacte ja no existeix al servidor.",
    "Unable to retrieve the contact from the server, please check your network connection." : "No s'ha pogut recuperar el contacte del servidor. Comproveu la connexió de xarxa.",
    "An error occurred while trying to move the contact" : "S'ha produït un error en intentar desplaçar el contacte",
    "An error occurred while trying to copy the contact" : "S'ha produït un error en intentar copiar el contacte",
    "Unable to update contact" : "No s'ha pogut actualitzar el contacte",
    "No contact selected" : "No heu seleccionat cap contacte",
    "Select a contact on the list to begin" : "Seleccioneu un contacte de la llista per a començar",
    "Title" : "Càrrec",
    "Company" : "Empresa",
    "Go to talk conversation" : "Anar a conversa",
    "View profile" : "Visualitza el perfil",
    "This contact was broken and received a fix. Please review the content and click here to save it." : "Aquest contacte estava trencat i s'ha corregit. Reviseu-ne el contingut i feu clic aquí per a desar-lo.",
    "Edit profile" : "Edita el perfil",
    "Clone contact" : "Clona el contacte",
    "Generate QR Code" : "Genera un codi QR",
    "Contact vCard as QR code" : "Contacte vCard com a codi QR",
    "Pick an address book" : "Trieu una llibreta d'adreces",
    "Select address book" : "Seleccioneu una llibreta d'adreces",
    "Media shares with you" : "Lese comparticions de mitjans amb tu",
    "Talk conversations with you" : "Converses de Parlar amb tu",
    "Calendar events with you" : "Esdeveniments de Calendari amb tu",
    "Deck cards with you" : "Pila de Targetes amb tu",
    "No shared items with this contact" : "No s'ha compartit cap element amb aquest contacte",
    "Move" : "Move",
    "Remove from favorites" : "Suprimeix de preferits",
    "Add to favorites" : "Afegeix a favorits",
    "Groups" : "Grups",
    "Add to {group}" : "Afegeix a {group}",
    "Remove {type}" : "Suprimeix {type}",
    "Add to group" : "Afegeix al grup",
    "Search {types}" : "Cerqueu {types}",
    "Search for people to add" : "Cerqueu persones per a afegir-les",
    "No results" : "Sense resultats",
    "Add {type}" : "Afegeix {type}",
    "New team name" : "Nou nom de l'equip",
    "Personal team" : "Equip personal",
    "This team will only be visible to you. Other members will not be able to see or use it." : "Aquest equip només serà visible per a tu. Els altres membres no el podran veure ni utilitzar.",
    "Local team" : "Equip local",
    "This team will not be shared with the other instances of the global scale" : "Aquest equip no es compartirà amb les altres instàncies de l'escala global",
    "Create team" : "Crea equip",
    "Promote as sole owner" : "Eleva a propietari únic",
    "Promote to {level}" : "Eleva a {level}",
    "Demote to {level}" : "Redueix a {level}",
    "Could not delete the member {displayName}" : "No s'ha pogut suprimir {displayName}",
    "Could not change the member level to {level}" : "No s'ha pogut canviar el nivell del membre a {level}",
    "Could not accept membership request" : "No s'ha pogut acceptar la sol·licitud d'incorporació",
    "Accept membership request" : "Accepta la sol·licitud d'incorporació",
    "Reject membership request" : "Rebutja la sol·licitud d'incorporació",
    "Manage level" : "Administra el nivell",
    "Remove member" : "Suprimeix el membre",
    "Unable to get the results" : "No s'han pogut obtenir els resultats",
    "Some members could not be added" : "No s'han pogut afegir alguns membres",
    "There was an issue adding members to the team" : "Hi ha hagut un problema en afegir membres a l'equip",
    "The list of members is only visible to members of this team" : "La llista de membres només és visible per als membres d'aquest equip",
    "You currently have no access to the member list" : "Actualment no teniu accés a la llista de membres",
    "Pending" : "Pendent",
    "Chart" : "Gràfic",
    "Select Date" : "Seleccioneu una data",
    "Select type" : "Seleccioneu un tipus",
    "Add contact in group" : "Afegeix el contacte a un grup",
    "None" : "Cap",
    "Select option" : "Seleccioneu una opció",
    "Notes" : "Anotacions",
    "Add property of this type" : "Afegeix una propietat d'aquest tipus",
    "Member" : "Membre",
    "Unable to create the contact." : "No s'ha pogut crear el contacte.",
    "Contact not found" : "No s'ha trobat el contacte",
    "Group {group} not found" : "No s'ha trobat el grup {group}",
    "Add member" : "Afegeix un membre",
    "New contact" : "Contacte nou",
    "_{success} contact added to {name}_::_{success} contacts added to {name}_" : ["S'ha afegit {success} contacte a {name}","S'han afegit {success} contactes a {name}"],
    "_Adding {success} contact to {name}_::_Adding {success} contacts to {name}_" : ["S'està afegint {success} contacte a {name}","S'estan afegint {success} contactes a {name}"],
    "_{count} error_::_{count} errors_" : ["{count} error","{count} errors"],
    "_Importing %n contact into {addressbook}_::_Importing %n contacts into {addressbook}_" : ["S'està important %n contacte a {addressbook}","S'estan important %n contactes a {addressbook}"],
    "_Done importing %n contact into {addressbook}_::_Done importing %n contacts into {addressbook}_" : ["La importació d'%n contacte a {addressbook} ha finalitzat","La importació de %n contactes a {addressbook} ha finalitzat"],
    "No data for this contact" : "No hi ha dades per a aquest contacte",
    "No data for this contact on their profile" : "No hi ha dades d'aquest contacte al seu perfil",
    "Import" : "Importa",
    "Are you sure you want to import this contact file?" : "Esteu segur que voleu importar aquest fitxer de contacte?",
    "Could not copy" : "No s'ha pogut copiar",
    "Join team" : "Uneix-te a l'equip",
    "You are about to leave {circle}.\nAre you sure?" : "Esteu a punt d'abandonar {circle}.\nSegur que voleu continuar?",
    "Please confirm team leave" : "Si us plau, confirmeu la sortida de l'equip",
    "Could not leave the team {displayName}" : "No s'ha pogut abandonar l'equip {displayName}",
    "Unable to join the team" : "No es pot unir a l'equip",
    "You are about to delete {circle}.\nAre you sure?" : "Esteu a punt de suprimir {circle}.\nSegur que voleu continuar?",
    "Please confirm team deletion" : "Si us plau, confirmeu la supressió de l'equip",
    "Unable to delete the team" : "No es pot suprimir l'equip",
    "Link copied to the clipboard" : "S'ha copiat l'enllaç al porta-retalls",
    "Could not copy link to the clipboard." : "No s'ha pogut copiar l'enllaç al porta-retalls.",
    "Not grouped" : "Sense grup",
    "Organization chart" : "Organigrama",
    "Team" : "Equip",
    "User" : "Usuari",
    "Group" : "Grup",
    "Email" : "Correu electrònic",
    "Contact" : "Contacte",
    "Moderator" : "Moderador",
    "Admin" : "Administrador",
    "Owner" : "Propietari",
    "Invites" : "Invitacions",
    "Anyone can request membership" : "Qualsevol usuari pot sol·licitar la incorporació",
    "Members need to accept invitation" : "Els membres han d'acceptar la invitació",
    "Memberships must be confirmed/accepted by a Moderator (requires \"Anyone can request membership\")" : "Els membres han de ser confirmats/acceptats per un moderador (requereix \"Qualsevol persona pot sol·licitar la subscripció\")",
    "Members can also invite" : "Els membres també poden convidar altres usuaris",
    "Prevent teams from being a member of another team" : "Evitar que els equips siguin membres d'un altre equip",
    "Visible to everyone" : "Visible per a tothom",
    "users" : "usuaris",
    "Users" : "Usuaris",
    "groups" : "grups",
    "teams" : "equips",
    "email addresses" : "adreces de correu electrònic",
    "Email addresses" : "Adreces de correu electrònic",
    "contacts" : "contactes",
    "Detailed name" : "Nom detallat",
    "Additional names" : "Noms addicionals",
    "Prefix" : "Prefix",
    "Suffix" : "Sufix",
    "Nickname" : "Sobrenom",
    "Website" : "Lloc web",
    "Location" : "Ubicació",
    "Federated Cloud ID" : "ID de núvol federat",
    "Home" : "Casa",
    "Work" : "Feina",
    "Other" : "Un altre",
    "Address" : "Adreça",
    "Post office box" : "Apartat de correus",
    "Extended address" : "Adreça completa",
    "City" : "Ciutat",
    "State or province" : "Estat o província",
    "Postal code" : "Codi postal",
    "Country" : "País",
    "Birthday" : "Aniversari",
    "Place of birth" : "Lloc de naixement",
    "Anniversary" : "Commemoració",
    "Date of death" : "Data de defunció",
    "Place of death" : "Lloc de la mort",
    "Instant messaging" : "Missatgeria instantània",
    "Phone" : "Telèfon",
    "Mobile" : "Mòbil",
    "Work mobile" : "Mòbil de la feina",
    "Home mobile" : "Mòbil de casa",
    "Fax" : "Fax",
    "Fax home" : "Fax (casa)",
    "Fax work" : "Fax (feina)",
    "Pager" : "Cercapersones",
    "Voice" : "Veu",
    "Car" : "Cotxe",
    "Work pager" : "Cercapersones de la feina",
    "Line manager" : "Responsable de línia",
    "Social network" : "Xarxa social",
    "Relationship to you" : "Relació",
    "Spouse" : "Parella",
    "Child" : "Fill",
    "Mother" : "Mare",
    "Father" : "Pare",
    "Parent" : "Progenitor",
    "Brother" : "Germà",
    "Sister" : "Germana",
    "Relative" : "Familiar",
    "Friend" : "Amic",
    "Colleague" : "Company",
    "Assistant" : "Assistent",
    "Related contacts" : "Contactes relacionats",
    "Agent" : "Agent",
    "Emergency" : "Emergència",
    "Co-worker" : "Company de feina",
    "Gender" : "Gènere",
    "Female" : "Femení",
    "Male" : "Masculí",
    "Unknown" : "Desconegut",
    "Time zone" : "Fus horari",
    "Spoken languages" : "Llengües que parla",
    "_{failed} contact failed to be read_::_{failed} contacts failed to be read_" : ["No s'ha pogut llegir {failed} contacte","No s'han pogut llegir {failed} contactes"],
    "An error has occurred in team(s). Check the console for more details." : "S'ha produït un error al(s) equip(s). Consulteu la consola per obtenir més detalls.",
    "Unable to create team {circleName}" : "No es pot crear l'equip {circleName}",
    "Unable to delete team {circleId}" : "No es pot suprimir l'equip {circleId}",
    "Unable to delete contact" : "No s'ha pogut suprimir el contacte"
},
"nplurals=2; plural=(n != 1);");
