OC.L10N.register(
    "contacts",
    {
    "Import contacts" : "Uvezi kontakte",
    "Details" : "Pojedinosti",
    "All contacts" : "Svi kontakti",
    "_Imported %n contact_::_Imported %n contacts_" : ["Uvezen %n kontakt","Uvezena %n kontakta","Uvezeno %n kontakata"],
    "_(skipped %n contact)_::_(skipped %n contacts)_" : ["(preskočen %n kontakt)","(preskočena %n kontakta)","(preskočeno %n kontakata)"],
    "Contacts" : "Kontakti",
    "A contacts app for Nextcloud" : "Aplikacija za kontakte za Nextcloud",
    "The Nextcloud contacts app is a user interface for Nextcloud's CardDAV server. Easily sync contacts from various devices with your Nextcloud and edit them online.\n\n* 🚀 **Integration with other Nextcloud apps!** Currently Mail and Calendar – more to come.\n* 🎉 **Never forget a birthday!** You can sync birthdays and other recurring events with your Nextcloud Calendar.\n* 👥 **Sharing of Adressbooks!** You want to share your contacts with your friends or coworkers? No problem!\n* 🙈 **We’re not reinventing the wheel!** Based on the great and open SabreDAV library." : "Nextcloudova aplikacija za kontakte je korisničko sučelje za Nextcloudov CardDAV poslužitelj. Jednostavno sinkronizirajte kontakte s raznih uređaja s Nextcloudom i uređujte ih na mreži.\n\n* 🚀 **Integracija s drugim Nextcloudovim aplikacijama!** Trenutno e-pošta i kalendar – i još puno toga.\n* 🌐 **Nikad više nemojte zaboraviti nečiji rođendan** Sinkronizirajte rođendane i ostale ponavljajuće događaje u svojem Nextcloud kalendaru\n* 🙋 **Dijeljenje adresara!** Želite dijeliti svoje kontakte s prijateljima ili kolegama. Nema problema!\n* 🙈 **Ne izmišljamo toplu vodu!** Na temelju odlične i besplatne SabreDAV biblioteke.",
    "Copy to full name" : "Kopiraj u puno ime",
    "Omit year" : "Izuzmi godinu",
    "Allow updating avatars from social media" : "Omogući ažuriranje avatara s društvenih medija",
    "There was an error fetching the member list" : "Došlo je do pogreške pri dohvaćanju popisa članova",
    "Please select a team" : "Odaberite tim",
    "Loading team…" : "Učitavanje tima…",
    "Loading contacts …" : "Učitavanje kontakata …",
    "There are no contacts yet" : "Još uvijek nema kontakata",
    "Create contact" : "Stvori kontakt",
    "There are no contacts in this group" : "U ovoj grupi nema kontakata",
    "Create contacts" : "Stvori kontakte",
    "Add contacts" : "Dodaj kontakte",
    "Loading …" : "Učitavanje …",
    "Manage team" : "Upravljaj timom",
    "Leave team" : "Napusti tim",
    "Delete team" : "Izbriši tim",
    "Setting saved" : "Postavka je spremljena",
    "Failed to save setting" : "Neuspjelo spremanje postavke",
    "Contacts settings" : "Postavke kontakata",
    "General" : "Općenito",
    "Update avatars from social media" : "Ažuriraj avatare s društvenih mreža",
    "Refreshed once per week" : "Osvježava se jednom tjedno",
    "Address books" : "Adresari",
    "Tried to drop an invalid contact!" : "Pokušaj uklanjanja nevažećeg kontakta!",
    "Rename" : "Preimenuj",
    "Export" : "Izvoz",
    "Send email" : "Pošalji poruku e-pošte",
    "Send email as BCC" : "Pošalji e-poštu kao BCC",
    "Delete" : "Izbriši",
    "Show all groups" : "Prikaži sve grupe",
    "Collapse groups" : "Sakrij grupe",
    "Show all teams" : "Prikaži sve timove",
    "Collapse teams" : "Sažmi timove",
    "Group name cannot be empty" : "Naziv grupe ne može biti prazan",
    "This group already exists" : "Ova grupa već postoji",
    "An error occurred while creating the group" : "Došlo je do pogreške pri stvaranju grupe",
    "This team already exists" : "Ovaj tim već postoji",
    "An error happened during the creation of the team" : "Došlo je do pogreške pri stvaranju tima",
    "Recently contacted" : "Nedavno kontaktiran",
    "Contact groups" : "Grupe kontakata",
    "Create a new contact group" : "Stvori novu grupu kontakata",
    "Contact group name" : "Naziv grupe kontakata",
    "Teams" : "Timovi",
    "Create a new team" : "Stvori novi tim",
    "Open the contacts app settings" : "Otvori postavke aplikacije Kontakti",
    "_Shared with {num} entity_::_Shared with {num} entities_" : ["Dijeljeno s {num} entitetom","Dijeljeno s {num} entiteta","Dijeljeno s {num} entiteta"],
    "Copied" : "Kopirano",
    "Cannot copy" : "Nije moguće kopirati",
    "Copy link" : "Kopiraj poveznicu",
    "Toggling of address book was not successful" : "Promjena adresara nije bila uspješna",
    "This will delete the address book and every contacts within it" : "Brisanjem adresara brišu se i svi kontakti koje sadrži",
    "Delete {addressbook}?" : "Izbrisati {addressbook}?",
    "This will unshare the address book and every contacts within it" : "Ovo će ukloniti dijeljenje adresara i svih kontakata u njemu",
    "Unshare {addressbook}?" : "Ukloniti dijeljenje {addressbook}?",
    "Deletion of address book was not successful." : "Neuspješno brisanje adresara",
    "Renaming of address book was not successful." : "Neuspješna promjena naziva adresara",
    "{addressbookname} (Hidden)" : "{addressbookname} (Skriveno)",
    "Download" : "Preuzmi",
    "Show" : "Prikaži",
    "Unshare from me" : "Ukloni dijeljenje sa mnom",
    "_%n contact_::_%n contacts_" : ["%n kontakt","%n kontakta","%n kontakata"],
    "_%n group_::_%n groups_" : ["%n grupa","%n grupe","%n grupa"],
    "Share with users or groups" : "Dijelite s korisnicima ili grupama",
    "Share with users" : "Dijeli s korisnicima",
    "No users or groups" : "Nema korisnika ili grupa",
    "Unable to delete the share" : "Nije moguće izbrisati dijeljenje",
    "Unable to change permissions" : "Nije moguće promijeniti dopuštenja",
    "can create and edit" : "stvaranje i uređivanje moguće",
    "Choose a vCard file to import" : "Odaberite datoteku vCard za uvoz",
    "Import into the {addressbookName} address book" : "Uvezi u adresar {addressbookName}",
    "Select local file" : "Odaberi lokalnu datoteku",
    "Import from files" : "Uvezi iz datoteka",
    "Importing is disabled because there are no address books available" : "Uvoz je onemogućen jer nema dostupnih adresara",
    "An error occurred, unable to create the address book" : "Došlo je do pogreške, nije moguće stvoriti adresar",
    "New address book" : "Novi adresar",
    "Add new address book" : "Dodaj novi adresar",
    "Cancel" : "Odustani",
    "Add" : "Dodaj",
    "First name" : "Ime",
    "Last name" : "Prezime",
    "Phonetic first name" : "Fonetsko ime",
    "Phonetic last name" : "Fonetsko prezime",
    "Display name" : "Ime za prikaz",
    "Last modified" : "Posljednja izmjena",
    "Sort contacts by" : "Sortiraj kontakte po",
    "Manages" : "Upravlja",
    "Oversees" : "Nadzire",
    "An error happened during the config change" : "Došlo je do pogreške tijekom promjene konfiguracije",
    "Enforce password protection on files shared to this team" : "Nametni zaštitu lozinkom za datoteke podijeljene ovom timu",
    "Use a unique password for all shares to this team" : "Koristi jedinstvenu lozinku za sva dijeljenja ovom timu",
    "Unique password …" : "Jedinstvena lozinka …",
    "Save" : "Spremi",
    "Change unique password" : "Promijeni jedinstvenu lozinku",
    "Failed to save password. Please try again later." : "Neuspjelo spremanje lozinke. Pokušajte ponovno kasnije.",
    "Close" : "Zatvori",
    "There is no description for this team" : "Nema opisa za ovaj tim",
    "Enter a description for the team" : "Unesite opis tima",
    "Folder" : "Mapa",
    "New folder" : "Nova mapa",
    "Folder name" : "Naziv mape",
    "This will create a regular folder shared with the team. To create a Team Folder, please contact your {productName} administrator" : "Ovo će stvoriti običnu mapu podijeljenu s timom. Za stvaranje Mape tima obratite se administratoru sustava {productName}",
    "Talk conversation" : "Talk razgovor",
    "New Talk conversation" : "Novi Talk razgovor",
    "Conversation name" : "Naziv razgovora",
    "Collective" : "Kolektiv",
    "Calendar" : "Kalendar",
    "New calendar" : "Novi kalendar",
    "Calendar name" : "Naziv kalendara",
    "Deck board" : "Deck ploča",
    "New Deck board" : "Nova Deck ploča",
    "Board name" : "Naziv ploče",
    "Deck app is not installed. Please install it to create team boards." : "Aplikacija Deck nije instalirana. Instalirajte je kako biste stvorili timske ploče.",
    "Unknown resource type" : "Nepoznata vrsta resursa",
    "Team calendar \"{resourceName}\" created and shared with team" : "Timski kalendar „{resourceName}” je stvoren i podijeljen s timom",
    "{resourceType} \"{resourceName}\" created and shared with team" : "{resourceType} „{resourceName}” je stvoren i podijeljen s timom",
    "A calendar named \"{name}\" already exists. Please choose a different name." : "Kalendar s nazivom „{name}” već postoji. Odaberite drugačiji naziv.",
    "Failed to create {resourceType}: {error}" : "Neuspjelo stvaranje {resourceType}: {error}",
    "An error happened while saving {fields}" : "Došlo je do pogreške pri spremanju: {fields}",
    "Team name" : "Naziv tima",
    "Team owner" : "Vlasnik tima",
    "Delete picture" : "Izbriši sliku",
    "Edit" : "Uredi",
    "Request to join" : "Zahtjev za pridruživanje",
    "Create" : "Stvori",
    "Show in Calendar" : "Prikaži u Kalendaru",
    "Your request to join this team is pending approval" : "Vaš zahtjev za pridruživanje ovom timu čeka odobrenje",
    "You are not a member of {circle}" : "Niste član {circle}",
    "Members" : "Članovi",
    "Confirm" : "Potvrdi",
    "Add more info" : "Dodaj više informacija",
    "More fields" : "Više polja",
    "Please select a valid format" : "Odaberite valjani format",
    "Invalid image" : "Slika neispravna",
    "Error cropping picture" : "Pogreška pri izrezivanju slike",
    "Pick an avatar" : "Odaberi avatar",
    "Pick" : "Odaberi",
    "Error while processing the picture." : "Pogreška tijekom obrade slike.",
    "Avatar downloaded from social network" : "Avatar je preuzet s društvene mreže",
    "Avatar already up to date" : "Avatar je ažuriran",
    "Avatar download failed" : "Preuzimanje avatara nije uspjelo",
    "Crop contact photo" : "Izreži fotografiju kontakta",
    "Upload a new picture" : "Otpremi novu sliku",
    "Choose from Files" : "Odaberi iz datoteka",
    "Download picture" : "Preuzmi sliku",
    "This contact is in read-only mode. You do not have permission to edit this contact." : "Taj je kontakt u načinu rada samo za čitanje. Nemate dopuštenje za uređivanje ovog kontakta.",
    "The contact you were trying to edit has changed. Please manually refresh the contact. Any further edits will be discarded." : "Kontakt koji ste pokušali urediti se promijenio. Ručno osvježite kontakt. Sva daljnja uređivanja bit će odbačena.",
    "Address book" : "Adresar",
    "Add contact to Birthday Calendar" : "Dodaj kontakt u Kalendar rođendana",
    "Exclude contact from Birthday Calendar" : "Izuzmi kontakt iz Kalendara rođendana",
    "{title} at {organization}" : "{title} u {organization}",
    "Name" : "Naziv",
    "Syntax error. Cannot open the contact." : "Sintaktička pogreška. Kontakt se ne može otvoriti.",
    "The contact does not exist on the server anymore." : "Kontakt više ne postoji na poslužitelju.",
    "Unable to retrieve the contact from the server, please check your network connection." : "Nije moguće dohvatiti kontakt s poslužitelja, provjerite svoju mrežnu vezu.",
    "An error occurred while trying to move the contact" : "Došlo je do pogreške tijekom prijenosa kontakta",
    "An error occurred while trying to copy the contact" : "Došlo je do pogreške prilikom kopiranja kontakta",
    "Unable to update contact" : "Nije moguće ažurirati kontakt",
    "No contact selected" : "Nije odabran nijedan kontakt",
    "Select a contact on the list to begin" : "Odaberi kontakt s popisa za početak",
    "Title" : "Naslov",
    "Company" : "Tvrtka",
    "Go to talk conversation" : "Idi na Talk razgovor",
    "View profile" : "Prikaži profil",
    "This contact was broken and received a fix. Please review the content and click here to save it." : "Kontakt je bio pogrešan i ispravljen je. Pregledajte sadržaj i kliknite ovdje kako biste ga spremili.",
    "Edit profile" : "Uredi profil",
    "Clone contact" : "Kloniraj kontakt",
    "Generate QR Code" : "Generiraj QR kod",
    "Contact vCard as QR code" : "VCard kontakta kao QR kod",
    "Pick an address book" : "Odaberi adresar",
    "Select address book" : "Označi adresar",
    "Media shares with you" : "Medijske datoteke podijeljene s vama",
    "Talk conversations with you" : "Talk razgovori s vama",
    "Calendar events with you" : "Događaji u kalendaru s vama",
    "Deck cards with you" : "Deck kartice s vama",
    "No shared items with this contact" : "Nema dijeljenih stavki s ovim kontaktom",
    "This contact cannot be moved" : "Ovaj kontakt nije moguće premjestiti",
    "This contact cannot be grouped" : "Ovaj kontakt nije moguće grupirati",
    "Add contacts to groups" : "Dodaj kontakte u grupe",
    "Move contacts to addressbook" : "Premjesti kontakte u adresar",
    "Select groups" : "Odaberi grupe",
    "Select addressbook" : "Odaberi adresar",
    "Selected contacts" : "Odabrani kontakti",
    "Please note that only {count} of the {total} contacts can be added to a group" : "Imajte na umu da se u grupu može dodati samo {count} od ukupno {total} kontakata",
    "Please note that only {count} of the {total} contacts can be moved" : "Imajte na umu da se može premjestiti samo {count} od ukupno {total} kontakata",
    "Move" : "Premjesti",
    "from {addressbook}" : "iz {addressbook}",
    "Remove from favorites" : "Ukloni iz favorita",
    "Add to favorites" : "Dodaj u favorite",
    "Confirm merging contacts" : "Potvrdi spajanje kontakata",
    "The selected contacts have conflicting information. Choose which information to keep" : "Odabrani kontakti imaju proturječne podatke. Odaberite koje podatke želite zadržati",
    "Contacts can be merged" : "Kontakte je moguće spojiti",
    "Groups" : "Grupe",
    "Select groups to add the merged contact to" : "Odaberite grupe u koje želite dodati spojeni kontakt",
    "Merge contacts" : "Spoji kontakte",
    "_Delete {number} contact_::_Delete {number} contacts_" : ["Izbriši {number} kontakt","Izbriši {number} kontakta","Izbriši {number} kontakata"],
    "Please select at least one editable contact to delete" : "Odaberite barem jedan kontakt koji se može uređivati za brisanje",
    "Please select two editable contacts to merge" : "Odaberite dva kontakta koja se mogu uređivati za spajanje",
    "_Add {number} contact to group_::_Add {number} contacts to group_" : ["Dodaj {number} kontakt u grupu","Dodaj {number} kontakta u grupu","Dodaj {number} kontakata u grupu"],
    "Please select at least one editable contact to add to a group" : "Odaberite barem jedan kontakt koji se može uređivati za dodavanje u grupu",
    "_Move {number} contact to addressbook_::_Move {number} contacts to addressbook_" : ["Premjesti {number} kontakt u adresar","Premjesti {number} kontakta u adresar","Premjesti {number} kontakata u adresar"],
    "Please select at least one editable contact to move to an addressbook" : "Odaberite barem jedan kontakt koji se može uređivati za premještanje u adresar",
    "Are you sure you want to proceed?" : "Jeste li sigurni da želite nastaviti?",
    "Add contacts to group" : "Dodaj kontakte u grupu",
    "Search contacts …" : "Pretraži kontakte …",
    "Unselect {number}" : "Poništi odabir {number}",
    "Add to {group}" : "Dodaj u {group}",
    "Add members to {group}" : "Dodaj članove u {group}",
    "Please note that you can only add contacts from writable address books to contact groups. Contacts from read-only address books, such as the system address book, cannot be added." : "Imajte na umu da u grupe kontakata možete dodavati samo kontakte iz adresara u koje je moguće pisati. Kontakte iz adresara samo za čitanje, poput sistemskog adresara, nije moguće dodati.",
    "Remove {type}" : "Ukloni {type}",
    "Add to group" : "Dodaj u grupu",
    "Add members to group" : "Dodaj članove u grupu",
    "Search {types}" : "Traži {types}",
    "Add guest" : "Dodaj gosta",
    "Search for people to add" : "Potraži osobe za dodavanje",
    "No results" : "Nema rezultata",
    "Add {type}" : "Dodaj {type}",
    "New team name" : "Naziv novog tima",
    "Personal team" : "Osobni tim",
    "This team will only be visible to you. Other members will not be able to see or use it." : "Ovaj tim bit će vidljiv samo vama. Ostali članovi ga neće moći vidjeti ni koristiti.",
    "Local team" : "Lokalni tim",
    "This team will not be shared with the other instances of the global scale" : "Ovaj tim neće se dijeliti s drugim instancama globalne skale",
    "Create team" : "Stvori tim",
    "Promote as sole owner" : "Unaprijedi kao jedinog vlasnika",
    "Promote to {level}" : "Unaprijedi na {level}",
    "Demote to {level}" : "Vrati na {level}",
    "Are you sure you want to leave this team? This action cannot be undone." : "Jeste li sigurni da želite napustiti ovaj tim? Ovu radnju nije moguće poništiti.",
    "Leave team failed." : "Neuspjelo napuštanje tima.",
    "Could not delete the member {displayName}" : "Brisanje člana {displayName} nije uspjelo",
    "Could not change the member level to {level}" : "Mijenjanje razine člana na {level} nije uspjelo",
    "Could not accept membership request" : "Zahtjev za članstvo nije prihvaćen",
    "Accept membership request" : "Prihvati zahtjev za članstvo",
    "Reject membership request" : "Odbij zahtjev za članstvo",
    "Manage level" : "Upravljaj razinom",
    "Remove member" : "Ukloni člana",
    "Unable to get the results" : "Nije moguće dohvatiti rezultate",
    "Some members could not be added" : "Neki članovi nisu dodani",
    "There was an issue adding members to the team" : "Došlo je do problema pri dodavanju članova u tim",
    "Loading members list …" : "Učitavanje popisa članova …",
    "The list of members is only visible to members of this team" : "Popis članova vidljiv je samo članovima ovog tima",
    "You currently have no access to the member list" : "Trenutačno nemate pristup popisu članova",
    "Add to {team}" : "Dodaj u {team}",
    "Invite members to {team}" : "Pozovi članove u {team}",
    "Pending" : "Na čekanju",
    "Select chart …" : "Odaberi grafikon …",
    "Chart" : "Grafikon",
    "Select Date" : "Odaberi datum",
    "Select type" : "Odaberi vrstu",
    "Add contact in group" : "Dodaj kontakt u grupu",
    "None" : "Nema",
    "copy" : "kopiraj",
    "Select option" : "Odaberi opciju",
    "JavaScript URIs are not allowed" : "JavaScript URI-ji nisu dopušteni",
    "Notes" : "Bilješke",
    "send an email" : "pošalji poruku e-pošte",
    "Personal dates" : "Osobni datumi",
    "Add property of this type" : "Dodaj svojstvo ove vrste",
    "Member" : "Član",
    "This is a read-only group managed by administrators. Group members can only view this group." : "Ovo je grupa samo za čitanje kojom upravljaju administratori. Članovi mogu samo pregledavati ovu grupu.",
    "Unable to create the contact." : "Nije moguće stvoriti kontakt.",
    "Contact not found" : "Kontakt nije pronađen",
    "Group {group} not found" : "Grupa {group} nije pronađena",
    "Add member" : "Dodaj člana",
    "New contact" : "Novi kontakt",
    "_{success} contact added to {name}_::_{success} contacts added to {name}_" : ["{success} kontakt dodan {name}","{success} kontakta dodana {name}","{success} kontakata dodano {name}"],
    "_Adding {success} contact to {name}_::_Adding {success} contacts to {name}_" : ["Dodavanje {success} kontakta {name}","Dodavanje {success} kontakta {name}","Dodavanje {success} kontakata {name}"],
    "_{count} error_::_{count} errors_" : ["{count} pogreška","{count} pogreške","{count} pogrešaka"],
    "_Importing %n contact into {addressbook}_::_Importing %n contacts into {addressbook}_" : ["Uvoz %n kontakta u {addressbook}","Uvoz %n kontakta u {addressbook}","Uvoz %n kontakata u {addressbook}"],
    "_Done importing %n contact into {addressbook}_::_Done importing %n contacts into {addressbook}_" : ["Završen uvoz %n kontakta u {addressbook}","Završen uvoz %n kontakta u {addressbook}","Završen uvoz %n kontakata u {addressbook}"],
    "No data for this contact" : "Nema podataka za ovaj kontakt",
    "No data for this contact on their profile" : "Nema podataka za ovaj kontakt na njegovom profilu",
    "Import" : "Uvezi",
    "Are you sure you want to import this contact file?" : "Jeste li sigurni da želite uvesti ovu datoteku kontakata?",
    "Could not copy" : "Kopiranje nije uspjelo",
    "Join team" : "Pridruži se timu",
    "You are about to leave {circle}.\nAre you sure?" : "Napustit ćete krug {circle}.\nJeste li sigurni?",
    "Please confirm team leave" : "Potvrdite napuštanje tima",
    "Could not leave the team {displayName}" : "Nije moguće napustiti tim {displayName}",
    "Unable to join the team" : "Nije moguće pridružiti se timu",
    "You are about to delete {circle}.\nAre you sure?" : "Izbrisat ćete krug {circle}.\nJeste li sigurni?",
    "Please confirm team deletion" : "Potvrdite brisanje tima",
    "Unable to delete the team" : "Nije moguće izbrisati tim",
    "Confirm enabling federation" : "Potvrdite omogućavanje udruženja",
    "Enabling this will prevent {circle} from being a member of other teams.\nAre you sure?" : "Omogućavanjem ove opcije spriječit ćete da {circle} bude član drugih timova.\nJeste li sigurni?",
    "Enable federation" : "Omogući udruženja",
    "Link copied to the clipboard" : "Poveznica je kopirana u međuspremnik",
    "Could not copy link to the clipboard." : "Kopiranje poveznice u međuspremnik nije uspjelo.",
    "Not grouped" : "Nije grupirano",
    "Organization chart" : "Organizacijski dijagram",
    "Team" : "Tim",
    "User" : "Korisnik",
    "Group" : "Grupa",
    "Email" : "E-pošta",
    "Contact" : "Kontakt",
    "Moderator" : "Moderator",
    "Admin" : "Administrator",
    "Owner" : "Vlasnik",
    "Invites" : "Pozivi",
    "Anyone can request membership" : "Svatko može zatražiti članstvo",
    "Members need to accept invitation" : "Članovi moraju prihvatiti poziv",
    "Memberships must be confirmed/accepted by a Moderator (requires \"Anyone can request membership\")" : "Članstvo mora potvrditi/prihvatiti moderator (potrebno je \"Svatko može zatražiti članstvo\")",
    "Members can also invite" : "Članovi također mogu pozivati",
    "Membership" : "Članstvo",
    "Prevent teams from being a member of another team" : "Spriječi timove da budu članovi drugog tima",
    "Federation" : "Udruženje",
    "Allow federated members" : "Dopusti udružene članove",
    "Privacy" : "Privatnost",
    "Visible to everyone" : "Vidljivo svima",
    "users" : "korisnici",
    "Users" : "Korisnici",
    "groups" : "grupe",
    "federated users" : "udruženi korisnici",
    "Federated users" : "Udruženi korisnici",
    "teams" : "timovi",
    "email addresses" : "adrese e-pošte",
    "Email addresses" : "Adrese e-pošte",
    "contacts" : "kontakti",
    "Detailed name" : "Detaljan naziv",
    "Additional names" : "Dodatna imena",
    "Prefix" : "Prefiks",
    "Suffix" : "Sufiks",
    "Nickname" : "Nadimak",
    "Website" : "Web-mjesto",
    "Location" : "Lokacija",
    "Federated Cloud ID" : "ID udruženog oblaka",
    "Home" : "Početna",
    "Work" : "Posao",
    "Other" : "Ostalo",
    "Address" : "Adresa",
    "Post office box" : "Poštanski sandučić",
    "Extended address" : "Proširena adresa",
    "City" : "Grad",
    "State or province" : "Savezna država ili pokrajina",
    "Postal code" : "Poštanski broj",
    "Country" : "Država",
    "Birthday" : "Rođendan",
    "Place of birth" : "Mjesto rođenja",
    "Anniversary" : "Godišnjica",
    "Date of death" : "Datum smrti",
    "Place of death" : "Mjesto smrti",
    "Instant messaging" : "Razmjena izravnih poruka",
    "Phone" : "Telefon",
    "Mobile" : "Mobitel",
    "Work mobile" : "Poslovni mobitel",
    "Home mobile" : "Privatni mobitel",
    "Fax" : "Faks",
    "Fax home" : "Privatni faks",
    "Fax work" : "Poslovni faks",
    "Pager" : "Dojavljivač",
    "Voice" : "Glas",
    "Car" : "Automobil",
    "Work pager" : "Poslovni dojavljivač",
    "Line manager" : "Nadređeni",
    "Social network" : "Društvena mreža",
    "Relationship to you" : "Odnos s vama",
    "Spouse" : "Supružnik",
    "Child" : "Dijete",
    "Mother" : "Majka",
    "Father" : "Otac",
    "Parent" : "Roditelj",
    "Brother" : "Brat",
    "Sister" : "Sestra",
    "Relative" : "Rođak/rođakinja",
    "Friend" : "Prijatelj/prijateljica",
    "Colleague" : "Kolega",
    "Assistant" : "Pomoćnik",
    "Related contacts" : "Povezani kontakti",
    "Agent" : "Agent",
    "Emergency" : "Hitno",
    "Co-worker" : "Suradnik",
    "Gender" : "Rod",
    "Female" : "Ženski",
    "Male" : "Muški",
    "Unknown" : "Nepoznato",
    "Time zone" : "Vremenska zona",
    "Spoken languages" : "Poznati jezici",
    "_{failed} contact failed to be read_::_{failed} contacts failed to be read_" : ["{failed} kontakt nije pročitan","{failed} kontakata nije pročitano","{failed} kontakata nije pročitano"],
    "An error has occurred in team(s). Check the console for more details." : "Došlo je do pogreške u timu/timovima. Provjerite konzolu za više detalja.",
    "Unable to create team {circleName}" : "Nije moguće stvoriti tim {circleName}",
    "Unable to delete team {circleId}" : "Nije moguće izbrisati tim {circleId}",
    "Unable to delete contact" : "Nije moguće izbrisati kontakt",
    "Value copied to the clipboard" : "Vrijednost kopirana u međuspremnik",
    "Could not copy value to the clipboard." : "Kopiranje vrijednosti u međuspremnik nije uspjelo.",
    "note" : "bilješka",
    "email" : "e-pošta"
},
"nplurals=3; plural=n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2;");
