OC.L10N.register(
    "contacts",
    {
    "Import contacts" : "連絡先のインポート",
    "Details" : "詳細",
    "All contacts" : "すべての連絡先",
    "Contacts" : "連絡先",
    "A contacts app for Nextcloud" : "Nextcloud の連絡先アプリ",
    "The Nextcloud contacts app is a user interface for Nextcloud's CardDAV server. Easily sync contacts from various devices with your Nextcloud and edit them online.\n\n* 🚀 **Integration with other Nextcloud apps!** Currently Mail and Calendar – more to come.\n* 🎉 **Never forget a birthday!** You can sync birthdays and other recurring events with your Nextcloud Calendar.\n* 👥 **Sharing of Adressbooks!** You want to share your contacts with your friends or coworkers? No problem!\n* 🙈 **We’re not reinventing the wheel!** Based on the great and open SabreDAV library." : "Nextcloud の連絡先アプリは、 Nextcloud の CardDAV サーバーのユーザーインターフェースです。 さまざまなデバイスの連絡先を Nextcloud で簡単に同期し、オンラインで編集できます。\n\n*🚀**他の Nextcloud アプリケーションとの統合！**現在、メールとカレンダー - 今後の予定です。\n*🎉**誕生日を忘れないでください！**あなたの Nextcloud カレンダーで誕生日やその他の定期的なイベントを同期できます。\n*👥** 連絡先の共有！**あなたの友達や同僚とあなたの連絡先を共有したいですか？ 問題ない！\n*🙈**私たちは車輪を再発明していません！**偉大でオープンな SabreDAV ライブラリをベースにしています。",
    "Copy to full name" : "フルネームをコピー",
    "Omit year" : "年を省略する",
    "Allow updating avatars from social media" : "ソーシャルメディアからのアバターの更新を許可する",
    "There was an error fetching the member list" : "メンバーリストの取得中にエラーが発生しました",
    "Please select a team" : "チームを選択してください",
    "Loading team…" : "チームを読み込み中...",
    "There are no contacts yet" : "連絡先はまだありません",
    "Create contact" : "連絡先を作成",
    "There are no contacts in this group" : "このグループには連絡先がありません",
    "Create contacts" : "連絡先を作成",
    "Add contacts" : "連絡先を追加",
    "Manage team" : "チームを管理",
    "Leave team" : "チームを離脱",
    "Delete team" : "チームを削除",
    "Contacts settings" : "連絡先の設定",
    "Update avatars from social media" : "SNSでアバターをアップデート",
    "Address books" : "アドレス帳",
    "Rename" : "名前を変更",
    "Export" : "エクスポート",
    "Send email" : "メールを送信",
    "Send email as BCC" : "BCCでメール送信",
    "Delete" : "削除",
    "Show all groups" : "すべてのグループを表示",
    "Collapse groups" : "グループを折りたたむ",
    "Show all teams" : "すべてのチームを表示",
    "Collapse teams" : "チームを折りたたむ",
    "Group name cannot be empty" : "グループ名を空にすることはできません",
    "This group already exists" : "このグループはすでに存在しています",
    "An error occurred while creating the group" : "グループ作成中にエラーが発生しました",
    "This team already exists" : "このチームはすでに存在しています",
    "An error happened during the creation of the team" : "チームの作成中にエラーが発生しました",
    "Recently contacted" : "最近連絡した",
    "Contact groups" : "連絡先グループ",
    "Create a new contact group" : "新規連絡先グループを作成",
    "Contact group name" : "連絡先グループ名",
    "Teams" : "チーム",
    "Create a new team" : "新しいチームを作成する",
    "Open the contacts app settings" : "連絡先アプリの設定を開く",
    "_Shared with {num} entity_::_Shared with {num} entities_" : ["{num} 個のエンティティと共有"],
    "Copied" : "コピーしました",
    "Cannot copy" : "コピーできません",
    "Copy link" : "リンクをコピー",
    "Toggling of address book was not successful" : "アドレス帳の切り替えに失敗",
    "This will delete the address book and every contacts within it" : "これはアドレス帳とその中のすべての連絡先を削除します",
    "Delete {addressbook}?" : "{addressbook} を削除しますか？",
    "This will unshare the address book and every contacts within it" : "これにより、アドレス帳とその中のすべての連絡先の共有が解除されます",
    "Unshare {addressbook}?" : "{addressbook}の共有を解除しますか?",
    "Deletion of address book was not successful." : "アドレス帳の削除に失敗しました。",
    "Renaming of address book was not successful." : "アドレス帳の名前変更に失敗しました。",
    "Download" : "ダウンロード",
    "Show" : "表示",
    "Unshare from me" : "共有を自分から解除",
    "_%n contact_::_%n contacts_" : ["%n 連絡先"],
    "_%n group_::_%n groups_" : ["%n グループ"],
    "Share with users or groups" : "ユーザーまたはグループと共有する",
    "Share with users" : "ユーザーに共有",
    "No users or groups" : "ユーザーまたはグループはありません",
    "Unable to delete the share" : "共有を削除できません",
    "Unable to change permissions" : "権限を変更できません。",
    "Choose a vCard file to import" : "インポートするvCardファイルを選択",
    "Import into the {addressbookName} address book" : "アドレス帳 {addressbookName} にインポートします",
    "Select local file" : "ローカルファイルの選択",
    "Import from files" : "ファイルからインポート ",
    "Importing is disabled because there are no address books available" : "使用可能なアドレス帳がないため、インポートは無効です",
    "An error occurred, unable to create the address book" : "エラーが発生し、アドレス帳を作成できませんでした。",
    "Add new address book" : "新しいアドレス帳を追加する",
    "Cancel" : "キャンセル",
    "Add" : "Add",
    "First name" : "名",
    "Last name" : "姓",
    "Phonetic first name" : "めい",
    "Phonetic last name" : "せい",
    "Display name" : "表示名",
    "Last modified" : "最終更新日",
    "Manages" : "管理",
    "Oversees" : "統括",
    "An error happened during the config change" : "構成の変更中にエラーが発生しました",
    "Enforce password protection on files shared to this team" : "このチームと共有するファイルにパスワード保護を強制します",
    "Use a unique password for all shares to this team" : "このチームのすべての共有に一意のパスワードを使用します",
    "Save" : "保存",
    "Change unique password" : "固有パスワードを変更",
    "Failed to save password. Please try again later." : "パスワードを保存できませんでした。後でもう一度やり直してください",
    "Close" : "閉じる",
    "There is no description for this team" : "このチームの説明はありません",
    "Enter a description for the team" : "チームの説明を入力します",
    "Folder" : "フォルダ",
    "Conversation name" : "会話名",
    "Team name" : "チーム名",
    "Delete picture" : "画像を削除",
    "Edit" : "編集",
    "Request to join" : "参加リクエスト",
    "Create" : "作成",
    "Your request to join this team is pending approval" : "このチームへの参加リクエストは承認待ちです",
    "You are not a member of {circle}" : "あなたはサークル{circle}のメンバーではありません",
    "Members" : "メンバー",
    "Confirm" : "承認",
    "Add more info" : "さらに情報を追加",
    "More fields" : "その他のフィールド",
    "Please select a valid format" : "有効なフォーマットを選択してください。",
    "Invalid image" : "無効な画像",
    "Error cropping picture" : "画像のトリミング中にエラーが発生しました",
    "Pick an avatar" : "アバターを選択",
    "Pick" : "選定",
    "Error while processing the picture." : "画像の加工中にエラーが発生しました",
    "Avatar downloaded from social network" : "SNSでダウンロード済みのアバター",
    "Avatar already up to date" : "アバターはすでに最新です",
    "Avatar download failed" : "アバターのダウンロードに失敗しました",
    "Crop contact photo" : "写真を切り抜き",
    "Upload a new picture" : "新しい写真をアップロードする",
    "Choose from Files" : "ファイルから選択",
    "Download picture" : "画像をダウンロード",
    "This contact is in read-only mode. You do not have permission to edit this contact." : "この連絡先は読み取り専用モードです。 この連絡先を編集する権限がありません。",
    "The contact you were trying to edit has changed. Please manually refresh the contact. Any further edits will be discarded." : "編集しようとした連絡先が変更されました。 連絡先を手動で更新してください。 それ以上の編集は破棄されます。",
    "Address book" : "アドレス帳",
    "Add contact to Birthday Calendar" : "誕生日カレンダーに連絡先を追加する",
    "Exclude contact from Birthday Calendar" : "誕生日カレンダーから連絡先を除外する",
    "{title} at {organization}" : "{organization}の{title}",
    "Name" : "名前",
    "Syntax error. Cannot open the contact." : "構文エラー。 連絡先を開けません",
    "The contact does not exist on the server anymore." : "連絡先はサーバー上に存在しません。",
    "Unable to retrieve the contact from the server, please check your network connection." : "サーバーから連絡先を取得できないので、ネットワークの接続をご確認ください。",
    "An error occurred while trying to move the contact" : "連絡先の移動中にエラーが発生しました",
    "An error occurred while trying to copy the contact" : "連絡先のコピー中にエラーが発生しました",
    "Unable to update contact" : "連絡先を更新できません",
    "No contact selected" : "連絡先が選択されていません",
    "Select a contact on the list to begin" : "開始するには、リストの連絡先を選択してください",
    "Title" : "タイトル",
    "Company" : "会社",
    "Go to talk conversation" : "Talkのチャットへ移動",
    "View profile" : "プロフィールを表示",
    "This contact was broken and received a fix. Please review the content and click here to save it." : "この連絡先は変更され、修正を受信しました。内容を確認してクリックで保存してください。",
    "Edit profile" : "プロフィールを編集",
    "Clone contact" : "連絡先の複製",
    "Generate QR Code" : "QRコードを生成",
    "Contact vCard as QR code" : "QRコードでの連絡先vCard",
    "Pick an address book" : "アドレス帳を選ぶ",
    "Select address book" : "アドレス帳を選ぶ",
    "Media shares with you" : "メディアはあなたと共有済み",
    "Talk conversations with you" : "あなたと会話",
    "Calendar events with you" : "カレンダーイベント",
    "Deck cards with you" : "デッキカード",
    "No shared items with this contact" : "この連絡先との共有アイテムはありません",
    "Move" : "Move",
    "Remove from favorites" : "お気に入りから削除",
    "Add to favorites" : "Add to favorites",
    "Groups" : "グループ",
    "Add to {group}" : "{group}に追加",
    "Add members to {group}" : "ユーザーを{group}に追加",
    "Remove {type}" : "{type} を削除",
    "Add to group" : "グループに追加",
    "Add members to group" : "ユーザーをグループに追加",
    "Search {types}" : "{types} を検索",
    "Search for people to add" : "追加するメンバーを検索",
    "No results" : "該当なし",
    "Add {type}" : "{type}を追加",
    "New team name" : "新しいチーム名",
    "Personal team" : "パーソナルチーム",
    "This team will only be visible to you. Other members will not be able to see or use it." : "このチームはあなたにしか見えません。他のメンバーは表示または使用できません。",
    "Local team" : "ローカルチーム",
    "This team will not be shared with the other instances of the global scale" : "このチームはグローバルスケールの他のインスタンスと共有されません",
    "Create team" : "チームを作成する",
    "Promote as sole owner" : "唯一の所有者に昇格",
    "Promote to {level}" : "{level}に昇格",
    "Demote to {level}" : "{level}に降格",
    "Could not delete the member {displayName}" : "メンバー{displayName}を削除できませんでした",
    "Could not change the member level to {level}" : "メンバーレベルを{level}に変更できませんでした",
    "Could not accept membership request" : "メンバーシップリクエストを承諾できませんでした",
    "Accept membership request" : "メンバーシップリクエストを受け入れる",
    "Reject membership request" : "メンバーシップリクエストを拒否",
    "Manage level" : "レベルを管理",
    "Remove member" : "メンバーを削除",
    "Unable to get the results" : "結果を取得できません",
    "Some members could not be added" : "一部のメンバーを追加できませんでした",
    "There was an issue adding members to the team" : "チームへのメンバーの追加で問題が発生しました",
    "The list of members is only visible to members of this team" : "メンバーのリストは、このチームのメンバーにのみ表示されます",
    "You currently have no access to the member list" : "メンバーリストへのアクセス権がありません",
    "Pending" : "保留中",
    "Chart" : "チャート",
    "Select Date" : "日付を選択",
    "Select type" : "タイプを選択",
    "Add contact in group" : "グループに連絡先を追加",
    "None" : "なし",
    "Select option" : "オプションを選択",
    "Notes" : "ノート",
    "Personal dates" : "個人的な日程",
    "Add property of this type" : "このタイプのプロパティーを追加",
    "Member" : "メンバー",
    "Unable to create the contact." : "連絡先を追加できません。",
    "Contact not found" : "連絡先がありません",
    "Group {group} not found" : "グループ {group} が見つかりません",
    "Add member" : "メンバーの追加",
    "New contact" : "新しい連絡先",
    "_{success} contact added to {name}_::_{success} contacts added to {name}_" : ["{success} 件の連絡先を {name} に追加しました"],
    "_Adding {success} contact to {name}_::_Adding {success} contacts to {name}_" : ["{success} 件の連絡先を {name} に追加中"],
    "_{count} error_::_{count} errors_" : ["{count} つのエラー"],
    "_Importing %n contact into {addressbook}_::_Importing %n contacts into {addressbook}_" : ["{アドレス帳}に %n の連絡先をインポートしています。"],
    "_Done importing %n contact into {addressbook}_::_Done importing %n contacts into {addressbook}_" : ["{アドレス帳}に %n 連絡先のインポートが完了しました"],
    "No data for this contact" : "この連絡先のデータはありません",
    "No data for this contact on their profile" : "プロフィールにこの連絡先のデータがありません",
    "Import" : "インポート",
    "Are you sure you want to import this contact file?" : "この連絡先ファイルをインポートしますか?",
    "Could not copy" : "コピーできませんでした",
    "Join team" : "チームに参加する",
    "You are about to leave {circle}.\nAre you sure?" : "{circle}を離れようとしています。\nよろしいですか？",
    "Please confirm team leave" : "チームの離脱を確認してください",
    "Could not leave the team {displayName}" : "チーム{displayName}から離脱できませんでした",
    "Unable to join the team" : "チームに参加できません",
    "You are about to delete {circle}.\nAre you sure?" : "{circle}を削除しようとしています。\nよろしいですか？",
    "Please confirm team deletion" : "チームの削除を確認してください",
    "Unable to delete the team" : "チームを削除できません",
    "Link copied to the clipboard" : "クリップボードにリンクをコピーしました",
    "Could not copy link to the clipboard." : "クリップボードにコピーできませんでした",
    "Not grouped" : "グループ化されていません",
    "Organization chart" : "組織図",
    "Team" : "チーム",
    "User" : "ユーザー",
    "Group" : "グループ",
    "Email" : "メール",
    "Contact" : "連絡先",
    "Moderator" : "モデレータ",
    "Admin" : "管理者",
    "Owner" : "所有者",
    "Invites" : "招待",
    "Anyone can request membership" : "誰でもメンバーへの参加をリクエストできます",
    "Members need to accept invitation" : "メンバーは招待を承認する必要があります",
    "Memberships must be confirmed/accepted by a Moderator (requires \"Anyone can request membership\")" : "メンバシップはモデレータによって確認/承認される必要があります (「誰でもメンバシップをリクエストできます」が必要) 。",
    "Members can also invite" : "メンバーによる招待も可能",
    "Prevent teams from being a member of another team" : "チームが別のチームのメンバーになることを禁止する",
    "Visible to everyone" : "すべての人に公開",
    "users" : "ユーザー",
    "Users" : "ユーザー",
    "groups" : "グループ",
    "teams" : "チーム",
    "email addresses" : "メールアドレス",
    "Email addresses" : "メールアドレス",
    "contacts" : "連絡先",
    "Detailed name" : "詳細名",
    "Additional names" : "ミドルネーム",
    "Prefix" : "プレフィックス",
    "Suffix" : "サフィックス",
    "Nickname" : "ニックネーム",
    "Website" : "ウェブサイト",
    "Location" : "場所",
    "Federated Cloud ID" : "クラウド共有ID",
    "Home" : "自宅",
    "Work" : "職場",
    "Other" : "その他",
    "Address" : "住所",
    "Post office box" : "郵便ポスト",
    "Extended address" : "拡張アドレス",
    "City" : "市町村",
    "State or province" : "都道府県",
    "Postal code" : "郵便番号",
    "Country" : "国名",
    "Birthday" : "誕生日",
    "Place of birth" : "出身地",
    "Anniversary" : "記念日",
    "Date of death" : "命日",
    "Place of death" : "死亡場所",
    "Instant messaging" : "インスタントメッセージ",
    "Phone" : "電話番号",
    "Mobile" : "携帯",
    "Work mobile" : "職場携帯",
    "Home mobile" : "個人携帯",
    "Fax" : "FAX",
    "Fax home" : "自宅FAX",
    "Fax work" : "職場FAX",
    "Pager" : "ポケベル",
    "Voice" : "音声番号",
    "Car" : "自動車",
    "Work pager" : "ワークページャー",
    "Line manager" : "ラインマネージャー",
    "Social network" : "ソーシャルネットワーク",
    "Relationship to you" : "あなたとの関係",
    "Spouse" : "配偶者",
    "Child" : "子供",
    "Mother" : "母親",
    "Father" : "父親",
    "Parent" : "両親",
    "Brother" : "兄弟",
    "Sister" : "姉妹",
    "Relative" : "親族",
    "Friend" : "友人",
    "Colleague" : "同僚",
    "Assistant" : "アシスタント",
    "Related contacts" : "関連した連絡先",
    "Agent" : "エージェント",
    "Emergency" : "緊急",
    "Co-worker" : "同僚",
    "Gender" : "性別",
    "Female" : "女性",
    "Male" : "男性",
    "Unknown" : "不明",
    "Time zone" : "タイムゾーン",
    "Spoken languages" : "話せる言語",
    "_{failed} contact failed to be read_::_{failed} contacts failed to be read_" : ["{failed}連絡先の読み込みができませんでした。"],
    "An error has occurred in team(s). Check the console for more details." : "チームでエラーが発生しました。詳細については、コンソールを確認してください。",
    "Unable to create team {circleName}" : "チーム{circleName}を作成できません",
    "Unable to delete team {circleId}" : "チーム {circleId} を削除できません",
    "Unable to delete contact" : "連絡先を削除できません。"
},
"nplurals=1; plural=0;");
